@@ -7,15 +7,12 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: FileManager.cpp 1312 2006-07-22 14:28:45Z cs $
+ * $Id: FileManager.cpp 1497 2007-06-13 07:54:55Z cs $
  */
 
 #include <assert.h>
-#include <time.h>
 
 #include <qwidgetstack.h>
-#include <qstring.h>
-#include <qstringlist.h>
 #include <qapplication.h>
 #include <qclipboard.h>
 #include <qpushbutton.h>
@@ -46,11 +43,8 @@
 #include <kdatepicker.h>
 #include <kcombobox.h>
 
-#include "Utility.h"
-#include "CoreAttributes.h"
 #include "Report.h"
 #include "FileManager.h"
-#include "ManagedFileInfo.h"
 #include "TjDatePicker.h"
 
 FileManager::FileManager(KMainWindow* m, QWidgetStack* v, KListView* b,
@@ -58,7 +52,7 @@ FileManager::FileManager(KMainWindow* m, QWidgetStack* v, KListView* b,
     mainWindow(m), viewStack(v), browser(b), searchLine(s)
 {
     masterFile = 0;
-    editorConfigured = FALSE;
+    editorConfigured = false;
 
     /* Add our own custom editor actions. */
     new KAction(i18n("Insert Date"), "",
@@ -87,7 +81,7 @@ FileManager::updateFileList(const QStringList& fl, const KURL& url)
     // First we mark all files as no longer part of the project.
     for (std::list<ManagedFileInfo*>::iterator fli = files.begin();
          fli != files.end(); ++fli)
-        (*fli)->setPartOfProject(FALSE);
+        (*fli)->setPartOfProject(false);
 
     /* Then we add the new ones and mark the existing ones as part of the
      * project again. */
@@ -96,15 +90,15 @@ FileManager::updateFileList(const QStringList& fl, const KURL& url)
         KURL url;
         url.setPath(*sli);
 
-        bool newFile = TRUE;
+        bool newFile = true;
         // Is this file being managed already?
         for (std::list<ManagedFileInfo*>::iterator mfi = files.begin();
              mfi != files.end(); ++mfi)
         {
             if ((*mfi)->getFileURL() == url)
             {
-                (*mfi)->setPartOfProject(TRUE);
-                newFile = FALSE;
+                (*mfi)->setPartOfProject(true);
+                newFile = false;
                 break;
             }
         }
@@ -114,7 +108,7 @@ FileManager::updateFileList(const QStringList& fl, const KURL& url)
             // No, so let's add it to our internal list.
             ManagedFileInfo* mfi =
                 new ManagedFileInfo(this, KURL::fromPathOrURL(*sli));
-            mfi->setPartOfProject(TRUE);
+            mfi->setPartOfProject(true);
             files.push_back(mfi);
         }
     }
@@ -369,8 +363,20 @@ FileManager::showInEditor(const KURL& url)
                 }
                 if (!editorConfigured)
                 {
+                    if (!KTextEditor::configInterface(document))
+                    {
+                        KMessageBox::error
+                            (viewStack,
+                             i18n("You have selected a KDE Editor component "
+                                  "that is not powerful enough for "
+                                  "TaskJuggler. "
+                                  "Please select the 'Embedded Advanced Text "
+                                  "Editor' component in the KDE Control "
+                                  "Panel."));
+                        return;
+                    }
                     KTextEditor::configInterface(document)->readConfig(config);
-                    editorConfigured = TRUE;
+                    editorConfigured = true;
                 }
 
                 KTextEditor::View* editor =
@@ -383,8 +389,8 @@ FileManager::showInEditor(const KURL& url)
                                                   editor->sizePolicy()
                                                   .hasHeightForWidth()));
                 document->openURL(url);
-                document->setReadWrite(TRUE);
-                document->setModified(FALSE);
+                document->setReadWrite(true);
+                document->setModified(false);
 
                 // Signal to update the file-modified status
                 connect(document, SIGNAL(textChanged()),
@@ -400,11 +406,18 @@ FileManager::showInEditor(const KURL& url)
                 /* Remove some actions of the editor that we don't want to
                  * show in the menu/toolbars */
                 KActionCollection* ac = editor->actionCollection();
-                ac->remove(ac->action("file_print"));
-                ac->action("view_folding_markers")->setShortcut(KShortcut());
-                ac->action("view_border")->setShortcut(KShortcut());
-                ac->action("view_line_numbers")->setShortcut(KShortcut());
-                ac->action("view_dynamic_word_wrap")->setShortcut(KShortcut());
+                if (ac->action("file_print"))
+                    ac->remove(ac->action("file_print"));
+                if (ac->action("view_folding_markers"))
+                    ac->action("view_folding_markers")->
+                        setShortcut(KShortcut());
+                if (ac->action("view_border"))
+                    ac->action("view_border")->setShortcut(KShortcut());
+                if (ac->action("view_line_numbers"))
+                    ac->action("view_line_numbers")->setShortcut(KShortcut());
+                if (ac->action("view_dynamic_word_wrap"))
+                    ac->action("view_dynamic_word_wrap")->
+                        setShortcut(KShortcut());
 
 /*                KActionPtrList actionList =
                     editor->actionCollection()->actions();
@@ -604,6 +617,9 @@ FileManager::clear()
 void
 FileManager::insertDate()
 {
+    if (!getCurrentFile())
+        return;
+
     // Create some shortcuts for the edit and cursor interface.
     KTextEditor::EditInterface* ei =
         KTextEditor::editInterface(getCurrentFile()->getEditor()->
@@ -721,7 +737,7 @@ FileManager::enableEditorActions(bool enable)
 void
 FileManager::enableClipboardActions(bool enable)
 {
-    bool hasSelection = FALSE;
+    bool hasSelection = false;
     if (getCurrentFile())
         hasSelection = KTextEditor::selectionInterface
             (getCurrentFile()->getEditor()->document())->hasSelection();
@@ -739,12 +755,12 @@ FileManager::enableClipboardActions(bool enable)
 void
 FileManager::enableUndoActions(bool enable)
 {
-    bool undoEnable = FALSE;
+    bool undoEnable = false;
     if (getCurrentFile())
         undoEnable = (KTextEditor::undoInterface
                       (getCurrentFile()->getEditor()->document())->
                       undoCount() > 0 );
-    bool redoEnable = FALSE;
+    bool redoEnable = false;
     if (getCurrentFile())
         redoEnable = (KTextEditor::undoInterface
                       (getCurrentFile()->getEditor()->document())->
@@ -782,11 +798,11 @@ FileManager::showEditor()
 void
 FileManager::hideEditor()
 {
+    // Disable all editor actions.
+    enableEditorActions(false);
+
     if (currentGUIClient)
     {
-        // Disable all editor actions.
-        enableEditorActions(false);
-
         mainWindow->guiFactory()->removeClient(currentGUIClient);
         currentGUIClient = 0;
     }
