@@ -7,14 +7,13 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: ManagedReportInfo.cpp 1214 2005-11-17 20:05:36Z cs $
+ * $Id: ManagedReportInfo.cpp 1497 2007-06-13 07:54:55Z cs $
  */
 
 #include "ManagedReportInfo.h"
 
 #include "klocale.h"
 
-#include "Report.h"
 #include "TjReport.h"
 
 ManagedReportInfo::ManagedReportInfo(ReportManager* rm, Report* r) :
@@ -22,7 +21,7 @@ ManagedReportInfo::ManagedReportInfo(ReportManager* rm, Report* r) :
 {
     report = 0;
     browserEntry = 0;
-    loadingProject = FALSE;
+    loadingProject = false;
 }
 
 ManagedReportInfo::~ManagedReportInfo()
