@@ -8,7 +8,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: TjGanttChart.cpp 1365 2007-01-10 12:55:41Z cs $
+ * $Id: TjGanttChart.cpp 1497 2007-06-13 07:54:55Z cs $
  */
 
 #include "TjGanttChart.h"
@@ -26,12 +26,8 @@
 #include <kglobal.h>
 
 #include "Project.h"
-#include "Task.h"
 #include "Resource.h"
-#include "TaskList.h"
-#include "ResourceList.h"
 #include "QtReport.h"
-#include "QtReportElement.h"
 #include "TjObjPosTable.h"
 #include "TjGanttZoomStep.h"
 #include "TjLineAccounter.h"
@@ -787,7 +783,7 @@ TjGanttChart::generateHeaderAndGrid()
         reportDef->getProject()->getStart() &&
         reportDef->getProject()->getNow() < reportDef->getProject()->getEnd())
         markBoundary(time2x(reportDef->getProject()->getNow()),
-                            TRUE, TJRL_NOWLINE);
+                            true, TJRL_NOWLINE);
 }
 
 void
@@ -1002,7 +998,7 @@ TjGanttChart::generateGanttBackground()
     rect->setZ(TJRL_BACKGROUND);
     rect->show();
 
-    bool toggle = FALSE;
+    bool toggle = false;
     for (int y = 0; y < chartHeight; y += 25) // Just temporary
     {
         toggle = !toggle;
@@ -1553,16 +1549,16 @@ TjGanttChart::drawResourceLoadColum(Resource* r, const Task* t,
     // Now we are calculation the load of the resource with respect to this
     // task, to all tasks, and we calculate the not yet allocated load.
     Interval period(start, end);
-    double freeLoad = r->getAvailableWorkLoad(scenario, period);
+    double freeLoad = r->getEffectiveFreeLoad(scenario, period);
     double taskLoad;
     double load;
     Qt::BrushStyle pattern1 , pattern2, pattern3;
 
     if (r->getEfficiency() > 0.0)
     {
-        freeLoad = r->getAvailableWorkLoad(scenario, period);
-        taskLoad = r->getLoad(scenario, period, AllAccounts, t);
-        load = r->getLoad(scenario, period, AllAccounts);
+        freeLoad = r->getEffectiveFreeLoad(scenario, period);
+        taskLoad = r->getEffectiveLoad(scenario, period, AllAccounts, t);
+        load = r->getEffectiveLoad(scenario, period, AllAccounts);
         pattern1 = pattern2 = pattern3 = Qt::Dense4Pattern;
     }
     else
