@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: TjHTMLReport.cpp 1275 2006-03-05 19:16:55Z cs $
+ * $Id: TjHTMLReport.cpp 1336 2006-09-26 18:09:50Z cs $
  */
 
 #include "TjHTMLReport.h"
@@ -23,7 +23,7 @@
 
 TjHTMLReport::TjHTMLReport(QWidget* p, ReportManager* m, Report* rDef,
                                  const QString& n) :
-    TjReportBase(p, m, rDef, n)
+    TjUIReportBase(p, m, rDef, n)
 {
     QVBoxLayout* hl = new QVBoxLayout(this, 0);
     hl->setAutoAdd(true);
@@ -47,10 +47,10 @@ TjHTMLReport::TjHTMLReport(QWidget* p, ReportManager* m, Report* rDef,
 bool
 TjHTMLReport::generateReport()
 {
-    HTMLReport* htmlReport = dynamic_cast<HTMLReport*>(reportDef);
+    HTMLReport* htmlReport = dynamic_cast<HTMLReport*>(report);
     if (!htmlReport->generate())
         return false;
-    KURL reportURL = KURL::fromPathOrURL(reportDef->getFullFileName());
+    KURL reportURL = KURL::fromPathOrURL(report->getFullFileName());
     browser->openURL(reportURL);
 
     return true;
