@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: TjHTMLReport.h 1336 2006-09-26 18:09:50Z cs $
+ * $Id: TjHTMLReport.h 1428 2007-03-17 15:24:21Z cs $
  */
 
 #ifndef _TjHTMLReport_h_
@@ -42,9 +42,6 @@ public slots:
     void showURLinStatusBar(const QString& url);
     void openURLRequest(const KURL &url, const KParts::URLArgs&);
 
-protected:
-    TjHTMLReport() { }
-
 private:
     KHTMLPart* browser;
 } ;
