@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: TjLineAccounter.h 1307 2006-07-19 13:09:16Z cs $
+ * $Id: TjLineAccounter.h 1428 2007-03-17 15:24:21Z cs $
  */
 
 #ifndef _TjLineAccounter_h_
@@ -23,8 +23,6 @@ public:
     ~TjLine() { }
 
 private:
-    TjLine() { }
-
     int coord;
     int start;
     int end;
@@ -40,8 +38,6 @@ public:
     bool collision(bool vertical, int coord, int start, int end);
 
 private:
-    TjLineAccounter() { }
-
     int minDist;
     std::list<TjLine*> vertLines;
     std::list<TjLine*> horizLines;
