@@ -7,30 +7,25 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: TjPrintResourceReport.cpp 1315 2006-08-11 21:05:41Z cs $
+ * $Id: TjPrintResourceReport.cpp 1497 2007-06-13 07:54:55Z cs $
  */
 
 #include "TjPrintResourceReport.h"
 
 #include <qpaintdevice.h>
-#include <qpainter.h>
 #include <qpaintdevicemetrics.h>
 
 #include "Project.h"
-#include "Task.h"
 #include "Resource.h"
-#include "ResourceList.h"
-#include "ReportElement.h"
 #include "QtResourceReport.h"
-#include "QtResourceReportElement.h"
 
 void
 TjPrintResourceReport::initialize()
 {
     // We need those values frequently. So let's store them in a more
     // accessible place.
-    reportElement =
-        (dynamic_cast<const QtResourceReport*>(reportDef))->getTable();
+    reportElement = dynamic_cast<QtReportElement*>(const_cast<QtResourceReport*>(
+                dynamic_cast<const QtResourceReport*>(reportDef))->getTable());
     scenario = reportElement->getScenario(0);
 }
 
@@ -43,12 +38,12 @@ TjPrintResourceReport::generate()
     if (!reportElement->filterResourceList(filteredResourceList, 0,
                                            reportElement->getHideResource(),
                                            reportElement->getRollUpResource()))
-        return FALSE;
+        return false;
     maxDepthResourceList = filteredResourceList.maxDepth();
     (static_cast<const QtResourceReportElement*>(reportElement))->
         sortResourceList(filteredResourceList);
     if (filteredResourceList.isEmpty())
-        return TRUE;
+        return true;
 
     /* Same for task list. Just that we don't have to sort it. It needs to
      * be regenerated per task later on. */
@@ -56,7 +51,7 @@ TjPrintResourceReport::generate()
     if (!reportElement->filterTaskList(filteredTaskList, 0,
                                        reportElement->getHideTask(),
                                        reportElement->getRollUpTask()))
-        return FALSE;
+        return false;
     maxDepthTaskList = filteredTaskList.maxDepth();
 
     generateTableHeader();
@@ -73,7 +68,7 @@ TjPrintResourceReport::generate()
         if (!reportElement->filterTaskList
             (filteredTaskList, *rli, reportElement->getHideTask(),
              reportElement->getRollUpTask()))
-            return FALSE;
+            return false;
         reportElement->sortTaskList(filteredTaskList);
         for (TaskListIterator tli(filteredTaskList); *tli; ++tli)
         {
@@ -88,6 +83,6 @@ TjPrintResourceReport::generate()
 
     layoutPages();
 
-    return TRUE;
+    return true;
 }
 
