@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: TjPrintTaskReport.cpp 1315 2006-08-11 21:05:41Z cs $
+ * $Id: TjPrintTaskReport.cpp 1497 2007-06-13 07:54:55Z cs $
  */
 
 #include "TjPrintTaskReport.h"
@@ -15,16 +15,11 @@
 #include <assert.h>
 
 #include <qpaintdevice.h>
-#include <qpainter.h>
 #include <qpaintdevicemetrics.h>
 
 #include "Project.h"
-#include "Task.h"
 #include "Resource.h"
-#include "ResourceList.h"
-#include "ReportElement.h"
 #include "QtTaskReport.h"
-#include "QtTaskReportElement.h"
 
 void
 TjPrintTaskReport::initialize()
@@ -33,8 +28,8 @@ TjPrintTaskReport::initialize()
 
     // We need those values frequently. So let's store them in a more
     // accessible place.
-    reportElement =
-        (dynamic_cast<const QtTaskReport*>(reportDef))->getTable();
+    reportElement = dynamic_cast<QtReportElement*>(const_cast<QtTaskReport*>(
+                dynamic_cast<const QtTaskReport*>(reportDef))->getTable());
     scenario = reportElement->getScenario(0);
 }
 
@@ -47,12 +42,12 @@ TjPrintTaskReport::generate()
     if (!reportElement->filterTaskList(filteredTaskList, 0,
                                        reportElement->getHideTask(),
                                        reportElement->getRollUpTask()))
-        return FALSE;
+        return false;
     maxDepthTaskList = filteredTaskList.maxDepth();
     (static_cast<const QtTaskReportElement*>(reportElement))->
         sortTaskList(filteredTaskList);
     if (filteredTaskList.isEmpty())
-        return TRUE;
+        return true;
 
     /* Same for resource list. Just that we don't have to sort it. It needs to
      * be regenerated per task later on. */
@@ -60,7 +55,7 @@ TjPrintTaskReport::generate()
     if (!reportElement->filterResourceList(filteredResourceList, 0,
                                            reportElement->getHideResource(),
                                            reportElement->getRollUpResource()))
-        return FALSE;
+        return false;
     maxDepthResourceList = filteredResourceList.maxDepth();
 
     generateTableHeader();
@@ -77,7 +72,7 @@ TjPrintTaskReport::generate()
         if (!reportElement->filterResourceList
             (filteredResourceList, *tli, reportElement->getHideResource(),
              reportElement->getRollUpResource()))
-            return FALSE;
+            return false;
         reportElement->sortResourceList(filteredResourceList);
         for (ResourceListIterator rli(filteredResourceList); *rli; ++rli)
         {
@@ -92,6 +87,6 @@ TjPrintTaskReport::generate()
 
     layoutPages();
 
-    return TRUE;
+    return true;
 }
 
