@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: TjReport.cpp 1374 2007-01-28 16:49:27Z cs $
+ * $Id: TjReport.cpp 1497 2007-06-13 07:54:55Z cs $
  */
 
 #include "TjReport.h"
@@ -16,13 +16,11 @@
 
 #include <qsplitter.h>
 #include <qlayout.h>
-#include <qfont.h>
 #include <qheader.h>
 #include <qcanvas.h>
 #include <qdatetime.h>
 #include <qtimer.h>
 #include <qpopupmenu.h>
-#include <qdict.h>
 #include <qpaintdevicemetrics.h>
 
 #include <klistview.h>
@@ -35,13 +33,11 @@
 #include <kglobalsettings.h>
 #include <ktextbrowser.h>
 #include <krun.h>
-#include <kprinter.h>
 #include <kmessagebox.h>
 
 #include "Project.h"
 #include "Task.h"
 #include "Resource.h"
-#include "Journal.h"
 #include "Utility.h"
 #include "ExpressionTree.h"
 #include "Report.h"
@@ -49,10 +45,7 @@
 #include "TextAttribute.h"
 #include "ReferenceAttribute.h"
 #include "QtTaskReport.h"
-#include "QtTaskReportElement.h"
 #include "QtResourceReport.h"
-#include "QtResourceReportElement.h"
-#include "ReportLayers.h"
 #include "RichTextDisplay.h"
 #include "TjPrintReport.h"
 #include "TjGanttChart.h"
@@ -65,18 +58,18 @@ TjReport::TjReport(QWidget* p, ReportManager* m, Report* const rDef,
                    const QString& n)
     : TjUIReportBase(p, m, rDef, n)
 {
-    loadingProject = FALSE;
+    loadingProject = false;
     autoFit = true;
 
     QHBoxLayout* hl = new QHBoxLayout(this, 0, 0);
     splitter = new QSplitter(Horizontal, this);
 
     listView = new KListView(splitter);
-    listView->setRootIsDecorated(TRUE);
+    listView->setRootIsDecorated(true);
     listView->setSizePolicy(QSizePolicy::Maximum, QSizePolicy::Preferred);
-    listView->setAllColumnsShowFocus(TRUE);
+    listView->setAllColumnsShowFocus(true);
     // The sorting does not work yet properly.
-    listView->header()->setClickEnabled(FALSE);
+    listView->header()->setClickEnabled(false);
     listView->setItemMargin(2);
 
     canvasFrame = new QWidget(splitter);
@@ -169,12 +162,12 @@ TjReport::print()
 
     // This block avoids a compile error due to gotos crossing 'first'.
     {
-        bool first = TRUE;
+        bool first = true;
         for (int y = 0; y < yPages; ++y)
             for (int x = 0; x < xPages; ++x)
             {
                 if (first)
-                    first = FALSE;
+                    first = false;
                 else
                     printer->newPage();
                 tjpr->printReportPage(x, y);
@@ -203,16 +196,16 @@ TjReport::event(QEvent* ev)
 bool
 TjReport::generateReport()
 {
-    setLoadingProject(TRUE);
+    setLoadingProject(true);
 
     setCursor(KCursor::waitCursor());
     if (!this->generateList())
     {
-        setLoadingProject(FALSE);
+        setLoadingProject(false);
         setCursor(KCursor::arrowCursor());
-        return FALSE;
+        return false;
     }
-    setLoadingProject(FALSE);
+    setLoadingProject(false);
     setCursor(KCursor::arrowCursor());
 
     /* The first time we generate the report, the window has not been fully
@@ -222,15 +215,15 @@ TjReport::generateReport()
     delayTimer = new QTimer(this);
     connect(delayTimer, SIGNAL(timeout()),
             this, SLOT(regenerateChart()));
-    delayTimer->start(200, TRUE);
+    delayTimer->start(200, true);
 
     delete statusBarUpdateTimer;
     statusBarUpdateTimer = new QTimer(this);
     connect(statusBarUpdateTimer, SIGNAL(timeout()),
             this, SLOT(updateStatusBar()));
-    statusBarUpdateTimer->start(500, FALSE);
+    statusBarUpdateTimer->start(500, false);
 
-    return TRUE;
+    return true;
 }
 
 void
@@ -324,7 +317,7 @@ TjReport::generateTaskListLine(const QtReportElement* reportElement,
             double val = t->getCredits
                 (scenario, Interval(reportElement->getStart(),
                                     reportElement->getEnd()), Cost, r);
-            cellText = indent(tcf->realFormat.format(val, FALSE),
+            cellText = indent(tcf->realFormat.format(val, false),
                               lvi, tcf->getHAlign() ==
                               TableColumnFormat::right);
         }
@@ -416,7 +409,7 @@ TjReport::generateTaskListLine(const QtReportElement* reportElement,
                 t->getCredits
                 (scenario, Interval(reportElement->getStart(),
                                     reportElement->getEnd()), Cost, r);
-            cellText = indent(tcf->realFormat.format(val, FALSE),
+            cellText = indent(tcf->realFormat.format(val, false),
                               lvi, tcf->getHAlign() ==
                               TableColumnFormat::right);
         }
@@ -441,7 +434,7 @@ TjReport::generateTaskListLine(const QtReportElement* reportElement,
             double val = t->getCredits
                 (scenario, Interval(reportElement->getStart(),
                                     reportElement->getEnd()), Revenue, r);
-            cellText = indent(tcf->realFormat.format(val, FALSE),
+            cellText = indent(tcf->realFormat.format(val, false),
                               lvi, tcf->getHAlign() ==
                               TableColumnFormat::right);
         }
@@ -510,7 +503,7 @@ TjReport::generateResourceListLine(const QtReportElement* reportElement,
             double val = r->getCredits
                 (scenario, Interval(reportElement->getStart(),
                                     reportElement->getEnd()), Cost, t);
-            cellText = indent(tcf->realFormat.format(val, FALSE),
+            cellText = indent(tcf->realFormat.format(val, false),
                               lvi, tcf->getHAlign() ==
                               TableColumnFormat::right);
         }
@@ -522,12 +515,15 @@ TjReport::generateResourceListLine(const QtReportElement* reportElement,
         {
             double val = 0.0;
             if (t)
-                val = r->getLoad(scenario, Interval(t->getStart(scenario),
-                                                    t->getEnd(scenario)),
-                                 AllAccounts, t);
+                val = r->getEffectiveLoad
+                    (scenario, Interval(t->getStart(scenario),
+                                        t->getEnd(scenario)),
+                     AllAccounts, t);
             else
-                val = r->getLoad(scenario, Interval(reportElement->getStart(),
-                                                    reportElement->getEnd()));
+                val = r->getEffectiveLoad
+                    (scenario, Interval(reportElement->getStart(),
+                                        reportElement->getEnd()));
+
             cellText = indent
                 (reportElement->scaledLoad(val, tcf->realFormat), lvi,
                  tcf->getHAlign() == TableColumnFormat::right);
@@ -537,7 +533,7 @@ TjReport::generateResourceListLine(const QtReportElement* reportElement,
             if (!t)
             {
                 double val = 0.0;
-                val = r->getAvailableWorkLoad
+                val = r->getEffectiveFreeLoad
                     (scenario, Interval(reportElement->getStart(),
                                         reportElement->getEnd()));
                 cellText = indent
@@ -582,7 +578,7 @@ TjReport::generateResourceListLine(const QtReportElement* reportElement,
                                     reportElement->getEnd()));
         else if ((*ci)->getName() == "rate")
         {
-            cellText = indent(tcf->realFormat.format(r->getRate(), FALSE),
+            cellText = indent(tcf->realFormat.format(r->getRate(), false),
                               lvi, tcf->getHAlign() ==
                               TableColumnFormat::right);
         }
@@ -591,7 +587,7 @@ TjReport::generateResourceListLine(const QtReportElement* reportElement,
             double val = r->getCredits
                 (scenario, Interval(reportElement->getStart(),
                                     reportElement->getEnd()), Revenue, t);
-            cellText = indent(tcf->realFormat.format(val, FALSE),
+            cellText = indent(tcf->realFormat.format(val, false),
                               lvi, tcf->getHAlign() ==
                               TableColumnFormat::right);
         }
@@ -599,7 +595,7 @@ TjReport::generateResourceListLine(const QtReportElement* reportElement,
         {
             if (!t)
             {
-                double load = r->getLoad
+                double load = r->getEffectiveLoad
                     (scenario, Interval(reportElement->getStart(),
                                         reportElement->getEnd()));
                 double val;
@@ -607,7 +603,7 @@ TjReport::generateResourceListLine(const QtReportElement* reportElement,
                     val = 0.0;
                 else
                 {
-                    double freeLoad = r->getAvailableWorkLoad
+                    double freeLoad = r->getEffectiveFreeLoad
                         (scenario, Interval(reportElement->getStart(),
                                             reportElement->getEnd()));
                     val = 100.0 / (1.0 + (freeLoad / load));
@@ -1030,19 +1026,27 @@ TjReport::showTaskDetails(const Task* task)
         {
             const ReportElement* reportElement = getReportElement();
             double completion = task->getCompletionDegree(scenario) / 100.0;
-            text += i18n("<hr/><b>Effort:</b> %1<br/>");
+            text += i18n("<hr/><b>Effort:</b> %1<br/>")
+                    .arg(reportElement->scaledLoad
+                         (task->getEffort(scenario), report->getNumberFormat(),
+                          true, false));
             if (completion < 0.0)
             {
                 text += i18n("<b>Completion degree:</b> in progress<br/>");
             }
+            else if (completion == 0.0)
+            {
+                text += i18n("<b>Completion degree:</b> 0%<br/>");
+            }
+            else if (completion >= 1.0)
+            {
+                text += i18n("<b>Completion degree:</b> 100%<br/>");
+            }
             else
             {
-                text += i18n("<b>Completion degree:</b> %2%<br/>"
-                             "<b>Done effort:</b> %3<br/>"
-                             "<b>Remaining effort:</b> %4<br/>")
-                    .arg(reportElement->scaledLoad
-                         (task->getEffort(scenario), report->getNumberFormat(),
-                          true, false))
+                text += i18n("<b>Completion degree:</b> %1%<br/>"
+                             "<b>Done effort:</b> %2<br/>"
+                             "<b>Remaining effort:</b> %3<br/>")
                     .arg(task->getCompletionDegree(scenario))
                     .arg(reportElement->scaledLoad
                          (task->getEffort(scenario) * completion,
@@ -1112,8 +1116,8 @@ TjReport::showResourceDetails(Resource* resource)
     QString text;
     Interval iv = Interval(report->getStart(),
                            report->getEnd());
-    double load = resource->getLoad(scenario, iv);
-    double freeLoad = resource->getAvailableWorkLoad(scenario, iv);
+    double load = resource->getEffectiveLoad(scenario, iv);
+    double freeLoad = resource->getEffectiveFreeLoad(scenario, iv);
 
     text = i18n("<b>Resource:</b> %1 (%2)<br/>")
         .arg(resource->getName())
@@ -1315,7 +1319,7 @@ TjReport::show()
     QWidget::show();
 
     if (statusBarUpdateTimer)
-        statusBarUpdateTimer->start(500, FALSE);
+        statusBarUpdateTimer->start(500, false);
 
     updateZoomSelector();
 }
@@ -1364,7 +1368,7 @@ TjReport::treeLevel(const QListViewItem* lvi) const
 }
 
 QString
-TjReport::generateJournal(JournalIterator jit) const
+TjReport::generateJournal(Journal::Iterator jit) const
 {
     QString text;
 
