@@ -7,23 +7,22 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: TjReport.h 1367 2007-01-10 15:24:59Z cs $
+ * $Id: TjReport.h 1497 2007-06-13 07:54:55Z cs $
  */
 
 #ifndef _TjReport_h_
 #define _TjReport_h_
 
-#include <time.h>
 #include <set>
 #include <map>
 #include <vector>
 
-#include <qstring.h>
 #include <qlistview.h>
 
 #include "TjUIReportBase.h"
 #include "TaskList.h"
 #include "ResourceList.h"
+#include "Journal.h"
 #include "ReportLayers.h"
 #include "ltQString.h"
 #include "ltstr.h"
@@ -87,8 +86,6 @@ private slots:
     void updateStatusBar();
 
 protected:
-    TjReport() { }
-
     virtual bool event(QEvent* ev);
     virtual bool generateList() = 0;
 
@@ -110,7 +107,7 @@ protected:
                    bool right);
     int treeLevel(const QListViewItem* lvi) const;
 
-    QString generateJournal(JournalIterator jit) const;
+    QString generateJournal(Journal::Iterator jit) const;
 
     QString generateRTCustomAttributes(const CoreAttributes* ca) const;
 
