@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: TjSummaryReport.h 1336 2006-09-26 18:09:50Z cs $
+ * $Id: TjSummaryReport.h 1428 2007-03-17 15:24:21Z cs $
  */
 
 #ifndef _TjSummaryReport_h_
@@ -36,9 +36,6 @@ public slots:
     virtual void show();
     virtual void hide();
 
-protected:
-    TjSummaryReport() { }
-
 private:
     const Project* project;
     QTextBrowser* textBrowser;
