@@ -8,7 +8,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: taskjugglerview.cpp 1351 2006-10-31 20:34:24Z cs $
+ * $Id: taskjugglerview.cpp 1497 2007-06-13 07:54:55Z cs $
  */
 
 #include "taskjugglerview.h"
@@ -21,7 +21,6 @@
 #include <qsplitter.h>
 #include <qtabwidget.h>
 #include <qtoolbox.h>
-#include <qvaluelist.h>
 #include <qstringlist.h>
 #include <qregexp.h>
 #include <qtooltip.h>
@@ -34,10 +33,8 @@
 #include <qpushbutton.h>
 
 #include <kdebug.h>
-#include <kmainwindow.h>
 #include <kapp.h>
 #include <kaction.h>
-#include <kurl.h>
 #include <ktrader.h>
 #include <klibloader.h>
 #include <kmessagebox.h>
@@ -66,19 +63,15 @@
 #include "TableColumnInfo.h"
 #include "Report.h"
 #include "QtTaskReport.h"
-#include "QtTaskReportElement.h"
 #include "FileManager.h"
-#include "ManagedFileInfo.h"
 #include "ReportManager.h"
-#include "ManagedReportInfo.h"
 #include "TemplateSelector.h"
 #include "taskjuggler.h"
-#include "ltstr.h"
 
 TaskJugglerView::TaskJugglerView(QWidget *parent)
     : DCOPObject("TaskJugglerIface"), QWidget(parent)
 {
-    TJMH.setConsoleMode(FALSE);
+    TJMH.setConsoleMode(false);
 
     // setup our layout manager to automatically add our widgets
     QHBoxLayout *top_layout = new QHBoxLayout(this);
@@ -96,7 +89,7 @@ TaskJugglerView::TaskJugglerView(QWidget *parent)
     mw->fileListViewSearch->setListView(mw->fileListView);
 
     project = 0;
-    loadingProject = FALSE;
+    loadingProject = false;
 
     loadDelayTimer = new QTimer(this);
 
@@ -177,7 +170,7 @@ TaskJugglerView::TaskJugglerView(QWidget *parent)
     KStatusBar* statusBar = (static_cast<KMainWindow*>(parent))->statusBar();
     progressBar = new QProgressBar(statusBar);
     progressBar->setMaximumSize(150, progressBar->maximumHeight());
-    statusBar->addWidget(progressBar, 0, TRUE);
+    statusBar->addWidget(progressBar, 0, true);
 
     // Add icons to the toolbox tab headers
     mw->listViews->setItemIconSet(mw->listViews->indexOf(mw->tasksPage),
@@ -489,9 +482,9 @@ TaskJugglerView::openURL(KURL url)
      * So the GUI won't show up before all files are loaded and scheduled.
      * With a timer we delay the load so we are sure app->exec has been
      * called. */
-    loadDelayTimer->start(200, TRUE);
+    loadDelayTimer->start(200, true);
     urlToLoad = url;
-    showReportAfterLoad = TRUE;
+    showReportAfterLoad = true;
 }
 
 void
@@ -569,7 +562,7 @@ TaskJugglerView::schedule()
     if (vl[1] > 0)
         editorSplitterSizes = vl;
 
-    showReportAfterLoad = TRUE;
+    showReportAfterLoad = true;
     loadProject(fileManager->getMasterFileURL());
 }
 
@@ -580,6 +573,32 @@ TaskJugglerView::stop()
         project->breakScheduling();
 }
 
+void
+TaskJugglerView::generate()
+{
+    if (!fileManager->getMasterFile())
+    {
+        kdDebug() << "TaskJugglerView::schedule(): No master file set" << endl;
+        return;
+    }
+
+    fileManager->saveAllFiles();
+
+    /* If the message list is visible we store the settings of the editor
+     * splitter into a value list. This is reused for later errors and also
+     * stored as property in the config file. */
+    QValueList<int> vl = mw->editorSplitter->sizes();
+    if (vl[1] > 0)
+        editorSplitterSizes = vl;
+
+    showReportAfterLoad = false;
+    loadProject(fileManager->getMasterFileURL());
+    changeStatusBar(i18n("Generating Reports..."));
+    if (!project->generateReports())
+        showErrorMessages();
+    changeStatusBar(i18n("All reports generated."));
+}
+
 void
 TaskJugglerView::nextProblem()
 {
@@ -655,14 +674,14 @@ TaskJugglerView::loadProject(const KURL& url)
     {
         kdDebug() << "TaskJugglerView::loadProject(): Project loading flag is "
                                                       "already set" << endl;
-        return TRUE;
+        return true;
     }
 
     QString fileName = url.path();
 
     delete project;
     project = 0;
-    setLoadingProject(TRUE);
+    setLoadingProject(true);
     project = new Project();
     connect(project, SIGNAL(updateProgressInfo(const QString&)),
             this, SLOT(showProgressInfo(const QString&)));
@@ -672,35 +691,34 @@ TaskJugglerView::loadProject(const KURL& url)
     ProjectFile* pf = new ProjectFile(project);
     (dynamic_cast<TaskJuggler*>(parent()))->enableActions(false);
     setCursor(KCursor::waitCursor());
-    if (!pf->open(fileName, "", "", TRUE))
+    if (!pf->open(fileName, "", "", true))
     {
         KMessageBox::error(this, i18n("Cannot open file %1.")
                            .arg(url.prettyURL()),
                            i18n("Error loading Project") );
         setCursor(KCursor::arrowCursor());
         (dynamic_cast<TaskJuggler*>(parent()))->enableActions(true);
-        setLoadingProject(FALSE);
+        setLoadingProject(false);
         delete pf;
-        return FALSE;
+        return false;
     }
 
     emit announceRecentURL(url);
 
-    int errors = 0;
-    int warnings = 0;
     mw->messageListView->clear();
     messageCounter = 0;
-    if (!pf->parse())
-        errors++;
+    // Reset error and warning counters
+    TJMH.resetCounters();
+
+    pf->parse();
     delete pf;
     changeStatusBar(i18n("Checking project..."));
-    bool fatalError = false;
-    if (errors == 0)
-        project->pass2(false, fatalError, errors, warnings);
+    if (TJMH.getErrors() == 0)
+        project->pass2(false);
 
     changeStatusBar(i18n("Scheduling..."));
-    if (errors == 0)
-        project->scheduleAllScenarios(errors, warnings);
+    if (TJMH.getErrors() == 0)
+        project->scheduleAllScenarios();
 
     // Load tasks into Task List View
     updateTaskList();
@@ -719,49 +737,23 @@ TaskJugglerView::loadProject(const KURL& url)
 
     setCursor(KCursor::arrowCursor());
     (dynamic_cast<TaskJuggler*>(parent()))->enableActions(true);
-    setLoadingProject(FALSE);
+    setLoadingProject(false);
 
     // Show message list when errors have occured
-    QValueList<int> vl;
-    int h = mw->editorSplitter->height();
-    KMainWindow* mainWindow = dynamic_cast<KMainWindow*>(parent());
-    if (errors > 0 || warnings > 0)
-    {
-        // The messages should be visible, so we check whether we already have
-        // a setting for the splitter that is large enough. Otherwise we make
-        // the message list 15% of the splitter size.
-        if (editorSplitterSizes.isEmpty() || editorSplitterSizes[1] < 120)
-        {
-            vl.append(int(h * 0.85));
-            vl.append(int(h * 0.15));
-        }
-        else
-            vl = editorSplitterSizes;
-        mw->editorSplitter->setSizes(vl);
-        changeStatusBar(i18n("The project contains problems!"));
-        showEditor();
-        mw->messageListView->clearSelection();
-        QListViewItem* lvi = mw->messageListView->firstChild();
-        if (lvi)
-        {
-            /* Prevent GUI crash in case the back-end reports an error but
-             * does not provide an error message. */
-            mw->messageListView->setCurrentItem(lvi);
-            lvi->setSelected(true);
-            messageListClicked(lvi);
-
-            mainWindow->action("next_problem")->setEnabled(true);
-            mainWindow->action("previous_problem")->setEnabled(true);
-        }
-    }
+    if (TJMH.getErrors() > 0 || TJMH.getWarnings() > 0)
+        showErrorMessages();
     else
     {
+        QValueList<int> vl;
+        int h = mw->editorSplitter->height();
+
         vl.append(int(h));
         vl.append(int(0));
         mw->editorSplitter->setSizes(vl);
         changeStatusBar(i18n("The project has been scheduled "
                              "without problems."));
 
+        KMainWindow* mainWindow = dynamic_cast<KMainWindow*>(parent());
         mainWindow->action("next_problem")->setEnabled(false);
         mainWindow->action("previous_problem")->setEnabled(false);
 
@@ -771,27 +763,28 @@ TaskJugglerView::loadProject(const KURL& url)
             showReport();
             mw->listViews->setCurrentItem(mw->reportsPage);
             bool dummy;
-            reportManager->showReport(0, dummy);
+            if (!reportManager->showReport(0, dummy))
+                showErrorMessages();
         }
         else
             showEditor();
     }
 
-    return TRUE;
+    return true;
 }
 
 void
 TaskJugglerView::addWarningMessage(const QString& msg, const QString& file,
                                    int line)
 {
-    addMessage(msg, file, line, FALSE);
+    addMessage(msg, file, line, false);
 }
 
 void
 TaskJugglerView::addErrorMessage(const QString& msg, const QString& file,
                                  int line)
 {
-    addMessage(msg, file, line, TRUE);
+    addMessage(msg, file, line, true);
 }
 
 void
@@ -833,7 +826,7 @@ TaskJugglerView::addMessage(const QString& msg, const QString& file,
                     (mw->messageListView, "", textLine, "", "",
                      QString().sprintf("%03d", ++messageCounter));
 
-            parent->setOpen(TRUE);
+            parent->setOpen(true);
             parent->setPixmap(0, KGlobal::iconLoader()->
                               loadIcon(error ? "tj_error" : "tj_warning",
                                        KIcon::Small));
@@ -958,7 +951,7 @@ TaskJugglerView::focusBigTab(QWidget*)
             if (fileManager->getCurrentFile())
                 windowCaption +=
                     fileManager->getCurrentFile()->getUniqueName();
-            fileManager->enableEditorActions(TRUE);
+            fileManager->enableEditorActions(true);
             mw->listViews->setCurrentIndex(lastBrowserUsedWithEditor);
             fileManager->showEditor();
             reportManager->enableReportActions(false);
@@ -1099,8 +1092,8 @@ TaskJugglerView::reportListClicked(int button, QListViewItem* lvi,
     if (!lvi)
         return;
 
-    bool errors = FALSE;
-    bool showReportTab = TRUE;
+    bool errors = false;
+    bool showReportTab = true;
     switch (button)
     {
         case Qt::LeftButton:
@@ -1175,6 +1168,40 @@ TaskJugglerView::tutorial()
     kapp->invokeHelp("tutorial");
 }
 
+void
+TaskJugglerView::showErrorMessages()
+{
+    // The messages should be visible, so we check whether we already have
+    // a setting for the splitter that is large enough. Otherwise we make
+    // the message list 15% of the splitter size.
+    QValueList<int> vl;
+    int h = mw->editorSplitter->height();
+    if (editorSplitterSizes.isEmpty() || editorSplitterSizes[1] < 120)
+    {
+        vl.append(int(h * 0.85));
+        vl.append(int(h * 0.15));
+    }
+    else
+        vl = editorSplitterSizes;
+    mw->editorSplitter->setSizes(vl);
+    changeStatusBar(i18n("The project contains problems!"));
+    showEditor();
+    mw->messageListView->clearSelection();
+    QListViewItem* lvi = mw->messageListView->firstChild();
+    if (lvi)
+    {
+        /* Prevent GUI crash in case the back-end reports an error but
+         * does not provide an error message. */
+        mw->messageListView->setCurrentItem(lvi);
+        lvi->setSelected(true);
+        messageListClicked(lvi);
+
+        KMainWindow* mainWindow = dynamic_cast<KMainWindow*>(parent());
+        mainWindow->action("next_problem")->setEnabled(true);
+        mainWindow->action("previous_problem")->setEnabled(true);
+    }
+}
+
 void
 TaskJugglerView::setLoadingProject(bool lp)
 {
