@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: taskjugglerview.h 1287 2006-03-20 14:27:45Z cs $
+ * $Id: taskjugglerview.h 1479 2007-05-02 20:58:00Z cs $
  */
 
 
@@ -79,6 +79,7 @@ public:
 public slots:
     void schedule();
     void stop();
+    void generate();
     void nextProblem();
     void previousProblem();
     void setFocusToTaskList();
@@ -133,6 +134,7 @@ private:
     QString pickTemplateFile(const QString& extention);
     bool loadProject(const KURL& url);
 
+    void showErrorMessages();
     void updateTaskList();
     void updateResourceList();
     void updateAccountList();
