@@ -7,21 +7,22 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: Account.cpp 1259 2006-01-31 12:04:00Z cs $
+ * $Id: Account.cpp 1497 2007-06-13 07:54:55Z cs $
  */
 
 #include "Account.h"
-#include "Interval.h"
 #include "Task.h"
 #include "Project.h"
 #include "CustomAttributeDefinition.h"
 
 Account::Account(Project* p, const QString& i, const QString& n, Account* pr,
                  AccountType at, const QString& df, uint dl) :
-    CoreAttributes(p, i, n, pr, df, dl), acctType(at)
+    CoreAttributes(p, i, n, pr, df, dl),
+    transactions(),
+    acctType(at)
 {
+    transactions.setAutoDelete(true);
     p->addAccount(this);
-    kotrusId = "";
 }
 
 Account::~Account()
@@ -46,10 +47,10 @@ Account::getVolume(int sc, const Interval& period) const
     // Add plan credits for all tasks that should be credited to this account.
     for (TaskListIterator tli(project->getTaskListIterator()); *tli != 0; ++tli)
         if ((*tli)->getAccount() == this)
-            volume += (*tli)->getCredits(sc, period, acctType, 0, FALSE);
+            volume += (*tli)->getCredits(sc, period, acctType, 0, false);
 
     // Add all transactions that are registered within the period.
-    for (TransactionListIterator tli(transactions); *tli != 0; ++tli)
+    for (TransactionList::Iterator tli(transactions); *tli != 0; ++tli)
         if (period.contains((*tli)->getDate()))
             volume += (*tli)->getAmount();
 
