@@ -7,24 +7,17 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: Account.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: Account.h 1436 2007-03-17 17:04:30Z cs $
  */
 
 #ifndef _Account_h_
 #define _Account_h_
 
-#include <qstring.h>
-#include <qptrlist.h>
-#include <time.h>
-
-#include "CoreAttributes.h"
 #include "AccountList.h"
 #include "TransactionList.h"
 
 class Interval;
 
-#include "taskjuggler.h"
-
 /**
  * @short Stores all account related information.
  * @author Chris Schlaeger <cs@kde.org>
@@ -38,7 +31,7 @@ public:
 
     virtual CAType getType() const { return CA_Account; }
 
-    Account* getParent() const { return (Account*) parent; }
+    Account* getParent() const { return static_cast<Account*>(parent); }
 
     AccountListIterator getSubListIterator() const
     {
@@ -47,9 +40,6 @@ public:
 
     void inheritValues();
 
-    void setKotrusId(const QString& k) { kotrusId = k; }
-    const QString& getKotrusId() const { return kotrusId; }
-
     void setAcctType(AccountType at) { acctType = at; }
     AccountType getAcctType() const { return acctType; }
 
@@ -60,7 +50,6 @@ public:
     double getVolume(int sc, const Interval& period) const;
 
 private:
-    Account() { };  // don't use this
     QString kotrusId;
     TransactionList transactions;
     AccountType acctType;
