@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: AccountList.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: AccountList.h 1420 2007-02-23 02:51:52Z cs $
  */
 #ifndef _AccountList_h_
 #define _AccountList_h_
@@ -24,8 +24,8 @@ class Account;
 class AccountList : public CoreAttributesList
 {
 public:
-    AccountList() 
-    { 
+    AccountList()
+    {
         sorting[0] = CoreAttributesList::TreeMode;
         sorting[1] = CoreAttributesList::IdUp;
     }
@@ -34,11 +34,9 @@ public:
     Account* getAccount(const QString& id) const;
 
     static bool isSupportedSortingCriteria(int sc);
-    
-    virtual int compareItemsLevel(Account* a1, Account* a2, int level);
 
-protected:
-    virtual int compareItems(QCollection::Item i1, QCollection::Item i2);
+    virtual int compareItemsLevel(CoreAttributes* c1, CoreAttributes* c2,
+                                  int level);
 } ;
 
 /**
@@ -46,13 +44,13 @@ protected:
  * @see AccountList
  * @author Chris Schlaeger <cs@kde.org>
  */
-class AccountListIterator : public virtual CoreAttributesListIterator 
+class AccountListIterator : public virtual CoreAttributesListIterator
 {
 public:
     AccountListIterator(const CoreAttributesList& l) :
         CoreAttributesListIterator(l) { }
     virtual ~AccountListIterator() { }
-    Account* operator*() { return (Account*) get(); }
+    Account* operator*() { return static_cast<Account*>(get()); }
 } ;
 
 #endif
