@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: AccountTreeIterator.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: AccountTreeIterator.h 1420 2007-02-23 02:51:52Z cs $
  */
 
 #ifndef _AccountTreeIterator_h_
@@ -22,10 +22,10 @@ public:
         : CoreAttributesTreeIterator(r, m) { }
     virtual ~AccountTreeIterator() { }
 
-    Account* operator*() { return (Account*) current; }
+    Account* operator*() { return static_cast<Account*>(current); }
     Account* operator++()
     {
-        return (Account*) CoreAttributesTreeIterator::operator++();
+        return static_cast<Account*>(CoreAttributesTreeIterator::operator++());
     }
 } ;
 
