@@ -7,19 +7,17 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: Allocation.cpp 1259 2006-01-31 12:04:00Z cs $
+ * $Id: Allocation.cpp 1428 2007-03-17 15:24:21Z cs $
  */
 
-#include "qdom.h"
+#include "Allocation.h"
 
+#include "tjlib-internal.h"
 #include "Resource.h"
 #include "ResourceTreeIterator.h"
-#include "Allocation.h"
 #include "ReportXML.h"
 #include "UsageLimits.h"
 
-#define KW(a) a
-
 /* -- DTD --
     <!ELEMENT Allocation (Load, Persistent)>
     <!ELEMENT Load       (#PCDATA)>
@@ -29,12 +27,16 @@
 */
 
 Allocation::Allocation() :
-    lockedResource(0)
+    limits(0),
+    shifts(),
+    persistent(false),
+    mandatory(false),
+    lockedResource(0),
+    conflictStart(0),
+    candidates(),
+    selectionMode(minAllocationProbability)
 {
-    shifts.setAutoDelete(TRUE);
-    selectionMode = minAllocationProbability;
-    limits = 0;
-    persistent = mandatory = FALSE;
+    shifts.setAutoDelete(true);
 }
 
 Allocation::~Allocation()
@@ -42,23 +44,27 @@ Allocation::~Allocation()
     delete limits;
 }
 
-Allocation::Allocation(const Allocation& a)
+Allocation::Allocation(const Allocation& a) :
+    limits(a.limits ? new UsageLimits(*a.limits) : 0),
+    shifts(),
+    persistent(a.persistent),
+    mandatory(a.mandatory),
+    lockedResource(a.lockedResource),
+    conflictStart(0),
+    candidates(a.candidates),
+    selectionMode(a.selectionMode)
 {
-    shifts.setAutoDelete(TRUE);
-
-    persistent = a.persistent;
-    mandatory = a.mandatory;
-    lockedResource = a.lockedResource;
-    selectionMode = a.selectionMode;
+    shifts.setAutoDelete(true);
 
     for (QPtrListIterator<ShiftSelection> sli(a.shifts); *sli; ++sli)
         shifts.append(new ShiftSelection(**sli));
+}
 
-    candidates = a.candidates;
-    if (a.limits)
-        limits = new UsageLimits(*a.limits);
-    else
-        limits = 0;
+void
+Allocation::setLimits(UsageLimits* l)
+{
+    delete limits;
+    limits = l;
 }
 
 bool
@@ -99,7 +105,7 @@ Allocation::setSelectionMode(const QString& smt)
     else if (smt == KW("random"))
         selectionMode = random;
     else
-        return FALSE;
-    return TRUE;
+        return false;
+    return true;
 }
 
