@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: Allocation.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: Allocation.h 1408 2007-02-18 21:55:37Z cs $
  */
 #ifndef _Allocation_h_
 #define _Allocation_h_
@@ -15,7 +15,6 @@
 #include <qdom.h>
 
 #include "ShiftSelectionList.h"
-#include "ShiftSelection.h"
 
 class Resource;
 class UsageLimits;
@@ -28,7 +27,7 @@ public:
 
     ~Allocation();
 
-    void setLimits(UsageLimits* l) { limits = l; }
+    void setLimits(UsageLimits* l);
     const UsageLimits* getLimits() const { return limits; }
 
     void setPersistent(bool p) { persistent = p; }
