@@ -7,13 +7,11 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: Booking.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: Booking.h 1408 2007-02-18 21:55:37Z cs $
  */
 #ifndef _Booking_h_
 #define _Booking_h_
 
-#include <qstring.h>
-
 #include "Interval.h"
 #include "SbBooking.h"
 
@@ -24,15 +22,22 @@
 class Booking : public SbBooking
 {
 public:
-    Booking(const Interval& iv, Task* t)
-        : SbBooking(t)
-    {
-        interval = new Interval(iv);
-    }
-    Booking(Interval* iv, Task* t) : SbBooking(t), interval(iv) { }
-    Booking(const Interval& iv, SbBooking* sb) : SbBooking(*sb),
-            interval(new Interval(iv)) { }
-    ~Booking() { delete interval; }
+    Booking(const Interval& iv, Task* t) :
+        SbBooking(t),
+        interval(new Interval(iv))
+    { }
+
+    Booking(Interval* iv, Task* t) :
+        SbBooking(t),
+        interval(iv)
+    { }
+
+    Booking(const Interval& iv, SbBooking* sb) :
+        SbBooking(*sb),
+        interval(new Interval(iv))
+    { }
+
+    virtual ~Booking() { delete interval; }
 
     time_t getStart() const { return interval->getStart(); }
     time_t getEnd() const { return interval->getEnd(); }
