@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: BookingList.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: BookingList.h 1393 2007-02-14 20:30:10Z cs $
  */
 #ifndef _BookingList_h_
 #define _BookingList_h_
@@ -26,21 +26,11 @@ public:
     BookingList() { }
     virtual ~BookingList() { }
 
+    typedef QPtrListIterator<Booking> Iterator;
+
 protected:
     virtual int compareItems(QCollection::Item i1, QCollection::Item i2);
 };
 
-/**
- * @short Iterator class for BookingList objects.
- * @author Chris Schlaeger <cs@kde.org>
- */
-class BookingListIterator : public QPtrListIterator<Booking> 
-{
-public:
-    BookingListIterator(const BookingList& l) :
-        QPtrListIterator<Booking>(l) { }
-    virtual ~BookingListIterator() { }
-} ;
-
 #endif
 
