@@ -7,16 +7,14 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: CSVAccountReport.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: CSVAccountReport.h 1448 2007-03-23 09:17:49Z cs $
  */
 
 #ifndef _CSVAccountReport_h_
 #define _CSVAccountReport_h_
 
 #include "CSVReport.h"
-
-class Project;
-class CSVAccountReportElement;
+#include "CSVAccountReportElement.h"
 
 /**
  * @short Stores all information about an CSV account report.
@@ -25,18 +23,16 @@ class CSVAccountReportElement;
 class CSVAccountReport : public CSVReport
 {
 public:
-    CSVAccountReport(Project* p, const QString& f, const QString& df, int dl);
-    virtual ~CSVAccountReport();
+    CSVAccountReport(Project* p, const QString& f, const QString& df, int dl) :
+        CSVReport(p, f, df, dl)
+    {
+        setTable(new CSVAccountReportElement(this, df, dl));
+    }
+
+    virtual ~CSVAccountReport()
+    { }
 
     virtual const char* getType() const { return "CSVAccountReport"; }
-
-    bool generate();
-    CSVAccountReportElement* getTable() { return tab; }
-
-private:
-    CSVAccountReport() { } // Don't use this.
-
-    CSVAccountReportElement* tab;
-} ;
+};
 
 #endif
