@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: CSVAccountReportElement.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: CSVAccountReportElement.h 1428 2007-03-17 15:24:21Z cs $
  */
 #ifndef _CSVAccountReportElement_h_
 #define _CSVAccountReportElement_h_
@@ -18,12 +18,9 @@ class CSVAccountReportElement : public CSVReportElement
 {
 public:
     CSVAccountReportElement(Report* r, const QString& df, int dl);
-    ~CSVAccountReportElement();
+    ~CSVAccountReportElement() { };
 
     bool generate();
-
-private:
-    CSVAccountReportElement() { }
 } ;
 
 #endif
