@@ -7,35 +7,40 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: CSVReport.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: CSVReport.h 1479 2007-05-02 20:58:00Z cs $
  */
 
 #ifndef _CSVReport_h_
 #define _CSVReport_h_
 
-#include "CSVPrimitives.h"
-#include "Report.h"
-
-class Project;
-class ExpressionTree;
+#include "CSVReportElement.h"
+#include "ElementHolder.h"
 
 /**
  * @short Stores all information about an CSV report.
  * @author Chris Schlaeger <cs@kde.org>
  */
-class CSVReport : public Report, public CSVPrimitives
+class CSVReport : public Report, public CSVPrimitives, public ElementHolder
 {
 public:
-    CSVReport(Project* p, const QString& f, const QString& df, int dl);
+    CSVReport(Project* p, const QString& f, const QString& df, int dl) :
+        Report(p, f, df, dl),
+        CSVPrimitives()
+    { }
+
     virtual ~CSVReport() { }
 
     virtual const char* getType() const { return "CSVReport"; }
 
-    void generateHeader();
-    void generateFooter();
+    virtual bool generate()
+    {
+        if (!open())
+            return false;
 
-protected:
-    CSVReport() { }
+        bool ok = getTable()->generate();
+
+        return close() && ok;
+    }
 } ;
 
 #endif
