@@ -7,61 +7,36 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: CSVReportElement.cpp 1374 2007-01-28 16:49:27Z cs $
+ * $Id: CSVReportElement.cpp 1497 2007-06-13 07:54:55Z cs $
  */
 
-#include <config.h>
+#include "CSVReportElement.h"
+
 #include <assert.h>
 
-#include "CSVReportElement.h"
 #include "TjMessageHandler.h"
 #include "tjlib-internal.h"
 #include "Project.h"
-#include "Task.h"
 #include "Resource.h"
 #include "Account.h"
-#include "Report.h"
-#include "Booking.h"
 #include "BookingList.h"
-#include "Utility.h"
-#include "MacroTable.h"
-#include "TableColumnFormat.h"
 #include "TableLineInfo.h"
-#include "TableColumnInfo.h"
 #include "TableCellInfo.h"
 #include "ReferenceAttribute.h"
 #include "TextAttribute.h"
 #include "CSVReport.h"
 #include "UsageLimits.h"
 
-#define KW(a) a
-
-CSVReportElement::CSVReportElement(Report* r, const QString& df, int dl) :
-   ReportElement(r, df, dl)
-{
-    fieldSeparator = ";";
-}
-
-void
-CSVReportElement::generateHeader()
-{
-}
-
-void
-CSVReportElement::generateFooter()
-{
-}
-
 void
 CSVReportElement::generateTableHeader()
 {
-    bool first = TRUE;
+    bool first = true;
     for (QPtrListIterator<TableColumnInfo> it(columns); it; ++it )
     {
         if (!first)
             s() << fieldSeparator;
         else
-            first = FALSE;
+            first = false;
 
         if (columnFormat[(*it)->getName()])
         {
@@ -93,7 +68,7 @@ CSVReportElement::generateLine(TableLineInfo* tli, int funcSel)
 {
     setMacros(tli);
 
-    bool first = TRUE;
+    bool first = true;
     for (QPtrListIterator<TableColumnInfo> it(columns); it; ++it )
     {
         TableCellInfo tci(columnFormat[(*it)->getName()], tli, *it);
@@ -102,7 +77,7 @@ CSVReportElement::generateLine(TableLineInfo* tli, int funcSel)
             if (!first)
                 s() << fieldSeparator;
             else
-                first = FALSE;
+                first = false;
 
             GenCellPtr gcf = 0;
             switch (funcSel)
@@ -159,11 +134,10 @@ CSVReportElement::genCell(const QString& text, TableCellInfo* tci,
         cellText = filterText ? filter(text) : text;
         if (tci->tli->ca1 && !tci->tci->getCellText().isEmpty())
         {
-            QStringList* sl = new QStringList();
-            sl->append(text);
-            cellText = mt.expandReportVariable(tci->tci->getCellText(), sl);
+            QStringList sl(text);
+            cellText = mt.expandReportVariable(tci->tci->getCellText(), &sl);
             QString cellURL = mt.expandReportVariable(tci->tci->getCellURL(),
-                                                      sl);
+                                                      &sl);
         }
     }
     s() << "\"" << cellText << "\"";
@@ -176,7 +150,7 @@ CSVReportElement::reportTaskLoad(double load, TableCellInfo* tci,
     QString text;
     if (tci->tli->task->isActive(tci->tli->sc, period))
         text = scaledLoad(load, tci->tcf->realFormat);
-    genCell(text, tci, FALSE);
+    genCell(text, tci, false);
 }
 
 void
@@ -186,27 +160,26 @@ CSVReportElement::reportResourceLoad(double load, TableCellInfo* tci,
     QString text;
     if (load > 0.0)
         text += scaledLoad(load, tci->tcf->realFormat);
-    genCell(text, tci, FALSE);
+    genCell(text, tci, false);
 }
 
 void
 CSVReportElement::reportCurrency(double value, TableCellInfo* tci, time_t)
 {
-    genCell(tci->tcf->realFormat.format(value, tci), tci, FALSE);
+    genCell(tci->tcf->realFormat.format(value, tci), tci, false);
 }
 
 void
 CSVReportElement::generateTitle(TableCellInfo* tci, const QString& str)
 {
-    QStringList* sl = new QStringList();
-    sl->append(str);
+    QStringList sl(str);
     QString cellText;
     if (!tci->tci->getTitle().isEmpty())
     {
-        cellText = mt.expandReportVariable(tci->tci->getTitle(), sl);
+        cellText = mt.expandReportVariable(tci->tci->getTitle(), &sl);
         if (!tci->tci->getSubTitle().isEmpty())
             cellText += " " + mt.expandReportVariable(tci->tci->getSubTitle(),
-                                                      sl);
+                                                      &sl);
     }
     else
         cellText = str;
@@ -240,7 +213,7 @@ CSVReportElement::generateRightIndented(TableCellInfo* tci, const QString& str)
 
     genCell(str + QString().fill(' ', topIndent + (maxDepth - 1 -
                                                    tci->tli->ca1->treeLevel())),
-            tci, FALSE);
+            tci, false);
 }
 
 void
@@ -262,12 +235,12 @@ CSVReportElement::genHeadCurrency(TableCellInfo* tci)
 void
 CSVReportElement::genHeadDaily1(TableCellInfo* tci)
 {
-    bool first = TRUE;
+    bool first = true;
     bool weekStartsMonday = report->getWeekStartsMonday();
     for (time_t day = midnight(start); day < end; day = sameTimeNextDay(day))
     {
         if (first)
-            first = FALSE;
+            first = false;
         else
             s() << fieldSeparator;
 
@@ -301,13 +274,13 @@ void
 CSVReportElement::genHeadWeekly1(TableCellInfo* tci)
 {
     // Generates the 1st header line for weekly calendar views.
-    bool first = TRUE;
+    bool first = true;
     bool weekStartsMonday = report->getWeekStartsMonday();
     for (time_t week = beginOfWeek(start, weekStartsMonday); week < end;
          week = sameTimeNextWeek(week))
     {
         if (first)
-            first = FALSE;
+            first = false;
         else
             s() << fieldSeparator;
 
@@ -345,13 +318,13 @@ CSVReportElement::genHeadWeekly2(TableCellInfo*)
 void
 CSVReportElement::genHeadMonthly1(TableCellInfo* tci)
 {
-    bool first = TRUE;
+    bool first = true;
     bool weekStartsMonday = report->getWeekStartsMonday();
     for (time_t month = beginOfMonth(start); month < end;
          month = sameTimeNextMonth(month))
     {
         if (first)
-            first = FALSE;
+            first = false;
         else
             s() << fieldSeparator;
 
@@ -393,13 +366,13 @@ CSVReportElement::genHeadQuarterly1(TableCellInfo* tci)
         I18N_NOOP("3rd Quarter"), I18N_NOOP("4th Quarter")
     };
 
-    bool first = TRUE;
+    bool first = true;
     bool weekStartsMonday = report->getWeekStartsMonday();
     for (time_t quarter = beginOfQuarter(start); quarter < end;
          quarter = sameTimeNextQuarter(quarter))
     {
         if (first)
-            first = FALSE;
+            first = false;
         else
             s() << fieldSeparator;
 
@@ -433,13 +406,13 @@ CSVReportElement::genHeadQuarterly2(TableCellInfo*)
 void
 CSVReportElement::genHeadYear(TableCellInfo* tci)
 {
-    bool first = TRUE;
+    bool first = true;
     // Generates 1st header line of monthly calendar view.
     for (time_t year = beginOfYear(start); year < end;
          year = sameTimeNextYear(year))
     {
         if (first)
-            first = FALSE;
+            first = false;
         else
             s() << fieldSeparator;
 
@@ -463,7 +436,7 @@ CSVReportElement::genHeadYear(TableCellInfo* tci)
 void
 CSVReportElement::genCellEmpty(TableCellInfo* tci)
 {
-    genCell("", tci, TRUE);
+    genCell("", tci, true);
 }
 
 void
@@ -471,21 +444,21 @@ CSVReportElement::genCellSequenceNo(TableCellInfo* tci)
 {
     genCell(tci->tli->ca2 == 0 ?
             QString().sprintf("%d.", tci->tli->ca1->getSequenceNo()) :
-            QString(""), tci, TRUE);
+            QString::null, tci, true);
 }
 
 void
 CSVReportElement::genCellNo(TableCellInfo* tci)
 {
     genCell(tci->tli->ca2 == 0 ? QString().sprintf("%d.", tci->tli->idxNo) :
-            QString(""), tci, TRUE);
+            QString::null, tci, true);
 }
 
 void
 CSVReportElement::genCellHierarchNo(TableCellInfo* tci)
 {
     genCell(tci->tli->ca2 == 0 ?
-            tci->tli->ca1->getHierarchNo() : QString(""), tci, TRUE);
+            tci->tli->ca1->getHierarchNo() : QString::null, tci, true);
 }
 
 void
@@ -493,20 +466,20 @@ CSVReportElement::genCellIndex(TableCellInfo* tci)
 {
     genCell(tci->tli->ca2 == 0 ?
             QString().sprintf("%d.", tci->tli->ca1->getIndex()) :
-            QString(""), tci, TRUE);
+            QString::null, tci, true);
 }
 
 void
 CSVReportElement::genCellHierarchIndex(TableCellInfo* tci)
 {
     genCell(tci->tli->ca2 == 0 ?
-            tci->tli->ca1->getHierarchIndex() : QString(""), tci, TRUE);
+            tci->tli->ca1->getHierarchIndex() : QString::null, tci, true);
 }
 
 void
 CSVReportElement::genCellId(TableCellInfo* tci)
 {
-    genCell(tci->tli->ca1->getId(), tci, TRUE);
+    genCell(tci->tli->ca1->getId(), tci, true);
 }
 
 void
@@ -547,7 +520,7 @@ CSVReportElement::genCellName(TableCellInfo* tci)
     }
     else
         text = tci->tli->specialName;
-    genCell(text, tci, TRUE);
+    genCell(text, tci, true);
 }
 
 void
@@ -556,7 +529,7 @@ CSVReportElement::genCellStart(TableCellInfo* tci)
     if (!tci->tli->task->isStartOk(tci->tli->sc))
         tci->setBgColor(colors.getColor("error"));
     genCell(time2user(tci->tli->task->getStart(tci->tli->sc), timeFormat),
-            tci, FALSE);
+            tci, false);
 }
 
 void
@@ -566,7 +539,7 @@ CSVReportElement::genCellEnd(TableCellInfo* tci)
         tci->setBgColor(colors.getColor("error"));
     genCell(time2user(tci->tli->task->getEnd(tci->tli->sc) +
                       (tci->tli->task->isMilestone() ? 1 : 0), timeFormat),
-            tci, FALSE);
+            tci, false);
 }
 
 #define GCMMSE(a) \
@@ -575,7 +548,7 @@ CSVReportElement::genCell##a(TableCellInfo* tci) \
 { \
     genCell(tci->tli->task->get##a(tci->tli->sc) == 0 ? QString() : \
             time2user(tci->tli->task->get##a(tci->tli->sc), timeFormat), \
-            tci, FALSE); \
+            tci, false); \
 }
 
 GCMMSE(MinStart)
@@ -589,7 +562,7 @@ CSVReportElement::genCell##a##Buffer(TableCellInfo* tci) \
 { \
     genCell(QString().sprintf \
             ("%3.0f", tci->tli->task->get##a##Buffer(tci->tli->sc)), \
-            tci, FALSE); \
+            tci, false); \
 }
 
 GCSEBUFFER(Start)
@@ -599,14 +572,14 @@ void
 CSVReportElement::genCellStartBufferEnd(TableCellInfo* tci)
 {
     genCell(time2user(tci->tli->task->getStartBufferEnd
-                         (tci->tli->sc), timeFormat), tci, FALSE);
+                         (tci->tli->sc), timeFormat), tci, false);
 }
 
 void
 CSVReportElement::genCellEndBufferStart(TableCellInfo* tci)
 {
     genCell(time2user(tci->tli->task->getStartBufferEnd
-                      (tci->tli->sc) + 1, timeFormat), tci, FALSE);
+                      (tci->tli->sc) + 1, timeFormat), tci, false);
 }
 
 void
@@ -614,7 +587,7 @@ CSVReportElement::genCellDuration(TableCellInfo* tci)
 {
     genCell(scaledDuration(tci->tli->task->getCalcDuration(tci->tli->sc),
                            tci->tcf->realFormat),
-            tci, FALSE);
+            tci, false);
 }
 
 void
@@ -628,8 +601,8 @@ CSVReportElement::genCellEffort(TableCellInfo* tci)
     }
     else if (tci->tli->ca1->getType() == CA_Resource)
     {
-        val = tci->tli->resource->getLoad(tci->tli->sc, Interval(start, end),
-                                          AllAccounts, tci->tli->task);
+        val = tci->tli->resource->getEffectiveLoad
+            (tci->tli->sc, Interval(start, end), AllAccounts, tci->tli->task);
     }
 
     generateRightIndented(tci, scaledLoad(val, tci->tcf->realFormat));
@@ -641,7 +614,7 @@ CSVReportElement::genCellFreeLoad(TableCellInfo* tci)
     double val = 0.0;
     if (tci->tli->ca1->getType() == CA_Resource)
     {
-        val = tci->tli->resource->getAvailableWorkLoad
+        val = tci->tli->resource->getEffectiveFreeLoad
             (tci->tli->sc, Interval(start, end));
     }
 
@@ -654,12 +627,12 @@ CSVReportElement::genCellUtilization(TableCellInfo* tci)
     double val = 0.0;
     if (tci->tli->ca1->getType() == CA_Resource)
     {
-        double load =
-            tci->tli->resource->getLoad(tci->tli->sc, Interval(start, end));
+        double load = tci->tli->resource->getEffectiveLoad
+            (tci->tli->sc, Interval(start, end));
         if (load > 0.0)
         {
             double availableLoad =
-                tci->tli->resource->getAvailableWorkLoad
+                tci->tli->resource->getEffectiveFreeLoad
                 (tci->tli->sc, Interval(start, end));
 
             val = 100.0 / (1.0 + availableLoad / load);
@@ -691,14 +664,14 @@ CSVReportElement::genCellProjectId(TableCellInfo* tci)
     genCell(tci->tli->task->getProjectId() + " (" +
             report->getProject()->getIdIndex(tci->tli->task->
                                              getProjectId()) + ")", tci,
-            TRUE);
+            true);
 }
 
 void
 CSVReportElement::genCellProjectIDs(TableCellInfo* tci)
 {
     genCell(tci->tli->resource->getProjectIDs(tci->tli->sc,
-                                              Interval(start, end)), tci, TRUE);
+                                              Interval(start, end)), tci, true);
 }
 
 void
@@ -714,7 +687,7 @@ CSVReportElement::genCellResources(TableCellInfo* tci)
 
         text += (*rli)->getName();
     }
-    genCell(text, tci, FALSE);
+    genCell(text, tci, false);
 }
 
 void
@@ -722,9 +695,9 @@ CSVReportElement::genCellResponsible(TableCellInfo* tci)
 {
     if (tci->tli->task->getResponsible())
         genCell(tci->tli->task->getResponsible()->getName(),
-                tci, TRUE);
+                tci, true);
     else
-        genCell("", tci, TRUE);
+        genCell("", tci, true);
 }
 
 void
@@ -733,28 +706,28 @@ CSVReportElement::genCellText(TableCellInfo* tci)
     if (tci->tcf->getId() == "note")
     {
         if (tci->tli->task->getNote().isEmpty())
-            genCell("", tci, TRUE);
+            genCell("", tci, true);
         else
-            genCell(tci->tli->task->getNote(), tci, TRUE);
+            genCell(tci->tli->task->getNote(), tci, true);
         return;
     }
 
-    const TextAttribute* ta = (const TextAttribute*)
-        tci->tli->ca1->getCustomAttribute(tci->tcf->getId());
+    const TextAttribute* ta = static_cast<const TextAttribute*>
+        (tci->tli->ca1->getCustomAttribute(tci->tcf->getId()));
     if (!ta || ta->getText().isEmpty())
-        genCell("", tci, TRUE);
+        genCell("", tci, true);
     else
-        genCell(ta->getText(), tci, TRUE);
+        genCell(ta->getText(), tci, true);
 }
 
 void
 CSVReportElement::genCellStatusNote(TableCellInfo* tci)
 {
     if (tci->tli->task->getStatusNote(tci->tli->sc).isEmpty())
-        genCell("", tci, TRUE);
+        genCell("", tci, true);
     else
         genCell(tci->tli->task->getStatusNote(tci->tli->sc),
-                tci, TRUE);
+                tci, true);
 }
 
 void
@@ -816,7 +789,7 @@ void
 CSVReportElement::genCellPriority(TableCellInfo* tci)
 {
     genCell(QString().sprintf("%d", tci->tli->task->getPriority()),
-            tci, TRUE);
+            tci, true);
 }
 
 void
@@ -831,7 +804,7 @@ CSVReportElement::genCellFlags(TableCellInfo* tci)
             flagStr += ", ";
         flagStr += *it;
     }
-    genCell(flagStr, tci, TRUE);
+    genCell(flagStr, tci, true);
 }
 
 void
@@ -846,13 +819,13 @@ CSVReportElement::genCellCompleted(TableCellInfo* tci)
     {
         if (calcedCompletionDegree == providedCompletionDegree)
         {
-            genCell(QString(i18n("in progress")), tci, FALSE);
+            genCell(QString(i18n("in progress")), tci, false);
         }
         else
         {
             genCell(QString(i18n("%1% (in progress)"))
                     .arg((int) providedCompletionDegree),
-                    tci, FALSE);
+                    tci, false);
         }
     }
     else
@@ -860,14 +833,14 @@ CSVReportElement::genCellCompleted(TableCellInfo* tci)
         if (calcedCompletionDegree == providedCompletionDegree)
         {
             genCell(QString("%1%").arg((int) providedCompletionDegree),
-                    tci, FALSE);
+                    tci, false);
         }
         else
         {
             genCell(QString("%1% (%2%)")
                     .arg((int) providedCompletionDegree)
                     .arg((int) calcedCompletionDegree),
-                    tci, FALSE);
+                    tci, false);
         }
     }
 }
@@ -875,7 +848,7 @@ CSVReportElement::genCellCompleted(TableCellInfo* tci)
 void
 CSVReportElement::genCellStatus(TableCellInfo* tci)
 {
-    genCell(tci->tli->task->getStatusText(tci->tli->sc), tci, FALSE);
+    genCell(tci->tli->task->getStatusText(tci->tli->sc), tci, false);
 }
 
 void
@@ -884,7 +857,7 @@ CSVReportElement::genCellReference(TableCellInfo* tci)
     if (tci->tcf->getId() == "reference")
     {
         if (tci->tli->task->getReference().isEmpty())
-            genCell("", tci, TRUE);
+            genCell("", tci, true);
         else
         {
             QString text =tci->tli->task->getReference();
@@ -892,15 +865,15 @@ CSVReportElement::genCellReference(TableCellInfo* tci)
                 text += filter(tci->tli->task->getReference());
             else
                 text += filter(tci->tli->task->getReferenceLabel());
-            genCell(text, tci, TRUE, FALSE);
+            genCell(text, tci, true, false);
         }
         return;
     }
 
-    const ReferenceAttribute* ra =  (const ReferenceAttribute*)
-        tci->tli->ca1->getCustomAttribute(tci->tcf->getId());
+    const ReferenceAttribute* ra = static_cast<const ReferenceAttribute*>
+        (tci->tli->ca1->getCustomAttribute(tci->tcf->getId()));
     if (!ra || ra->getURL().isEmpty())
-        genCell("", tci, TRUE);
+        genCell("", tci, true);
     else
     {
         QString text = ra->getURL();
@@ -908,14 +881,14 @@ CSVReportElement::genCellReference(TableCellInfo* tci)
             text += filter(ra->getURL());
         else
             text += filter(ra->getLabel());
-        genCell(text, tci, TRUE, FALSE);
+        genCell(text, tci, true, false);
     }
 }
 
 void
 CSVReportElement::genCellScenario(TableCellInfo* tci)
 {
-    genCell(report->getProject()->getScenarioName(tci->tli->sc), tci, FALSE);
+    genCell(report->getProject()->getScenarioName(tci->tli->sc), tci, false);
 }
 
 #define GCDEPFOL(a, b) \
@@ -930,7 +903,7 @@ CSVReportElement::genCell##a(TableCellInfo* tci) \
             text += ", "; \
         text += (*it)->getId(); \
     } \
-    genCell(text, tci, TRUE); \
+    genCell(text, tci, true); \
 }
 
 GCDEPFOL(Depends, Previous)
@@ -1016,11 +989,11 @@ CSVReportElement::genCellTaskFunc(TableCellInfo* tci,
                                   time_t (*beginOfT)(time_t),
                                   time_t (*sameTimeNextT)(time_t))
 {
-    bool first = TRUE;
+    bool first = true;
     for (time_t t = (*beginOfT)(start); t < end; t = (*sameTimeNextT)(t))
     {
         if (first)
-            first = FALSE;
+            first = false;
         else
             s() << fieldSeparator;
 
@@ -1036,17 +1009,17 @@ CSVReportElement::genCellResourceFunc(TableCellInfo* tci,
                                       time_t (*beginOfT)(time_t),
                                       time_t (*sameTimeNextT)(time_t))
 {
-    bool first = TRUE;
+    bool first = true;
     for (time_t t = beginOfT(start); t < end; t = sameTimeNextT(t))
     {
         if (first)
-            first = FALSE;
+            first = false;
         else
             s() << fieldSeparator;
 
         Interval period = Interval(t, sameTimeNextT(t) - 1);
-        double load = tci->tli->resource->getLoad(tci->tli->sc, period,
-                                                  AllAccounts, tci->tli->task);
+        double load = tci->tli->resource->getEffectiveLoad
+            (tci->tli->sc, period, AllAccounts, tci->tli->task);
         reportResourceLoad(load, tci, period);
     }
 }
@@ -1056,12 +1029,12 @@ CSVReportElement::genCellAccountFunc(TableCellInfo* tci,
                                      time_t (*beginOfT)(time_t),
                                      time_t (*sameTimeNextT)(time_t))
 {
-    bool first = TRUE;
+    bool first = true;
     tci->tcf->realFormat = currencyFormat;
     for (time_t t = beginOfT(start); t < end; t = sameTimeNextT(t))
     {
         if (first)
-            first = FALSE;
+            first = false;
         else
             s() << fieldSeparator;
 
@@ -1096,13 +1069,13 @@ CSVReportElement::genCellDailyAccount(TableCellInfo* tci)
 void
 CSVReportElement::genCellWeeklyTask(TableCellInfo* tci)
 {
-    bool first = TRUE;
+    bool first = true;
     bool weekStartsMonday = report->getWeekStartsMonday();
     for (time_t week = beginOfWeek(start, weekStartsMonday); week < end;
          week = sameTimeNextWeek(week))
     {
         if (first)
-            first = FALSE;
+            first = false;
         else
             s() << fieldSeparator;
 
@@ -1116,19 +1089,19 @@ CSVReportElement::genCellWeeklyTask(TableCellInfo* tci)
 void
 CSVReportElement::genCellWeeklyResource(TableCellInfo* tci)
 {
-    bool first = TRUE;
+    bool first = true;
     bool weekStartsMonday = report->getWeekStartsMonday();
     for (time_t week = beginOfWeek(start, weekStartsMonday); week < end;
          week = sameTimeNextWeek(week))
     {
         if (first)
-            first = FALSE;
+            first = false;
         else
             s() << fieldSeparator;
 
         Interval period = Interval(week).firstWeek(weekStartsMonday);
-        double load = tci->tli->resource->getLoad(tci->tli->sc, period,
-                                                  AllAccounts, tci->tli->task);
+        double load = tci->tli->resource->getEffectiveLoad
+            (tci->tli->sc, period, AllAccounts, tci->tli->task);
         reportResourceLoad(load, tci, period);
     }
 }
@@ -1136,13 +1109,13 @@ CSVReportElement::genCellWeeklyResource(TableCellInfo* tci)
 void
 CSVReportElement::genCellWeeklyAccount(TableCellInfo* tci)
 {
-    bool first = TRUE;
+    bool first = true;
     bool weekStartsMonday = report->getWeekStartsMonday();
     for (time_t week = beginOfWeek(start, weekStartsMonday); week < end;
          week = sameTimeNextWeek(week))
     {
         if (first)
-            first = FALSE;
+            first = false;
         else
             s() << fieldSeparator;
 
@@ -1224,7 +1197,7 @@ CSVReportElement::genCellResponsibilities(TableCellInfo* tci)
             text += (*it)->getId();
         }
     }
-    genCell(text, tci, TRUE);
+    genCell(text, tci, true);
 }
 
 void
@@ -1237,8 +1210,8 @@ void \
 CSVReportElement::genCell##a##Effort(TableCellInfo* tci) \
 { \
     genCell(tci->tcf->realFormat.format \
-            (tci->tli->resource->get##a##Effort(), FALSE), \
-            tci, TRUE); \
+            (tci->tli->resource->get##a##Effort(), false), \
+            tci, true); \
 }
 
 GCEFFORT(Min)
@@ -1248,28 +1221,22 @@ CSVReportElement::genCellMaxEffort(TableCellInfo* tci)
 {
     genCell(tci->tcf->realFormat.format
             (tci->tli->resource->getLimits() ?
-             tci->tli->resource->getLimits()->getDailyMax() : 0, FALSE),
-            tci, TRUE);
+             tci->tli->resource->getLimits()->getDailyMax() : 0, false),
+            tci, true);
 }
 
 void
 CSVReportElement::genCellEfficiency(TableCellInfo* tci)
 {
     genCell(tci->tcf->realFormat.format(tci->tli->resource->getEfficiency(),
-                                        tci), tci, TRUE);
+                                        tci), tci, true);
 }
 
 void
 CSVReportElement::genCellRate(TableCellInfo* tci)
 {
     genCell(tci->tcf->realFormat.format(tci->tli->resource->getRate(), tci),
-            tci, TRUE);
-}
-
-void
-CSVReportElement::genCellKotrusId(TableCellInfo* tci)
-{
-    genCell(tci->tli->resource->getKotrusId(), tci, TRUE);
+            tci, true);
 }
 
 void
@@ -1279,7 +1246,7 @@ CSVReportElement::genCellTotal(TableCellInfo* tci)
                                                 Interval(start, end));
     if (tci->tli->account->isLeaf())
         tci->tci->addToSum(tci->tli->sc, "total", value);
-    genCell(tci->tcf->realFormat.format(value, tci), tci, FALSE);
+    genCell(tci->tcf->realFormat.format(value, tci), tci, false);
 }
 
 void
@@ -1299,7 +1266,7 @@ CSVReportElement::genCellSummary(TableCellInfo* tci)
                 val += *it;
             else
                 val = *it;
-            genCell(tci->tcf->realFormat.format(val, tci), tci, FALSE);
+            genCell(tci->tcf->realFormat.format(val, tci), tci, false);
         }
     }
     else
@@ -1308,9 +1275,9 @@ CSVReportElement::genCellSummary(TableCellInfo* tci)
         // column cases.
         if (tci->tci->getSubColumns() > 0)
             for (uint col = 0; col < tci->tci->getSubColumns(); ++col)
-                genCell(tci->tcf->realFormat.format(0.0, tci), tci, FALSE);
+                genCell(tci->tcf->realFormat.format(0.0, tci), tci, false);
         else
-            genCell(tci->tcf->realFormat.format(0.0, tci), tci, FALSE);
+            genCell(tci->tcf->realFormat.format(0.0, tci), tci, false);
     }
 }
 
