@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: CSVReportElement.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: CSVReportElement.h 1454 2007-03-23 10:20:38Z cs $
  */
 
 #ifndef _CSVReportElement_h_
@@ -33,11 +33,13 @@ class Interval;
 class CSVReportElement : public ReportElement, public CSVPrimitives
 {
 public:
-    CSVReportElement(Report* r, const QString& df, int dl);
+    CSVReportElement(Report* r, const QString& df, int dl) :
+        ReportElement(r, df, dl),
+        CSVPrimitives(),
+        fieldSeparator(";")
+    { }
     virtual ~CSVReportElement() { }
 
-    virtual bool generate() = 0;
-
     virtual void genHeadDefault(TableCellInfo* tcf);
     virtual void genHeadCurrency(TableCellInfo* tcf);
     virtual void genHeadDaily1(TableCellInfo* tcf);
@@ -112,7 +114,6 @@ public:
     virtual void genCellMaxEffort(TableCellInfo* tli);
     virtual void genCellEfficiency(TableCellInfo* tli);
     virtual void genCellRate(TableCellInfo* tli);
-    virtual void genCellKotrusId(TableCellInfo* tli);
     virtual void genCellTotal(TableCellInfo* tli);
 
     virtual void genCellSummary(TableCellInfo* tli);
@@ -120,17 +121,15 @@ public:
     void setFieldSeparator(const QString fs) { fieldSeparator = fs; }
 
 protected:
-    CSVReportElement() { }
-
     void generateTableHeader();
 
-    void generateHeader();
-    void generateFooter();
+    void generateHeader() { };
+    void generateFooter() { };
 
     void generateLine(TableLineInfo* tli, int funcSel);
 
     void genCell(const QString& text, TableCellInfo* tli, bool multi,
-                 bool filter = TRUE);
+                 bool filter = true);
 
     void generateTitle(TableCellInfo* tci, const QString& str);
 
