@@ -7,16 +7,14 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: CSVResourceReport.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: CSVResourceReport.h 1448 2007-03-23 09:17:49Z cs $
  */
 
 #ifndef _CSVResourceReport_h_
 #define _CSVResourceReport_h_
 
 #include "CSVReport.h"
-
-class Project;
-class CSVResourceReportElement;
+#include "CSVResourceReportElement.h"
 
 /**
  * @short Stores all information about an CSV resource report.
@@ -25,18 +23,13 @@ class CSVResourceReportElement;
 class CSVResourceReport : public CSVReport
 {
 public:
-    CSVResourceReport(Project* p, const QString& f, const QString& df, int dl);
+    CSVResourceReport(Project* p, const QString& f, const QString& df, int dl) :
+        CSVReport(p, f, df, dl)
+    {
+        setTable(new CSVResourceReportElement(this, df, dl));
+    }
+
     virtual ~CSVResourceReport() { }
-
-    virtual const char* getType() const { return "CSVResourceReport"; }
-
-    bool generate();
-    CSVResourceReportElement* getTable() { return tab; }
-
-private:
-    CSVResourceReport() { }
-
-    CSVResourceReportElement* tab;
 } ;
 
 #endif
