@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: CSVResourceReportElement.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: CSVResourceReportElement.h 1428 2007-03-17 15:24:21Z cs $
  */
 
 #ifndef _CSVResourceReportElement_h_
@@ -19,11 +19,9 @@ class CSVResourceReportElement : public CSVReportElement
 {
 public:
     CSVResourceReportElement(Report* r, const QString& df, int dl);
-    ~CSVResourceReportElement();
+    ~CSVResourceReportElement() { };
 
     bool generate();
-private:
-    CSVResourceReportElement() { }
 } ;
 
 #endif
