@@ -7,16 +7,14 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: CSVTaskReport.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: CSVTaskReport.h 1448 2007-03-23 09:17:49Z cs $
  */
 
 #ifndef _CSVTaskReport_h_
 #define _CSVTaskReport_h_
 
 #include "CSVReport.h"
-
-class Project;
-class CSVTaskReportElement;
+#include "CSVTaskReportElement.h"
 
 /**
  * @short Stores all information about an CSV task report.
@@ -25,18 +23,16 @@ class CSVTaskReportElement;
 class CSVTaskReport : public CSVReport
 {
 public:
-    CSVTaskReport(Project* p, const QString& f, const QString& df, int dl);
-    virtual ~CSVTaskReport();
+    CSVTaskReport(Project* p, const QString& f, const QString& df, int dl) :
+        CSVReport(p, f, df, dl)
+    {
+        setTable(new CSVTaskReportElement(this, df, dl));
+    }
+
+    virtual ~CSVTaskReport()
+    { }
 
     virtual const char* getType() const { return "CSVTaskReport"; }
-
-    bool generate();
-    CSVTaskReportElement* getTable() { return tab; }
-
-private:
-    CSVTaskReport() { }
-
-    CSVTaskReportElement* tab;
-} ;
+};
 
 #endif
