@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: CSVTaskReportElement.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: CSVTaskReportElement.h 1428 2007-03-17 15:24:21Z cs $
  */
 
 #ifndef _CSVTaskReportElement_h_
@@ -19,11 +19,9 @@ class CSVTaskReportElement : public CSVReportElement
 {
 public:
     CSVTaskReportElement(Report* r, const QString& df, int dl);
-    ~CSVTaskReportElement();
+    ~CSVTaskReportElement() { };
 
     bool generate();
-private:
-    CSVTaskReportElement() { }
 } ;
 
 #endif
