@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: CoreAttributes.cpp 1373 2007-01-25 15:13:13Z cs $
+ * $Id: CoreAttributes.cpp 1428 2007-03-17 15:24:21Z cs $
  */
 
 #include "CoreAttributes.h"
@@ -20,12 +20,21 @@ CoreAttributes::CoreAttributes(Project* p, const QString& i,
                                const QString& n,
                                CoreAttributes* parent_, const QString& df,
                                uint dl) :
-        project(p), id(i), name(n), parent(parent_), definitionFile(df),
-        definitionLine(dl)
+    project(p),
+    id(i),
+    name(n),
+    parent(parent_),
+    definitionFile(df),
+    definitionLine(dl),
+    sequenceNo(0),
+    hierarchNo(0),
+    index(-1),
+    hierarchIndex(0),
+    sub(new CoreAttributesList()),
+    flags(),
+    customAttributes()
 {
-    customAttributes.setAutoDelete(TRUE);
-    index = -1;
-    sub = new CoreAttributesList();
+    customAttributes.setAutoDelete(true);
     if (parent_)
         parent_->sub->append(this);
 }
@@ -154,7 +163,7 @@ bool
 CoreAttributes::hasSameAncestor(const CoreAttributes* c) const
 {
     if (c == 0)
-        return FALSE;
+        return false;
 
     CoreAttributes const* p1;
     for (p1 = this; p1->parent; p1 = p1->parent)
@@ -169,26 +178,26 @@ bool
 CoreAttributes::isDescendentOf(const CoreAttributes* c) const
 {
     if (c == 0)
-        return FALSE;
+        return false;
 
     for (CoreAttributes const* p = this; p; p = p->parent)
         if (p == c)
-            return TRUE;
+            return true;
 
-    return FALSE;
+    return false;
 }
 
 bool
 CoreAttributes::isParentOf(const CoreAttributes* c) const
 {
     if (!c)
-        return FALSE;
+        return false;
 
     for (CoreAttributes const* p = c->parent; p; p = p->parent)
         if (p == this)
-            return TRUE;
+            return true;
 
-    return FALSE;
+    return false;
 }
 
 bool
@@ -238,11 +247,11 @@ CoreAttributes::inheritCustomAttributes
             {
             case CAT_Text:
                 addCustomAttribute(cadi.currentKey(), new TextAttribute
-                                   (*((TextAttribute*) custAttr)));
+                                   (*(static_cast<const TextAttribute*>(custAttr))));
                 break;
             case CAT_Reference:
                 addCustomAttribute(cadi.currentKey(), new ReferenceAttribute
-                                   (*((ReferenceAttribute*) custAttr)));
+                                   (*(static_cast<const ReferenceAttribute*>(custAttr))));
                 break;
             default:
                 qFatal("CoreAttributes::inheritCustomAttributes: "
