@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: CustomAttributeDefinition.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: CustomAttributeDefinition.h 1428 2007-03-17 15:24:21Z cs $
  */
 #ifndef _CustomAttributeDefinition_h_
 #define _CustomAttributeDefinition_h_
@@ -24,7 +24,10 @@ class CustomAttributeDefinition
 {
 public:
     CustomAttributeDefinition(const QString& n, CustomAttributeType t) :
-        name(n), type(t) { inherit = FALSE; }
+        name(n),
+        type(t),
+        inherit(false)
+    { }
     ~CustomAttributeDefinition() { }
 
     const QString& getName() const { return name; }
