@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: ExpressionFunctionTable.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: ExpressionFunctionTable.h 1413 2007-02-20 08:34:42Z cs $
  */
 
 #ifndef _ExpressionFunctionTable_h_
@@ -21,7 +21,7 @@ class ExpressionFunctionTable
 {
 public:
     ExpressionFunctionTable();
-    ~ExpressionFunctionTable();
+    ~ExpressionFunctionTable() { }
 
     bool isKnownFunction(const QString& name) const
     {
@@ -38,7 +38,10 @@ public:
         return functions[name]->getArgumentCount();
     }
 
-private: 
+private:
+    void addFunc(const QString& name, const ExpressionTreeFunctionLongPtr func,
+                 const int args);
+
     QDict<ExpressionTreeFunction> functions;
 } ;
 
