@@ -7,17 +7,16 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: ExpressionParser.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: ExpressionParser.h 1472 2007-04-19 08:47:13Z cs $
  */
 
 #ifndef _ExpressionParser_h_
 #define _ExpressionParser_h_
 
-#include <qstring.h>
+#include "Tokenizer.h"
 
 class Project;
 class Operation;
-class Tokenizer;
 class ExpressionTree;
 
 /**
@@ -28,18 +27,20 @@ class ExpressionTree;
 class ExpressionParser
 {
 public:
-    ExpressionParser();
-    ~ExpressionParser();
+    ExpressionParser(const QString& text, const Project* proj) :
+        tokenizer(text), project(proj)
+    { }
 
-    Operation* parse(const QString& text, const Project* proj);
+    Operation* parse();
 
 private:
-    Operation* parseLogicalExpression(int precedence, const Project* proj);
-    Operation* parseFunctionCall(const QString& token, const Project* proj);
+    Operation* parseLogicalExpression(int precedence);
+    Operation* parseFunctionCall(const QString& token);
 
-    void errorMessage(const char* msg, ...);
+    void errorMessage(const QString& msg);
 
-    Tokenizer* tokenizer;
+    Tokenizer tokenizer;
+    const Project* project;
 };
 
 #endif
