@@ -7,43 +7,51 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: ExpressionTree.cpp 1259 2006-01-31 12:04:00Z cs $
+ * $Id: ExpressionTree.cpp 1497 2007-06-13 07:54:55Z cs $
  */
 
 #include "ExpressionTree.h"
 #include "Operation.h"
-#include "CoreAttributes.h"
 #include "Project.h"
-#include "Task.h"
 #include "Resource.h"
-#include "Utility.h"
-#include "debug.h"
 #include "ExpressionParser.h"
 #include "ExpressionFunctionTable.h"
 #include "TjMessageHandler.h"
 #include "tjlib-internal.h"
 
-// Dummy marco to mark all keywords of taskjuggler syntax
-#define KW(a) a
-
-ExpressionTree::ExpressionTree(const Operation* op) : expression(op)
+// do not move this into the header, it expands the library image size
+ExpressionTree::ExpressionTree(const Operation* op) :
+    ca(0),
+    symbolTable(),
+    expression(op),
+    evalErrorFlag(false),
+    defFileName(),
+    defLineNo(0)
 {
-    symbolTable.setAutoDelete(TRUE);
-    evalErrorFlag = FALSE;
+    symbolTable.setAutoDelete(true);
 }
 
-ExpressionTree::ExpressionTree(const ExpressionTree& et)
+// do not move this into the header, it expands the library image size
+ExpressionTree::ExpressionTree(const ExpressionTree& et) :
+    ca(et.ca),
+    symbolTable(et.symbolTable),
+    expression(new Operation(*et.expression)),
+    evalErrorFlag(false),
+    defFileName(),
+    defLineNo(0)
 {
-    ca = et.ca;
-    symbolTable = et.symbolTable;
-    expression = new Operation(*et.expression);
-    evalErrorFlag = FALSE;
 }
 
-ExpressionTree::ExpressionTree()
+// do not move this into the header, it expands the library image size
+ExpressionTree::ExpressionTree() :
+    ca(0),
+    symbolTable(),
+    expression(0),
+    evalErrorFlag(false),
+    defFileName(),
+    defLineNo(0)
 {
-    symbolTable.setAutoDelete(TRUE);
-    evalErrorFlag = FALSE;
+    symbolTable.setAutoDelete(true);
 }
 
 ExpressionTree::~ExpressionTree()
@@ -54,14 +62,14 @@ ExpressionTree::~ExpressionTree()
 bool
 ExpressionTree::setTree(const QString& expr, const Project* proj)
 {
-    ExpressionParser parser;
-    return (expression = parser.parse(expr, proj)) != 0;
+    ExpressionParser parser(expr, proj);
+    return (expression = parser.parse()) != 0;
 }
 
 long
 ExpressionTree::evalAsInt(const CoreAttributes* c)
 {
-    evalErrorFlag = FALSE;
+    evalErrorFlag = false;
     ca = c;
     long val = expression->evalAsInt(this);
 
@@ -82,16 +90,9 @@ ExpressionTree::resolve(const QString& symbol)
 }
 
 void
-ExpressionTree::errorMessage(const char* msg, ...)
+ExpressionTree::errorMessage(const QString& msg)
 {
-    va_list ap;
-    char* buf = new char[32 + 2 * strlen(msg)];
-    va_start(ap, msg);
-    vsnprintf(buf, 1024, msg, ap);
-    va_end(ap);
-
-    TJMH.errorMessage(buf, defFileName, defLineNo);
-    delete [] buf;
-    evalErrorFlag = TRUE;
+    TJMH.errorMessage(msg, defFileName, defLineNo);
+    evalErrorFlag = true;
 }
 
