@@ -7,37 +7,31 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: ExpressionTreeFunction.cpp 1313 2006-07-27 10:50:04Z cs $
+ * $Id: ExpressionTreeFunction.cpp 1497 2007-06-13 07:54:55Z cs $
  */
 
-#include "Interval.h"
 #include "ExpressionTreeFunction.h"
+
 #include "ExpressionTree.h"
 #include "Operation.h"
-#include "CoreAttributes.h"
 #include "Project.h"
-#include "Task.h"
 #include "Resource.h"
 #include "Account.h"
-#include "Shift.h"
-#include "debug.h"
 #include "tjlib-internal.h"
 
-#define KW(a) (a)
-
 bool
 ExpressionTreeFunction::checkCoreAttributesType(ExpressionTree* et)
 {
     if (supportedCoreAttributes.isEmpty())
-        return TRUE;
+        return true;
 
     QValueList<CAType>::iterator it;
     for (it = supportedCoreAttributes.begin(); it !=
          supportedCoreAttributes.end(); ++it)
        if (et->getCoreAttributes()->getType() == *it)
-           return TRUE;
+           return true;
 
-    return FALSE;
+    return false;
 }
 
 long
@@ -115,11 +109,11 @@ ExpressionTreeFunction::hasAssignments(ExpressionTree* et,
         end = et->getCoreAttributes()->getProject()->getEnd();
 
     if (et->getCoreAttributes()->getType() == CA_Task)
-        return ((Task*) et->getCoreAttributes())->getLoad
-            (scenarioId, Interval(start, end), 0) > 0.0;
+        return static_cast<const Task*>(et->getCoreAttributes())
+            ->getLoad(scenarioId, Interval(start, end), 0) > 0.0;
     else
-        return ((Resource*) et->getCoreAttributes())->getLoad
-            (scenarioId, Interval(start, end)) > 0.0;
+        return static_cast<const Resource*>(et->getCoreAttributes())
+            ->getEffectiveLoad(scenarioId, Interval(start, end)) > 0.0;
 }
 
 long
@@ -231,7 +225,8 @@ ExpressionTreeFunction::isMilestone(ExpressionTree* et,
     if (et->getCoreAttributes()->getType() != CA_Task)
         return 0;
 
-    return ((Task*) et->getCoreAttributes())->isMilestone();
+    return static_cast<const Task*>(et->getCoreAttributes())
+        ->isMilestone();
 }
 
 long
@@ -247,7 +242,7 @@ ExpressionTreeFunction::isResource(ExpressionTree* et,
                 arg(ops[0]->evalAsString(et)));
             return 0;
         }
-        ops[0]->setValid(TRUE);
+        ops[0]->setValid(true);
     }
 
     return et->getCoreAttributes()->getType() == CA_Resource &&
@@ -274,7 +269,7 @@ ExpressionTreeFunction::isAccount(ExpressionTree* et,
                 arg(ops[0]->evalAsString(et)));
             return 0;
         }
-        ops[0]->setValid(TRUE);
+        ops[0]->setValid(true);
     }
 
     return et->getCoreAttributes()->getType() == CA_Account &&
@@ -311,11 +306,11 @@ ExpressionTreeFunction::isTaskStatus(ExpressionTree* et,
     };
     if (!ops[1]->isValid())
     {
-        bool ok = FALSE;
+        bool ok = false;
         for (uint i = 0; i < (sizeof(stati) / sizeof(char*)); i++)
             if (ops[1]->evalAsString(et) == stati[i])
             {
-                ok = TRUE;
+                ok = true;
                 break;
             }
         if (!ok)
@@ -327,7 +322,7 @@ ExpressionTreeFunction::isTaskStatus(ExpressionTree* et,
         ops[1]->setValid();
     }
 
-    return strcmp(stati[((Task*) et->getCoreAttributes())
+    return strcmp(stati[static_cast<const Task*>(et->getCoreAttributes())
                   ->getStatus(scenario)], ops[1]->evalAsString(et)) == 0;
 }
 
@@ -347,8 +342,8 @@ ExpressionTreeFunction::startsBefore(ExpressionTree* et,
         return 0;
     }
 
-    return ((Task*) et->getCoreAttributes())->getStart(scenario) <
-        ops[1]->evalAsTime(et);
+    return static_cast<const Task*>(et->getCoreAttributes())
+        ->getStart(scenario) < ops[1]->evalAsTime(et);
 }
 
 long
@@ -367,8 +362,8 @@ ExpressionTreeFunction::startsAfter(ExpressionTree* et,
         return 0;
     }
 
-    return ((Task*) et->getCoreAttributes())->getStart(scenario) >=
-        ops[1]->evalAsTime(et);
+    return static_cast<const Task*>(et->getCoreAttributes())
+        ->getStart(scenario) >= ops[1]->evalAsTime(et);
 }
 
 long
@@ -387,8 +382,8 @@ ExpressionTreeFunction::endsBefore(ExpressionTree* et,
         return 0;
     }
 
-    return ((Task*) et->getCoreAttributes())->getEnd(scenario) <
-        ops[1]->evalAsTime(et);
+    return static_cast<const Task*>(et->getCoreAttributes())
+        ->getEnd(scenario) < ops[1]->evalAsTime(et);
 }
 
 long
@@ -407,8 +402,8 @@ ExpressionTreeFunction::endsAfter(ExpressionTree* et,
         return 0;
     }
 
-    return ((Task*) et->getCoreAttributes())->getEnd(scenario) >
-        ops[1]->evalAsTime(et);
+    return static_cast<const Task*>(et->getCoreAttributes())
+        ->getEnd(scenario) > ops[1]->evalAsTime(et);
 }
 
 long
@@ -427,7 +422,7 @@ ExpressionTreeFunction::isSubTaskOf(ExpressionTree* et,
         return 0;
     }
 
-    return p->isSubTask((Task*) et->getCoreAttributes());
+    return p->isSubTask(const_cast<Task*>(static_cast<const Task*>(et->getCoreAttributes())));
 }
 
 long
@@ -446,7 +441,8 @@ ExpressionTreeFunction::containsTask(ExpressionTree* et,
         return 0;
     }
 
-    return ((Task*) et->getCoreAttributes())->isSubTask(st);
+    return static_cast<const Task*>(et->getCoreAttributes())
+        ->isSubTask(st);
 }
 
 long
@@ -469,7 +465,7 @@ ExpressionTreeFunction::isTaskOfProject(ExpressionTree* et,
     }
 
     return ops[0]->evalAsString(et) ==
-        ((Task*) (et->getCoreAttributes()))->getProjectId();
+        static_cast<const Task*> (et->getCoreAttributes())->getProjectId();
 }
 
 long
@@ -509,9 +505,8 @@ ExpressionTreeFunction::isAllocated(ExpressionTree* et,
     if (et->getCoreAttributes()->getProject()->getEnd() < end)
         end = et->getCoreAttributes()->getProject()->getEnd();
 
-    return ((Resource*) et->getCoreAttributes())->isAllocated
-        (scenarioId, Interval(start, end),
-         QString::null);
+    return static_cast<const Resource*>(et->getCoreAttributes())
+        ->isAllocated (scenarioId, Interval(start, end), QString::null);
 }
 
 long
@@ -542,7 +537,8 @@ ExpressionTreeFunction::isDutyOf(ExpressionTree* et,
         return 0;
     }
 
-    return ((Task*) et->getCoreAttributes())->isDutyOf(scenarioId, resource);
+    return static_cast<const Task *>(et->getCoreAttributes())
+        ->isDutyOf(scenarioId, resource);
 }
 
 long
@@ -591,9 +587,8 @@ ExpressionTreeFunction::isAllocatedToProject(ExpressionTree* et,
     if (et->getCoreAttributes()->getProject()->getEnd() < end)
         end = et->getCoreAttributes()->getProject()->getEnd();
 
-    return ((Resource*) et->getCoreAttributes())->isAllocated
-        (scenarioId, Interval(start, end),
-         ops[0]->evalAsString(et));
+    return static_cast<const Resource*>(et->getCoreAttributes())
+        ->isAllocated (scenarioId, Interval(start, end), ops[0]->evalAsString(et));
 }
 
 long
@@ -614,8 +609,8 @@ ExpressionTreeFunction::isOnCriticalPath(ExpressionTree* et,
         return 0;
     }
 
-    Task* task = ((Task*) et->getCoreAttributes());
-    return task->isOnCriticalPath(scenarioId);
+    return static_cast<const Task*>(et->getCoreAttributes())
+        ->isOnCriticalPath(scenarioId);
 }
 
 long
@@ -650,8 +645,8 @@ ExpressionTreeFunction::isPlanAllocated(ExpressionTree* et,
         return 0;
     }
 
-    return ((Resource*) et->getCoreAttributes())->isAllocated
-        (scenarioId, Interval(start, end),
+    return static_cast<const Resource*>(et->getCoreAttributes())
+        ->isAllocated (scenarioId, Interval(start, end),
          ops[0]->evalAsString(et));
 }
 
@@ -685,8 +680,8 @@ ExpressionTreeFunction::isActualAllocated(ExpressionTree* et,
         return 0;
     }
 
-    return ((Resource*) et->getCoreAttributes())->isAllocated
-        (scenarioId, Interval(start, end),
+    return static_cast<const Resource*>(et->getCoreAttributes())
+        ->isAllocated (scenarioId, Interval(start, end),
          ops[0]->evalAsString(et));
 }
 
