@@ -8,65 +8,59 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: FileInfo.cpp 1309 2006-07-19 18:04:38Z cs $
+ * $Id: FileInfo.cpp 1494 2007-06-07 12:00:27Z cs $
  */
 
+#include "FileInfo.h"
+
 #include <ctype.h>
 #include <stdlib.h>
 
 #include "TjMessageHandler.h"
 #include "tjlib-internal.h"
-#include "FileInfo.h"
 #include "ProjectFile.h"
 #include "debug.h"
 
-FileInfo::FileInfo(ProjectFile* p, const QString& file_, const QString& tp)
-    : pf(p), taskPrefix(tp)
-{
-    tokenTypeBuf = INVALID;
-    file = file_;
-}
-
-FileInfo::~FileInfo()
-{
-    delete f;
-}
+FileInfo::FileInfo(ProjectFile* p, const QString& file, const QString& tp) :
+    FileToken(file, tp),
+    pf(p),
+    oldLineBuf(),
+    oldLine(0)
+{ }
 
 bool
 FileInfo::open()
 {
-    if (file.right(2) == "/.")
+    if (m_file.right(2) == "/.")
     {
-        f = new QTextStream(stdin, IO_ReadOnly);
-        fh = stdin;
+        m_f.reset(new QTextStream(stdin, IO_ReadOnly));
+        m_fh = stdin;
     }
     else
     {
-        if ((fh = fopen(file, "r")) == 0)
-            return FALSE;
-        f = new QTextStream(fh, IO_ReadOnly);
+        if ((m_fh = fopen(m_file, "r")) == 0)
+            return false;
+        m_f.reset(new QTextStream(m_fh, IO_ReadOnly));
     }
 
     if (DEBUGLEVEL > 0)
-        qWarning(i18n("Processing file \'%1\'").arg(file));
+        tjWarning(i18n("Processing file \'%1\'").arg(m_file));
 
-    lineBuf = oldLineBuf = QString::null;
-    currLine = oldLine = 1;
-    return TRUE;
+    m_lineBuf = oldLineBuf = QString::null;
+    m_currLine = oldLine = 1;
+    return true;
 }
 
 bool
 FileInfo::close()
 {
-    delete f;
-    f = 0;
-    if (fh == stdin)
-        return TRUE;
+    if (m_fh == stdin)
+        return true;
 
-    if (fclose(fh) == EOF)
-        return FALSE;
+    if (fclose(m_fh) == EOF)
+        return false;
 
-    return TRUE;
+    return true;
 }
 
 QChar
@@ -74,24 +68,24 @@ FileInfo::getC(bool expandMacros)
 {
  BEGIN:
     QChar c;
-    if (ungetBuf.isEmpty())
+    if (m_ungetBuf.isEmpty())
     {
-        if (feof(fh))
+        if (feof(m_fh))
             c = QChar(EOFile);
         else
         {
-            *f >> c;
+            *m_f >> c;
             if (c == QChar('\r'))
             {
-                if (!feof(fh))
+                if (!feof(m_fh))
                 {
                     // Test for CR/LF Windows line breaks.
                     QChar cb;
-                    *f >> cb;
+                    *m_f >> cb;
                     if (cb != QChar('\n'))
                     {
                         // Probably a MacOS LF only line break
-                        ungetBuf.append(cb);
+                        m_ungetBuf.append(cb);
                     }
                 }
                 c = QChar('\n');
@@ -100,42 +94,42 @@ FileInfo::getC(bool expandMacros)
     }
     else
     {
-        c = ungetBuf.last();
-        ungetBuf.pop_back();
+        c = m_ungetBuf.last();
+        m_ungetBuf.pop_back();
         if (c.unicode() == EOMacro)
         {
-            macroStack.removeLast();
+            m_macroStack.removeLast();
             goto BEGIN;
         }
     }
-    oldLineBuf = lineBuf;
-    lineBuf += c;
+    oldLineBuf = m_lineBuf;
+    m_lineBuf += c;
 
     if (expandMacros)
     {
         if (c == '$')
         {
             QChar d;
-            if ((d = getC(FALSE)) == '{')
+            if ((d = getC(false)) == '{')
             {
-                // remove ${ from lineBuf;
-                oldLineBuf = lineBuf;
-                lineBuf = lineBuf.left(lineBuf.length() - 2);
+                // remove ${ from m_lineBuf;
+                oldLineBuf = m_lineBuf;
+                m_lineBuf = m_lineBuf.left(m_lineBuf.length() - 2);
                 readMacroCall();
                 goto BEGIN;
             }
             else if (d == '(')
             {
-                // remove $( from lineBuf;
-                oldLineBuf = lineBuf;
-                lineBuf = lineBuf.left(lineBuf.length() - 2);
+                // remove $( from m_lineBuf;
+                oldLineBuf = m_lineBuf;
+                m_lineBuf = m_lineBuf.left(m_lineBuf.length() - 2);
                 readEnvironment();
                 goto BEGIN;
             }
             else if (d == '$')
             {
                 QChar e;
-                if ((e = getC(FALSE)) == '{')
+                if ((e = getC(false)) == '{')
                 {
                     // Convert "$${" into "%{"
                     c = '%';
@@ -154,47 +148,19 @@ FileInfo::getC(bool expandMacros)
 void
 FileInfo::ungetC(QChar c)
 {
-    oldLineBuf = lineBuf;
-    lineBuf = lineBuf.left(lineBuf.length() - 1);
-    ungetBuf.append(c);
-}
-
-bool
-FileInfo::getDateFragment(QString& token, QChar& c)
-{
-    token += c;
-    c = getC();
-    // c must be a digit
-    if (!c.isDigit())
-    {
-        errorMessage(i18n("Corrupted date"));
-        return FALSE;
-    }
-    token += c;
-    // read other digits
-    while ((c = getC()).unicode() != EOFile && c.isDigit())
-        token += c;
-
-    return TRUE;
-}
-
-QString
-FileInfo::getPath() const
-{
-    if (file.find('/') >= 0)
-        return file.left(file.findRev('/') + 1);
-    else
-        return "";
+    oldLineBuf = m_lineBuf;
+    m_lineBuf = m_lineBuf.left(m_lineBuf.length() - 1);
+    m_ungetBuf.append(c);
 }
 
 TokenType
 FileInfo::nextToken(QString& token)
 {
-    if (tokenTypeBuf != INVALID)
+    if (m_tokenTypeBuf != INVALID)
     {
-        token = tokenBuf;
-        TokenType tt = tokenTypeBuf;
-        tokenTypeBuf = INVALID;
+        token = m_tokenBuf;
+        TokenType tt = m_tokenTypeBuf;
+        m_tokenTypeBuf = INVALID;
         return tt;
     }
 
@@ -214,21 +180,21 @@ FileInfo::nextToken(QString& token)
         case '/':
             /* This code skips c-style comments like the one you are just
              * reading. */
-            if ((c = getC(FALSE)) == '*')
+            if ((c = getC(false)) == '*')
             {
                 do
                 {
                     if (c == '\n')
                     {
-                        oldLine = currLine;
-                        currLine++;
+                        oldLine = m_currLine;
+                        m_currLine++;
                     }
-                    while ((c = getC(FALSE)) != '*')
+                    while ((c = getC(false)) != '*')
                     {
                         if (c == '\n')
                         {
-                            oldLine = currLine;
-                            currLine++;
+                            oldLine = m_currLine;
+                            m_currLine++;
                         }
                         else if (c.unicode() == EOFile)
                         {
@@ -236,30 +202,33 @@ FileInfo::nextToken(QString& token)
                             return EndOfFile;
                         }
                     }
-                } while ((c = getC(FALSE)) != '/');
+                } while ((c = getC(false)) != '/');
+                break;
             }
-            else
+            // This code skips C++-style comments like the one you are
+            // reading here.
+            else if (c != '/')
             {
                 ungetC(c);
                 ungetC('/');
                 goto BLANKS_DONE;
             }
-            break;
+            // break missing on purpose
         case '#':   // Comments start with '#' and reach towards end of line
-            while ((c = getC(FALSE)) != '\n' && c.unicode() != EOFile)
+            while ((c = getC(false)) != '\n' && c.unicode() != EOFile)
                 ;
             if (c.unicode() == EOFile)
                 return EndOfFile;
             // break missing on purpose
         case '\n':
             // Increase line counter only when not replaying a macro.
-            if (macroStack.isEmpty())
+            if (m_macroStack.isEmpty())
             {
-                oldLine = currLine;
-                currLine++;
+                oldLine = m_currLine;
+                m_currLine++;
             }
-            oldLineBuf = lineBuf;
-            lineBuf = "";
+            oldLineBuf = m_lineBuf;
+            m_lineBuf = "";
             break;
         default:
             ungetC(c);
@@ -372,10 +341,10 @@ FileInfo::nextToken(QString& token)
             while ((c = getC()).unicode() != EOFile &&
                    (escape || (c != delimiter)))
             {
-                if ((c == '\n') && macroStack.isEmpty())
+                if ((c == '\n') && m_macroStack.isEmpty())
                 {
-                    oldLine = currLine;
-                    currLine++;
+                    oldLine = m_currLine;
+                    m_currLine++;
                 }
                 if (c == '\\' && !escape)
                     escape = true;
@@ -396,7 +365,7 @@ FileInfo::nextToken(QString& token)
         {
             token = "";
             int nesting = 0;
-            while ((c = getC(FALSE)).unicode() != EOFile &&
+            while ((c = getC(false)).unicode() != EOFile &&
                    (c != ']' || nesting > 0))
             {
                 if (c == '[')
@@ -405,8 +374,8 @@ FileInfo::nextToken(QString& token)
                     nesting--;
                 if (c == '\n')
                 {
-                    oldLine = currLine;
-                    currLine++;			// macroStack.isEmpty ??
+                    oldLine = m_currLine;
+                    m_currLine++; // m_macroStack.isEmpty ??
                 }
                 token += c;
             }
@@ -478,143 +447,19 @@ FileInfo::nextToken(QString& token)
     }
 }
 
-bool
-FileInfo::readMacroCall()
-{
-    QString id;
-    TokenType tt;
-    /* For error reporting we need to replace the macro call with the macro
-     * text. So we save a copy of the current line buf (the ${ has already
-     * been removed) and copy it over the lineBuf again after we have read the
-     * complete macro call. */
-    QString lineBufCopy = lineBuf;
-    QString prefix;
-    if ((tt = nextToken(id)) == QUESTIONMARK)
-    {
-        prefix = "?";
-    }
-    else
-        returnToken(tt, id);
-
-    if ((tt = nextToken(id)) != ID && tt != INTEGER)
-    {
-        errorMessage(i18n("Macro ID expected"));
-        return FALSE;
-    }
-    id = prefix + id;
-
-    QString token;
-    // Store all arguments in a newly created string list.
-    QStringList* sl = new QStringList;
-    sl->append(id);
-    while ((tt = nextToken(token)) == STRING || tt == ID)
-        sl->append(token);
-    if (tt != RBRACE)
-    {
-        delete sl;
-        errorMessage(i18n("'}' expected"));
-        return FALSE;
-    }
-
-    // expand the macro
-    pf->getMacros().setLocation(file, currLine);
-    QString macro = pf->getMacros().resolve(sl);
-    delete sl;
-
-    if (macro.isNull() && prefix.isEmpty())
-        return FALSE;
-
-    lineBuf = lineBufCopy;
-
-    // Push pointer to macro on stack. Needed for error handling.
-    macroStack.append(pf->getMacros().getMacro(id));
-
-    // mark end of macro
-    ungetBuf.append(QChar(EOMacro));
-    // push expanded macro reverse into ungetC buffer.
-    for (int i = macro.length() - 1; i >= 0; --i)
-        ungetBuf.append(macro[i].latin1());
-    return TRUE;
-}
-
-bool
-FileInfo::readEnvironment()
-{
-    QString id;
-
-    if (nextToken(id) != ID)
-    {
-        errorMessage(i18n("Environment name expected"));
-        return FALSE;
-    }
-
-    QString token;
-    if (nextToken(token) != RBRACKET)
-    {
-        errorMessage(i18n("')' expected"));
-        return FALSE;
-    }
-
-    char *value = getenv (id.ascii());
-
-    if (value != 0)
-    {
-        id = value;
-    }
-    else
-    {
-        id = "";
-    }
-
-    // push expanded macro reverse into ungetC buffer.
-    for (int i = id.length() - 1; i >= 0; --i)
-        ungetBuf.append(id[i].latin1());
-
-    return TRUE;
-}
-
 void
-FileInfo::returnToken(TokenType tt, const QString& buf)
+FileInfo::errorMessage(const QString& msg)
 {
-    if (tokenTypeBuf != INVALID)
+    if (m_macroStack.isEmpty())
     {
-        qFatal("Internal Error: Token buffer overflow!");
-        return;
-    }
-    tokenTypeBuf = tt;
-    tokenBuf = buf;
-}
-
-QString
-FileInfo::cleanupLine(const QString& line)
-{
-    QString res;
-    for (uint i = 0; i < line.length(); ++i)
-        if (line[i] != QChar(EOMacro))
-            res += line[i];
-
-    return res;
-}
-
-void
-FileInfo::errorMessage(const char* msg, ...)
-{
-    va_list ap;
-    char buf[1024];
-    va_start(ap, msg);
-    vsnprintf(buf, 1024, msg, ap);
-    va_end(ap);
-
-    if (macroStack.isEmpty())
-    {
-        if (tokenTypeBuf == INVALID)
-            TJMH.errorMessage(QString("%1\n%2").arg(buf)
-                              .arg(cleanupLine(lineBuf)),
-                              file, currLine);
+        if (m_tokenTypeBuf == INVALID)
+            TJMH.errorMessage(QString("%1\n%2").arg(msg)
+                              .arg(cleanupLine(m_lineBuf)),
+                              m_file, m_currLine);
         else
-            TJMH.errorMessage(QString("%1\n%2").arg(buf)
+            TJMH.errorMessage(QString("%1\n%2").arg(msg)
                               .arg(cleanupLine(oldLineBuf)),
-                              file, oldLine);
+                              m_file, oldLine);
     }
     else
     {
@@ -622,7 +467,7 @@ FileInfo::errorMessage(const char* msg, ...)
         int i = 0;
         QString file;
         int line = 0;
-        for (QPtrListIterator<Macro> mli(macroStack); *mli; ++mli, ++i)
+        for (QPtrListIterator<Macro> mli(m_macroStack); *mli; ++mli, ++i)
         {
             stackDump += "\n  ${" + (*mli)->getName() + " ... }";
 
@@ -631,18 +476,56 @@ FileInfo::errorMessage(const char* msg, ...)
         }
         TJMH.errorMessage(i18n("Error in expanded macro\n%1\n%2"
                                "\nThis is the macro call stack:%3").
-                          arg(buf).arg(cleanupLine(lineBuf)).arg(stackDump),
+                          arg(msg).arg(cleanupLine(m_lineBuf)).arg(stackDump),
                           file, line);
     }
 }
 
 void
-FileInfo::errorMessageVA(const char* msg, va_list ap)
+FileInfo::warningMessage(const QString& msg)
 {
-    char buf[1024];
-    vsnprintf(buf, 1024, msg, ap);
+    if (m_macroStack.isEmpty())
+    {
+        if (m_tokenTypeBuf == INVALID)
+            TJMH.warningMessage(QString("%1\n%2").arg(msg)
+                                .arg(cleanupLine(m_lineBuf)),
+                                m_file, m_currLine);
+        else
+            TJMH.warningMessage(QString("%1\n%2").arg(msg)
+                                .arg(cleanupLine(oldLineBuf)),
+                                m_file, oldLine);
+    }
+    else
+    {
+        QString stackDump;
+        int i = 0;
+        QString file;
+        int line = 0;
+        for (QPtrListIterator<Macro> mli(m_macroStack); *mli; ++mli, ++i)
+        {
+            stackDump += "\n  ${" + (*mli)->getName() + " ... }";
 
-    errorMessage("%s", buf);
+            file = (*mli)->getFile();
+            line = (*mli)->getLine();
+        }
+        TJMH.warningMessage(i18n("Warning in expanded macro\n%1\n%2"
+                                 "\nThis is the macro call stack:%3").
+                            arg(msg).arg(cleanupLine(m_lineBuf)).arg(stackDump),
+                            file, line);
+    }
 }
 
+void FileInfo::setLocation(const QString& df, int dl)
+{
+    pf->getMacros().setLocation(df, dl);
+}
 
+QString FileInfo::resolve(const QStringList* argList)
+{
+    return pf->getMacros().resolve(argList);
+}
+
+Macro* FileInfo::getMacro(const QString& name) const
+{
+    return pf->getMacros().getMacro(name);
+}
