@@ -7,36 +7,34 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: HTMLAccountReport.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: HTMLAccountReport.h 1454 2007-03-23 10:20:38Z cs $
  */
 
 #ifndef _HTMLAccountReport_h_
 #define _HTMLAccountReport_h_
 
-#include "HTMLReport.h"
-
-class Project;
-class HTMLAccountReportElement;
+#include "HTMLSingleReport.h"
+#include "HTMLAccountReportElement.h"
+#include "tjlib-internal.h"
 
 /**
  * @short Stores all information about an HTML account report.
  * @author Chris Schlaeger <cs@kde.org>
  */
-class HTMLAccountReport : public HTMLReport
+class HTMLAccountReport : public HTMLSingleReport
 {
 public:
-    HTMLAccountReport(Project* p, const QString& f, const QString& df, int dl);
-    virtual ~HTMLAccountReport();
+    HTMLAccountReport(Project* p, const QString& f, const QString& df, int dl) :
+        HTMLSingleReport(p, f, df, dl)
+    {
+        setTable(new HTMLAccountReportElement(this, df, dl));
+    }
+
+    virtual ~HTMLAccountReport()
+    { }
 
     virtual const char* getType() const { return "HTMLAccountReport"; }
-
-    bool generate();
-    HTMLAccountReportElement* getTable() { return tab; }
-
-private:
-    HTMLAccountReport() { } // Don't use this.
-
-    HTMLAccountReportElement* tab;
-} ;
+    virtual QString getTitle() const { return i18n("Account Report"); }
+};
 
 #endif
