@@ -7,17 +7,14 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: HTMLAccountReportElement.cpp 1259 2006-01-31 12:04:00Z cs $
+ * $Id: HTMLAccountReportElement.cpp 1497 2007-06-13 07:54:55Z cs $
  */
 
 #include "HTMLAccountReportElement.h"
-#include "TableColumnInfo.h"
 #include "TableLineInfo.h"
 #include "tjlib-internal.h"
 #include "Project.h"
-#include "Report.h"
 #include "Account.h"
-#include "AccountList.h"
 
 HTMLAccountReportElement::HTMLAccountReportElement(Report* r,
                                                    const QString& df,
@@ -33,10 +30,6 @@ HTMLAccountReportElement::HTMLAccountReportElement(Report* r,
     accountSortCriteria[1] = CoreAttributesList::NameUp;
 }
 
-HTMLAccountReportElement::~HTMLAccountReportElement()
-{
-}
-
 bool
 HTMLAccountReportElement::generate()
 {
@@ -49,12 +42,12 @@ HTMLAccountReportElement::generate()
     AccountList filteredList;
     if (!filterAccountList(filteredList, AllAccounts, hideAccount,
                            rollUpAccount))
-        return FALSE;
+        return false;
     maxDepthAccountList = filteredList.maxDepth();
 
     /* Generate table of cost accounts. */
     if (!filterAccountList(filteredList, Cost, hideAccount, rollUpAccount))
-        return FALSE;
+        return false;
     sortAccountList(filteredList);
     maxDepthAccountList = filteredList.maxDepth();
 
@@ -74,7 +67,7 @@ HTMLAccountReportElement::generate()
     }
 
     /* Generate summary line for cost accounts. */
-    tli.boldText = TRUE;
+    tli.boldText = true;
     tli.specialName = i18n("Total Costs");
     for (uint sc = 0; sc < scenarios.count(); ++sc)
     {
@@ -87,17 +80,17 @@ HTMLAccountReportElement::generate()
 
     for (QPtrListIterator<TableColumnInfo> ci(columns); *ci != 0; ++ci)
     {
-        (*ci)->addSumToMemory(TRUE);
+        (*ci)->addSumToMemory(true);
         (*ci)->clearSum();
     }
 
     /* Generate table of revenue accounts. */
     if (!filterAccountList(filteredList, Revenue, hideAccount, rollUpAccount))
-        return FALSE;
+        return false;
     sortAccountList(filteredList);
     maxDepthAccountList = filteredList.maxDepth();
 
-    tli.boldText = FALSE;
+    tli.boldText = false;
     tli.specialName = QString::null;
     for (AccountListIterator ali(filteredList); *ali != 0; ++ali, ++aNo)
     {
@@ -113,7 +106,7 @@ HTMLAccountReportElement::generate()
     }
 
     /* Generate summary line for revenue accounts. */
-    tli.boldText = TRUE;
+    tli.boldText = true;
     tli.specialName = i18n("Total Revenues");
     for (uint sc = 0; sc < scenarios.count(); ++sc)
     {
@@ -126,7 +119,7 @@ HTMLAccountReportElement::generate()
 
     for (QPtrListIterator<TableColumnInfo> ci(columns); *ci != 0; ++ci)
     {
-        (*ci)->addSumToMemory(FALSE);
+        (*ci)->addSumToMemory(false);
         (*ci)->recallMemory();
     }
 
@@ -144,6 +137,6 @@ HTMLAccountReportElement::generate()
     s() << "</tbody>" << endl;
     s() << "</table>" << endl;
 
-    return TRUE;
+    return true;
 }
 
