@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: HTMLAccountReportElement.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: HTMLAccountReportElement.h 1428 2007-03-17 15:24:21Z cs $
  */
 #ifndef _HTMLAccountReportElement_h_
 #define _HTMLAccountReportElement_h_
@@ -18,12 +18,9 @@ class HTMLAccountReportElement : public HTMLReportElement
 {
 public:
     HTMLAccountReportElement(Report* r, const QString& df, int dl);
-    ~HTMLAccountReportElement();
+    ~HTMLAccountReportElement() { }
 
     bool generate();
-
-private:
-    HTMLAccountReportElement() { }
 } ;
 
 #endif
