@@ -7,24 +7,24 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: HTMLPrimitives.cpp 1259 2006-01-31 12:04:00Z cs $
+ * $Id: HTMLPrimitives.cpp 1428 2007-03-17 15:24:21Z cs $
  */
 
 /* The following encoding table was copied from the Qt library sources since
  * this information is not available over the public API. */
 
+#include "HTMLPrimitives.h"
+
 #include <ctype.h>
 
 #include <qcstring.h>
 #include <qmap.h>
 
-#include "HTMLPrimitives.h"
-
 QString
 HTMLPrimitives::htmlFilter(const QString& s) const
 {
     QString out;
-    bool parTags = FALSE;
+    bool parTags = false;
     for (uint i = 0; i < s.length(); i++)
     {
         QString repl;
@@ -57,7 +57,7 @@ HTMLPrimitives::htmlFilter(const QString& s) const
         {
             // Expand double line breaks to HTML paragraphs.
             repl = "</p><p>";
-            parTags = TRUE;
+            parTags = true;
             i++;
         }
         else if(s[i].row() != 0 || s[i].cell() >= 128)
