@@ -7,17 +7,12 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: HTMLReport.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: HTMLReport.h 1452 2007-03-23 09:34:36Z cs $
  */
 
 #ifndef _HTMLReport_h_
 #define _HTMLReport_h_
 
-#include <stdio.h>
-#include <time.h>
-
-#include <qstring.h>
-
 #include "Report.h"
 #include "HTMLPrimitives.h"
 
@@ -35,8 +30,9 @@ public:
     virtual ~HTMLReport() { }
 
     virtual const char* getType() const { return "HTMLReport"; }
+    virtual QString getTitle() const = 0;
 
-    void generateHeader(const QString& title);
+    void generateHeader();
     void generateFooter();
 
     void setRawStyleSheet(const QString& ss)
@@ -56,8 +52,6 @@ public:
     }
 
 protected:
-    HTMLReport() { }
-
     QString rawStyleSheet;
     QString rawHead;
     QString rawTail;
