@@ -7,36 +7,34 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: HTMLResourceReport.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: HTMLResourceReport.h 1454 2007-03-23 10:20:38Z cs $
  */
 
 #ifndef _HTMLResourceReport_h_
 #define _HTMLResourceReport_h_
 
-#include "HTMLReport.h"
-
-class Project;
-class HTMLResourceReportElement;
+#include "HTMLSingleReport.h"
+#include "HTMLResourceReportElement.h"
+#include "tjlib-internal.h"
 
 /**
  * @short Stores all information about an HTML resource report.
  * @author Chris Schlaeger <cs@kde.org>
  */
-class HTMLResourceReport : public HTMLReport
+class HTMLResourceReport : public HTMLSingleReport
 {
 public:
-    HTMLResourceReport(Project* p, const QString& f, const QString& df, int dl);
-    virtual ~HTMLResourceReport() { }
+    HTMLResourceReport(Project* p, const QString& f, const QString& df, int dl) :
+	    HTMLSingleReport(p, f, df, dl)
+    {
+	    setTable(new HTMLResourceReportElement(this, df, dl));
+    }
+
+    virtual ~HTMLResourceReport()
+    { }
 
     virtual const char* getType() const { return "HTMLResourceReport"; }
-
-    bool generate();
-    HTMLResourceReportElement* getTable() { return tab; }
-
-private:
-    HTMLResourceReport() { }
-
-    HTMLResourceReportElement* tab;
-} ;
+    virtual QString getTitle() const { return i18n("Resource Report"); }
+};
 
 #endif
