@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: HTMLResourceReportElement.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: HTMLResourceReportElement.h 1428 2007-03-17 15:24:21Z cs $
  */
 
 #ifndef _HTMLResourceReportElement_h_
@@ -22,8 +22,6 @@ public:
     ~HTMLResourceReportElement();
 
     bool generate();
-private:
-    HTMLResourceReportElement() { }
 } ;
 
 #endif
