@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: HTMLStatusReport.cpp 1259 2006-01-31 12:04:00Z cs $
+ * $Id: HTMLStatusReport.cpp 1497 2007-06-13 07:54:55Z cs $
  */
 
 #include "HTMLStatusReport.h"
@@ -15,15 +15,12 @@
 #include "Operation.h"
 #include "Project.h"
 #include "Resource.h"
-#include "Utility.h"
-#include "HTMLReportElement.h"
 #include "HTMLTaskReportElement.h"
-#include "TableColumnInfo.h"
-#include "tjlib-internal.h"
 
 HTMLStatusReport::HTMLStatusReport(Project* p, const QString& f,
                                    const QString& df, int dl) :
-    HTMLReport(p, f, df, dl)
+    HTMLReport(p, f, df, dl),
+    tables( 4 )
 {
     // By default this is a weekly status report.
     end = project->getNow();
@@ -37,8 +34,9 @@ HTMLStatusReport::HTMLStatusReport(Project* p, const QString& f,
     taskSortCriteria[2] = CoreAttributesList::EndDown;
     setHideResource(new ExpressionTree(new Operation(1)));
 
-    for (int i = 0; i < tablesCount; ++i)
-        tables[i] = new HTMLTaskReportElement(this, df, dl);
+    tables.setAutoDelete( true );
+    for (uint i = 0; i < tables.size(); ++i)
+        tables.insert(i, new HTMLTaskReportElement(this, df, dl));
 
     QString scenarioName = project->getScenarioId(0);
     /* Create table that contains the tasks that should be finished, but
@@ -115,15 +113,11 @@ HTMLStatusReport::HTMLStatusReport(Project* p, const QString& f,
 
 HTMLStatusReport::~HTMLStatusReport()
 {
-    for (int i = 0; i < tablesCount; i++)
-        delete tables[i];
 }
 
 void HTMLStatusReport::setTable(int tabIdx, HTMLReportElement* tab)
 {
-    if (tables[tabIdx] && tables[tabIdx] != tab)
-        delete tables[tabIdx];
-    tables[tabIdx] = tab;
+    tables.insert(tabIdx, tab);
 }
 
 HTMLReportElement*
@@ -136,23 +130,24 @@ bool
 HTMLStatusReport::generate()
 {
     if (!open())
-        return FALSE;
+        return false;
 
     if (headline.isEmpty())
         headline = i18n("Status report for the period %1 to %2")
             .arg(time2user(start, timeFormat)).arg(time2user(end, timeFormat));
 
-    generateHeader(i18n("Status Report"));
+    generateHeader();
 
-    for (int i = 0; i < tablesCount; ++i)
+    bool ok = true;
+    for (uint i = 0; i < tables.size(); ++i)
     {
-        tables[i]->generate();
+        if (!tables[i]->generate())
+            ok = false;
         s << "<br/>" << endl;
     }
 
     generateFooter();
 
-    f.close();
-    return TRUE;
+    return close() && ok;
 }
 
