@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: HTMLStatusReport.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: HTMLStatusReport.h 1452 2007-03-23 09:34:36Z cs $
  */
 
 #ifndef _HTMLStatusReport_h_
@@ -15,6 +15,10 @@
 
 #include "HTMLReport.h"
 
+#include "tjlib-internal.h"
+
+#include <qptrvector.h>
+
 class Project;
 class TaskList;
 class HTMLReportElement;
@@ -30,6 +34,7 @@ public:
     virtual ~HTMLStatusReport();
 
     virtual const char* getType() const { return "HTMLStatusReport"; }
+    virtual QString getTitle() const { return i18n("Status Report"); }
 
     void setTable(int tabIdx, HTMLReportElement* tab);
     HTMLReportElement* getTable(int tabIdx) const;
@@ -37,10 +42,7 @@ public:
     bool generate();
 
 private:
-    HTMLStatusReport() { }  // don't call this directly
-
-    static const int tablesCount = 4;
-    HTMLReportElement* tables[tablesCount];
+    QPtrVector< HTMLReportElement > tables;
 } ;
 
 #endif
