@@ -7,36 +7,34 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: HTMLTaskReport.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: HTMLTaskReport.h 1454 2007-03-23 10:20:38Z cs $
  */
 
 #ifndef _HTMLTaskReport_h_
 #define _HTMLTaskReport_h_
 
-#include "HTMLReport.h"
-
-class Project;
-class HTMLTaskReportElement;
+#include "HTMLSingleReport.h"
+#include "HTMLTaskReportElement.h"
+#include "tjlib-internal.h"
 
 /**
  * @short Stores all information about an HTML task report.
  * @author Chris Schlaeger <cs@kde.org>
  */
-class HTMLTaskReport : public HTMLReport
+class HTMLTaskReport : public HTMLSingleReport
 {
 public:
-    HTMLTaskReport(Project* p, const QString& f, const QString& df, int dl);
-    virtual ~HTMLTaskReport();
+    HTMLTaskReport(Project* p, const QString& f, const QString& df, int dl) :
+	    HTMLSingleReport(p, f, df, dl)
+    {
+	    setTable(new HTMLTaskReportElement(this, df, dl));
+    }
+
+    virtual ~HTMLTaskReport()
+    { }
 
     virtual const char* getType() const { return "HTMLTaskReport"; }
-
-    bool generate();
-    HTMLTaskReportElement* getTable() { return tab; }
-
-private:
-    HTMLTaskReport() { }
-
-    HTMLTaskReportElement* tab;
-} ;
+    virtual QString getTitle() const { return i18n("Task Report"); }
+};
 
 #endif
