@@ -7,30 +7,25 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: HTMLWeeklyCalendarElement.cpp 1373 2007-01-25 15:13:13Z cs $
+ * $Id: HTMLWeeklyCalendarElement.cpp 1497 2007-06-13 07:54:55Z cs $
  */
 
 #include "HTMLWeeklyCalendarElement.h"
 #include "tjlib-internal.h"
 #include "Project.h"
-#include "Report.h"
 #include "ExpressionTree.h"
 #include "Operation.h"
-#include "CoreAttributesList.h"
-#include "Task.h"
-#include "TaskList.h"
 #include "Resource.h"
-#include "ResourceList.h"
-#include "Utility.h"
-#include "Interval.h"
-#include "TableColumnInfo.h"
 #include "TableLineInfo.h"
 #include "HTMLReport.h"
 
 HTMLWeeklyCalendarElement::HTMLWeeklyCalendarElement(Report* r,
                                                      const QString& df,
                                                      int dl) :
-    HTMLReportElement(r, df, dl)
+    HTMLReportElement(r, df, dl),
+    daysToShow(),
+    numberOfDays(7),
+    taskReport(true)
 {
     uint sc = r->getProject()->getMaxScenarios();
     columns.append(new TableColumnInfo(sc, "name"));
@@ -51,8 +46,6 @@ HTMLWeeklyCalendarElement::HTMLWeeklyCalendarElement(Report* r,
     daysToShow.resize(7);
     for (unsigned int i = 0; i < 7; ++i)
         daysToShow.setBit(i);
-    numberOfDays = 7;
-    taskReport = true;
 }
 
 HTMLWeeklyCalendarElement::~HTMLWeeklyCalendarElement()
@@ -141,13 +134,13 @@ HTMLWeeklyCalendarElement::generateWeekHeader(bool weekStartsMonday,
         if (mAY != lastMAY)
         {
             s() << "     <td style=\"font-size:90%\">"
-                << monthAndYear(wd) << "</td>" << endl;
+                << htmlFilter(mAY) << "</td>" << endl;
             lastMAY = mAY;
         }
         s() << "    </tr>" << endl;
         if (report->getProject()->isVacation(wd))
             s() << "    <tr><td colspan=\"2\" style=\"font-size:80%\">"
-                << report->getProject()->vacationName(wd)
+                << htmlFilter(report->getProject()->vacationName(wd))
                 << "</td></tr>" << endl;
         s() << "   </table></td>" << endl;
     }
@@ -179,31 +172,31 @@ HTMLWeeklyCalendarElement::generateTaksPerDay(
 
         s() << "   <td width=\"" << cellWidth
             << "\" style=\"vertical-align:top\">" << endl;
-        bool first = TRUE;
+        bool first = true;
         int no = 1;
         for (TaskListIterator tli(filteredTaskList); *tli != 0;
              ++tli, ++no)
         {
             if ((*tli)->getLoad(scenarios[0], Interval(start, end)) == 0.0)
                 continue;
-            if ((*tli)->isActive(scenarios[0],
-                                 Interval(wd, sameTimeNextDay(wd))))
+            if (!(*tli)->isActive(scenarios[0],
+                                  Interval(wd, sameTimeNextDay(wd))))
+                continue;
+
+            if (first)
             {
-                if (first)
-                {
-                    s() << "     <table width=\"100%\">" << endl;
-                    first = FALSE;
-                }
-                TableLineInfo tli1;
-                tli1.ca1 = tli1.task = *tli;
-                tli1.idxNo = no;
-                tli1.fontFactor = 40;
-                generateLine(&tli1, 2);
+                s() << "     <table width=\"100%\">" << endl;
+                first = false;
             }
+            TableLineInfo tli1;
+            tli1.ca1 = tli1.task = *tli;
+            tli1.idxNo = no;
+            tli1.fontFactor = 40;
+            generateLine(&tli1, 2);
 
             if (!filterResourceList(filteredResourceList, *tli,
                                     getHideResource(), getRollUpResource()))
-                return FALSE;
+                return false;
             sortResourceList(filteredResourceList);
             int rNo = 1;
             for (ResourceListIterator rli(filteredResourceList); *rli != 0;
@@ -258,35 +251,34 @@ HTMLWeeklyCalendarElement::generateResourcesPerDay
         s() << "   <td width=\"" << cellWidth
             << "\" style=\"vertical-align:top\">"
             << endl;
-        bool first = TRUE;
+        bool first = true;
         int no = 1;
         for (ResourceListIterator rli(filteredResourceList);
              *rli != 0; ++rli, ++no)
         {
-            if ((*rli)->getLoad(scenarios[0],
-                                Interval(wd,
-                                         sameTimeNextDay(wd))) > 0.0)
+            if ((*rli)->getEffectiveLoad
+                (scenarios[0], Interval(wd, sameTimeNextDay(wd))) <= 0.0)
+                continue;
+
+            if (first)
             {
-                if (first)
-                {
-                    s() << "     <table width=\"100%\">" << endl;
-                    first = FALSE;
-                }
-                TableLineInfo tli2;
-                tli2.ca1 = tli2.resource = *rli;
-                tli2.idxNo = no;
-                tli2.fontFactor = 40;
-                generateLine(&tli2, 4);
+                s() << "     <table width=\"100%\">" << endl;
+                first = false;
             }
+            TableLineInfo tli2;
+            tli2.ca1 = tli2.resource = *rli;
+            tli2.idxNo = no;
+            tli2.fontFactor = 40;
+            generateLine(&tli2, 4);
 
             /* We only want to show the nested task list for leaf resources.
              * Leaf in this case means "task has no visible childs". */
-            bool hasVisibleChilds = FALSE;
+            bool hasVisibleChilds = false;
             for (ResourceListIterator cli((*rli)->getSubListIterator());
                  *cli; ++cli)
                 if (filteredResourceList.findRef(*cli) >= 0)
                 {
-                    hasVisibleChilds = TRUE;
+                    hasVisibleChilds = true;
                     break;
                 }
 
@@ -294,7 +286,7 @@ HTMLWeeklyCalendarElement::generateResourcesPerDay
                 continue;
 
             if (!filterTaskList(filteredTaskList, *rli, hideTask, rollUpTask))
-                return FALSE;
+                return false;
             sortTaskList(filteredTaskList);
 
             int tNo = 1;
@@ -333,21 +325,21 @@ HTMLWeeklyCalendarElement::generate()
 
     TaskList filteredTaskList;
     if (!filterTaskList(filteredTaskList, 0, hideTask, rollUpTask))
-        return FALSE;
+        return false;
     sortTaskList(filteredTaskList);
     maxDepthTaskList = filteredTaskList.maxDepth();
 
     ResourceList filteredResourceList;
     if (!filterResourceList(filteredResourceList, 0, hideResource,
                             rollUpResource))
-        return FALSE;
+        return false;
     sortResourceList(filteredResourceList);
     maxDepthResourceList = filteredResourceList.maxDepth();
 
     bool weekStartsMonday = report->getProject()->getWeekStartsMonday();
     s() << "<table align=\"center\" cellpadding=\"2\" "
         << "style=\"background-color:#000000\"";
-    if (((HTMLReport*) report)->hasStyleSheet())
+    if (static_cast<HTMLReport*>(report)->hasStyleSheet())
         s() << " class=\"tj_table\"";
     s() << ">" << endl;
 
@@ -390,7 +382,7 @@ HTMLWeeklyCalendarElement::generate()
 
     generateFooter();
 
-    return TRUE;
+    return true;
 }
 
 bool
