@@ -8,14 +8,11 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: ICalReport.h 1316 2006-08-12 09:40:53Z cs $
+ * $Id: ICalReport.h 1408 2007-02-18 21:55:37Z cs $
  */
 #ifndef _ICalReport_h_
 #define _ICalReport_h_
 
-#include <time.h>
-
-#include <qstring.h>
 #include <libkcal/calendarlocal.h>
 #include <libkcal/todo.h>
 
