@@ -7,14 +7,12 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: Interval.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: Interval.h 1428 2007-03-17 15:24:21Z cs $
  */
 
 #ifndef _Interval_h_
 #define _Interval_h_
 
-#include <time.h>
-
 #include <stdio.h>
 #include "Utility.h"
 
@@ -23,7 +21,7 @@ class Interval
 public:
     Interval(time_t s, time_t e) : start(s), end(e) { }
     Interval(time_t s) : start(s), end(s) { }
-    Interval() { start = 0; end = 0; }
+    Interval() : start(0), end(0) { }
     Interval(const Interval& iv) : start(iv.start), end(iv.end) { }
     virtual ~Interval() { }
 
@@ -45,13 +43,13 @@ public:
         {
             // Intervals do not overlap.
             end = start - 1;
-            return FALSE;
+            return false;
         }
         if (start < i.start)
             start = i.start;
         if (end > i.end)
             end = i.end;
-        return TRUE;
+        return true;
     }
     bool overlaps(const Interval& i) const
     {
@@ -64,18 +62,18 @@ public:
         if (((i.end + 1) == start) && (i.start < start))
         {
             start = i.start;
-            return TRUE;
+            return true;
         }
-        return FALSE;
+        return false;
     }
     bool append(const Interval& i)
     {
         if (((end + 1) == i.start) && ((end + 1) <= i.end))
         {
             end = i.end;
-            return TRUE;
+            return true;
         }
-        return FALSE;
+        return false;
     }
     int compare(const Interval& i) const
     {
