@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: Journal.h 1214 2005-11-17 20:05:36Z cs $
+ * $Id: Journal.h 1393 2007-02-14 20:30:10Z cs $
  */
 
 #ifndef _Journal_h_
@@ -26,18 +26,12 @@ public:
     }
     ~Journal() { }
 
+    typedef QPtrListIterator<JournalEntry> Iterator;
+
 protected:
     virtual int compareItems(QPtrCollection::Item item1,
                              QPtrCollection::Item item2);
 } ;
 
-class JournalIterator : public QPtrListIterator<JournalEntry>
-{
-public:
-    JournalIterator(const Journal& j) :
-        QPtrListIterator<JournalEntry>(j) { }
-    virtual ~JournalIterator() { }
-} ;
-
 #endif
 
