@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: LoopDetectorInfo.h 1268 2006-02-19 13:35:03Z cs $
+ * $Id: LoopDetectorInfo.h 1470 2007-04-12 16:36:58Z cs $
  */
 
 #ifndef _LoopDetectorInfo_h_
@@ -26,14 +26,21 @@ class LoopDetectorInfo
 {
     friend class LDIList;
 public:
-    LoopDetectorInfo()
-    {
-        prevLDI = nextLDI = 0;
-    }
-    LoopDetectorInfo(const Task* _t, bool ae) : t(_t), atEnd(ae) { }
-    ~LoopDetectorInfo() { }
+    LoopDetectorInfo() :
+        nextLDI(0),
+        prevLDI(0),
+        t(0),
+        atEnd(false)
+    { }
 
-    enum FromWhere { fromParent, fromSub, fromPrev, fromSucc, fromOtherEnd };
+    LoopDetectorInfo(const Task* _t, bool ae) :
+        nextLDI(0),
+        prevLDI(0),
+        t(_t),
+        atEnd(ae)
+    { }
+
+    ~LoopDetectorInfo() { }
 
     bool operator==(const LoopDetectorInfo& ldi) const
     {
@@ -66,11 +73,21 @@ private:
 class LDIList
 {
 public:
-    LDIList()
+    LDIList() :
+        items(0),
+        root(0),
+        leaf(0)
+    { }
+
+    LDIList(LDIList& list) :
+        items(0),
+        root(0),
+        leaf(0)
     {
-        root = leaf = 0;
-        items = 0;
+        for (LoopDetectorInfo* p = list.root; p; p = p->nextLDI)
+            append(new LoopDetectorInfo(p->t, p->atEnd));
     }
+
     virtual ~LDIList()
     {
         for (LoopDetectorInfo* p = root; p; p = root)
