@@ -7,9 +7,11 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: MacroTable.cpp 1259 2006-01-31 12:04:00Z cs $
+ * $Id: MacroTable.cpp 1472 2007-04-19 08:47:13Z cs $
  */
 
+#include "MacroTable.h"
+
 #include <ctype.h>
 #include <stdio.h>
 #include <qregexp.h>
@@ -18,15 +20,17 @@
 #include "config.h"
 #include "TjMessageHandler.h"
 #include "tjlib-internal.h"
-#include "MacroTable.h"
 
 bool
 MacroTable::addMacro(Macro* macro)
 {
     if (macros[macro->getName()])
-        return FALSE;
+    {
+        delete macro;
+        return false;
+    }
     macros.insert(macro->getName(), macro);
-    return TRUE;
+    return true;
 }
 
 void
@@ -47,7 +51,7 @@ MacroTable::resolve(const QStringList* argList)
     }
 
     QString name = nameWithPrefix;
-    bool emptyIsLegal = FALSE;
+    bool emptyIsLegal = false;
 
     if (name[0].latin1() == '?')
     {
@@ -56,10 +60,10 @@ MacroTable::resolve(const QStringList* argList)
         name = name.mid(1);
         if (name.isEmpty())
             errorMessage(i18n("'?' must be followed by a valid macro name!"));
-        emptyIsLegal = TRUE;
+        emptyIsLegal = true;
     }
 
-    QString result;
+    QString result = QString::null;
     if (name == "if")
     {
         if (!argList || argList->count() != 3)
@@ -210,8 +214,7 @@ MacroTable::expandReportVariable(QString text, const QStringList* argList)
                 res += (*argList)[0];
             else
             {
-                QStringList sl;
-                sl.append(varName);
+                QStringList sl(varName);
                 res += resolve(&sl);
             }
         }
@@ -281,7 +284,7 @@ MacroTable::evalExpression(const QString expr) const
     {
         errorMessage
             (i18n("Garbage at end of expression"));
-        return FALSE;
+        return false;
     }
 
     if (op == "=")
@@ -311,24 +314,18 @@ MacroTable::evalExpression(const QString expr) const
     else
     {
        errorMessage(i18n("Illegal operator: %1").arg(op.latin1()));
-       return FALSE;
+       return false;
     }
 
 UNEXPEND:
     errorMessage(i18n("Unexpected end of expression: %1").arg(expr.left(i)));
-    return FALSE;
+    return false;
 }
 
 void
-MacroTable::errorMessage(const char* msg, ... ) const
+MacroTable::errorMessage(const QString& msg) const
 {
-    va_list ap;
-    va_start(ap, msg);
-    char buf[1024];
-    vsnprintf(buf, 1024, msg, ap);
-    va_end(ap);
-
-    TJMH.errorMessage(buf, defFileName, defFileLine);
+    TJMH.errorMessage(msg, defFileName, defFileLine);
 }
 
 
