@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: MacroTable.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: MacroTable.h 1472 2007-04-19 08:47:13Z cs $
  */
 
 #ifndef _MacroTable_h_
@@ -32,8 +32,6 @@ public:
     const uint getLine() const { return line; }
 
 private:
-    Macro() { } // don't use this
-
     QString name;
     QString value;
     QString file;
@@ -43,9 +41,9 @@ private:
 class MacroTable
 {
 public:
-    MacroTable()
+    MacroTable() : defFileName(), defFileLine(0), macros()
     {
-        macros.setAutoDelete(TRUE);
+        macros.setAutoDelete(true);
     }
     ~MacroTable() { }
 
@@ -73,7 +71,7 @@ public:
 
 private:
     bool evalExpression(const QString expr) const;
-    void errorMessage(const char* txt, ... ) const;
+    void errorMessage(const QString& msg) const;
 
     /* We store a file name and a line number in case we need this for
      * error reports or warnings. This is the location of the macro reference,
