@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: Operation.cpp 1259 2006-01-31 12:04:00Z cs $
+ * $Id: Operation.cpp 1428 2007-03-17 15:24:21Z cs $
  */
 
 #include "Operation.h"
@@ -15,14 +15,14 @@
 #include "Utility.h"
 #include "ExpressionFunctionTable.h"
 
-Operation::Operation(const Operation& op)
+Operation::Operation(const Operation& op) :
+    opt(op.opt),
+    value(op.value),
+    name(op.name),
+    ops(0),
+    opsCount(op.opsCount),
+    valid(false)
 {
-    opt = op.opt;
-    value = op.value;
-    name = op.name;
-    ops = 0;
-    opsCount = op.opsCount;
-    valid = FALSE;
     if (opsCount > 0)
     {
         ops = new Operation*[opsCount];
