@@ -7,15 +7,18 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: ParserElement.cpp 1259 2006-01-31 12:04:00Z cs $
+ * $Id: ParserElement.cpp 1410 2007-02-20 08:34:27Z cs $
  */
 
 #include "ParserElement.h"
 #include "ParserNode.h"
 
 ParserElement::ParserElement(const QString t, ParserFunctionPtr preF, 
-                             ParserNode* pn, ParserFunctionPtr postF)
-        : tag(t), preFunc(preF), node(0), postFunc(postF)
+                             ParserNode* pn, ParserFunctionPtr postF) :
+    tag(t),
+    preFunc(preF),
+    node(0),
+    postFunc(postF)
 {
     pn->add(this, t);
 }
