@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: ParserElement.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: ParserElement.h 1428 2007-03-17 15:24:21Z cs $
  */
 
 #ifndef _ParserElement_h_
@@ -23,8 +23,6 @@ class XMLFile;
 
 typedef bool (XMLFile::*ParserFunctionPtr)(QDomNode&, ParserTreeContext&);
 
-#include "XMLFile.h"
-
 class ParserElement
 {
 public:
@@ -41,8 +39,6 @@ public:
     const QString& getTag() const { return tag; }
 
 private:
-    ParserElement();    // Don't use!
-
     QString tag;
     /* Pointer to a function that is called before the elements of the node
      * are processed. */
