@@ -7,16 +7,17 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: ParserNode.cpp 1259 2006-01-31 12:04:00Z cs $
+ * $Id: ParserNode.cpp 1428 2007-03-17 15:24:21Z cs $
  */
 
 #include "ParserNode.h"
 #include "ParserElement.h"
 
 ParserNode::ParserNode(ParserElement* pEl) :
-    parentElement(pEl)
+    parentElement(pEl),
+    elements()
 {
-    elements.setAutoDelete(TRUE);
+    elements.setAutoDelete(true);
     if (pEl)
         pEl->setNode(this);
 }
