@@ -7,50 +7,45 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: ParserTreeContext.cpp 1259 2006-01-31 12:04:00Z cs $
+ * $Id: ParserTreeContext.cpp 1454 2007-03-23 10:20:38Z cs $
  */
 
 #include "ParserTreeContext.h"
-#include "Scenario.h"
-#include "Shift.h"
-#include "Resource.h"
-#include "Account.h"
-#include "Task.h"
 #include "VacationInterval.h"
 
 Scenario*
 ParserTreeContext::getScenario() const
 {
-    return dynamic_cast<Scenario*>(ca);
+    return static_cast<Scenario*>(ca);
 }
 
 Shift*
 ParserTreeContext::getShift() const
 {
-    return dynamic_cast<Shift*>(ca);
+    return static_cast<Shift*>(ca);
 }
 
 Resource*
 ParserTreeContext::getResource() const
 {
-    return dynamic_cast<Resource*>(ca);
+    return static_cast<Resource*>(ca);
 }
 
 Account*
 ParserTreeContext::getAccount() const
 {
-    return dynamic_cast<Account*>(ca);
+    return static_cast<Account*>(ca);
 }
 
 Task*
 ParserTreeContext::getTask() const
 {
-    return dynamic_cast<Task*>(ca);
+    return static_cast<Task*>(ca);
 }
 
 VacationInterval*
 ParserTreeContext::getVacationInterval() const
 {
-    return dynamic_cast<VacationInterval*>(interval);
+    return static_cast<VacationInterval*>(interval);
 }
 
