@@ -8,22 +8,17 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: ParserTreeContext.h 1271 2006-03-02 17:03:48Z cs $
+ * $Id: ParserTreeContext.h 1497 2007-06-13 07:54:55Z cs $
  */
 
 #ifndef _ParserTreeContext_h_
 #define _ParserTreeContext_h_
 
-#include <qptrlist.h>
-#include <qstring.h>
+#include "Scenario.h"
+#include "Resource.h"
+#include "Account.h"
 
 class CoreAttributes;
-class Scenario;
-class Shift;
-class Resource;
-class Account;
-class Task;
-class Resource;
 class TaskScenario;
 class Allocation;
 class VacationInterval;
@@ -33,28 +28,38 @@ class TaskDependency;
 class ParserTreeContext
 {
 public:
-    ParserTreeContext() { }
+    ParserTreeContext() :
+        ca(0),
+        scenarioIndex(0),
+        weekday(0),
+        allocation(0),
+        taskDependency(0),
+        interval(0),
+        workingHours(),
+        extendProperty()
+    { }
+
     ~ParserTreeContext() { }
 
     void setCoreAttributes(CoreAttributes* c) { ca = c; }
     CoreAttributes* getCoreAttributes() const { return ca; }
 
-    void setScenario(Scenario* s) { ca = (CoreAttributes*) s; }
+    void setScenario(Scenario* s) { ca = static_cast<CoreAttributes*>(s); }
     Scenario* getScenario() const;
 
     void setWeekday(int day) { weekday = day; }
     int getWeekday() const { return weekday; }
 
-    void setShift(Shift* s) { ca = (CoreAttributes*) s; }
+    void setShift(Shift* s) { ca = static_cast<CoreAttributes*>(s); }
     Shift* getShift() const;
 
-    void setResource(Resource* r) { ca = (CoreAttributes*) r; }
+    void setResource(Resource* r) { ca = static_cast<CoreAttributes*>(r); }
     Resource* getResource() const;
 
-    void setAccount(Account* a) { ca = (CoreAttributes*) a; }
+    void setAccount(Account* a) { ca = static_cast<CoreAttributes*>(a); }
     Account* getAccount() const;
 
-    void setTask(Task* t) { ca = (CoreAttributes*) t; }
+    void setTask(Task* t) { ca = static_cast<CoreAttributes*>(t); }
     Task* getTask() const;
 
     void setScenarioIndex(int i) { scenarioIndex = i; }
