@@ -8,29 +8,18 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: Project.cpp 1352 2006-11-07 08:18:12Z cs $
+ * $Id: Project.cpp 1497 2007-06-13 07:54:55Z cs $
  */
 
-#include <config.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <qdom.h>
-#include <qdict.h>
-
-#include "Interval.h"
 #include "Project.h"
-#include "debug.h"
+
+#include <stdlib.h>
+
 #include "TjMessageHandler.h"
-#include "tjlib-internal.h"
 #include "Scenario.h"
 #include "Shift.h"
 #include "Account.h"
-#include "Task.h"
 #include "Resource.h"
-#include "Utility.h"
-#include "VacationInterval.h"
-#include "Optimizer.h"
-#include "OptimizerRun.h"
 #include "HTMLTaskReport.h"
 #include "HTMLResourceReport.h"
 #include "HTMLAccountReport.h"
@@ -42,131 +31,106 @@
 #include "ExportReport.h"
 #include "ReportXML.h"
 #include "UsageLimits.h"
-#include "kotrus.h"
 #include "CustomAttributeDefinition.h"
 
 DebugController DebugCtrl;
 
-Project::Project()
+Project::Project() :
+    QObject(),
+    start(0),
+    end(0),
+    now(0),
+    allowRedefinitions(false),
+    weekStartsMonday(true),
+    name(),
+    version(),
+    copyright(),
+    customer(),
+    timeZone(),
+    timeFormat("%Y-%m-%d %H:%M"),
+    shortTimeFormat("%H:%M"),
+    currency(),
+    currencyDigits(3),
+    numberFormat("-", "", ",", ".", 1),
+    currencyFormat("(", ")", ",", ".", 0),
+    priority(500),
+    minEffort(0.0),
+    resourceLimits(0),
+    rate(0.0),
+    dailyWorkingHours(8.0),
+    yearlyWorkingDays(260.714),
+    workingHours(),
+    scheduleGranularity(ONEHOUR),
+    allowedFlags(),
+    projectIDs(),
+    currentId(),
+    maxErrors(0),
+    journal(),
+    vacationList(),
+    scenarioList(),
+    taskList(),
+    resourceList(),
+    accountList(),
+    shiftList(),
+    originalTaskList(),
+    originalResourceList(),
+    originalAccountList(),
+    taskAttributes(),
+    resourceAttributes(),
+    accountAttributes(),
+    xmlreport(0),
+    reports(),
+    interactiveReports(),
+    sourceFiles(),
+    breakFlag(false)
 {
     /* Pick some reasonable initial number since we don't know the
      * project time frame yet. */
     initUtility(20000);
 
-    vacationList.setAutoDelete(TRUE);
-    taskAttributes.setAutoDelete(TRUE);
-    resourceAttributes.setAutoDelete(TRUE);
-    reports.setAutoDelete(TRUE);
-
-    allowRedefinitions = FALSE;
-
-    currentId = QString::null;
+    vacationList.setAutoDelete(true);
+    accountAttributes.setAutoDelete(true);
+    taskAttributes.setAutoDelete(true);
+    resourceAttributes.setAutoDelete(true);
+    reports.setAutoDelete(true);
 
     new Scenario(this, "plan", "Plan", 0);
-    scenarioList.createIndex(TRUE);
-    scenarioList.createIndex(FALSE);
+    scenarioList.createIndex(true);
+    scenarioList.createIndex(false);
 
-    /* This is the version 1.0 XML reports. It should be deleted for the next
-     * major release. */
-    xmlreport = 0;
-
-    priority = 500;
-    /* The following settings are country and culture dependent. Those
-     * defaults are probably true for many Western countries, but have to be
-     * changed in project files. */
-    dailyWorkingHours = 8.0;
-    yearlyWorkingDays = 260.714;
-    scheduleGranularity = ONEHOUR;
-    weekStartsMonday = TRUE;
-    timeFormat = "%Y-%m-%d %H:%M";
-    shortTimeFormat = "%H:%M";
-    numberFormat = RealFormat("-", "", ",", ".", 1);
-    currencyFormat = RealFormat("(", ")", ",", ".", 0);
-
-    start = 0;
-    end = 0;
     setNow(time(0));
 
-    minEffort = 0.0;
-    resourceLimits = 0;
-    rate = 0.0;
-    currencyDigits = 3;
-    kotrus = 0;
-
     /* Initialize working hours with default values that match the Monday -
      * Friday 9 - 6 (with 1 hour lunch break) pattern used by many western
      * countries. */
     // Sunday
     workingHours[0] = new QPtrList<Interval>();
-    workingHours[0]->setAutoDelete(TRUE);
+    workingHours[0]->setAutoDelete(true);
 
     for (int i = 1; i < 6; ++i)
     {
         workingHours[i] = new QPtrList<Interval>();
-        workingHours[i]->setAutoDelete(TRUE);
+        workingHours[i]->setAutoDelete(true);
         workingHours[i]->append(new Interval(9 * ONEHOUR, 12 * ONEHOUR - 1));
         workingHours[i]->append(new Interval(13 * ONEHOUR, 18 * ONEHOUR - 1));
     }
 
     // Saturday
     workingHours[6] = new QPtrList<Interval>();
-    workingHours[6]->setAutoDelete(TRUE);
-
-    maxErrors = 0;
+    workingHours[6]->setAutoDelete(true);
 }
 
 Project::~Project()
 {
-    while (!taskList.isEmpty())
-    {
-        for (TaskListIterator tli(taskList); *tli; ++tli)
-            if ((*tli)->getParent() == 0)
-            {
-                delete *tli;
-                break;
-            }
-    }
-
-    while (!resourceList.isEmpty())
-    {
-        for (ResourceListIterator tli(resourceList); *tli; ++tli)
-            if ((*tli)->getParent() == 0)
-            {
-                delete *tli;
-                break;
-            }
-    }
+    taskList.deleteContents();
+    resourceList.deleteContents();
     Resource::deleteStaticData();
 
-    while (!accountList.isEmpty())
-    {
-        for (AccountListIterator tli(accountList); *tli; ++tli)
-            if ((*tli)->getParent() == 0)
-            {
-                delete *tli;
-                break;
-            }
-    }
+    accountList.deleteContents();
+    shiftList.deleteContents();
+    scenarioList.deleteContents();
 
-    while (!shiftList.isEmpty())
-    {
-        for (ShiftListIterator tli(shiftList); *tli; ++tli)
-            if ((*tli)->getParent() == 0)
-            {
-                delete *tli;
-                break;
-            }
-    }
-
-    while (!scenarioList.isEmpty())
-    {
-        for (ScenarioListIterator tli(scenarioList); *tli; ++tli)
-            if ((*tli)->getParent() == 0)
-            {
-                delete *tli;
-                break;
-            }
-    }
+    delete resourceLimits;
 
     // Remove support for 1.0 XML reports for next major release. */
     delete xmlreport;
@@ -275,14 +239,14 @@ bool
 Project::addId(const QString& id, bool changeCurrentId)
 {
     if (projectIDs.findIndex(id) != -1)
-        return FALSE;
+        return false;
     else
         projectIDs.append(id);
 
     if (changeCurrentId)
         currentId = id;
 
-    return TRUE;
+    return true;
 }
 
 QString
@@ -308,8 +272,8 @@ Project::addScenario(Scenario* s)
 
     /* This is not too efficient, but since there are usually only a few
      * scenarios in a project, this doesn't hurt too much. */
-    scenarioList.createIndex(TRUE);
-    scenarioList.createIndex(FALSE);
+    scenarioList.createIndex(true);
+    scenarioList.createIndex(false);
 }
 
 void
@@ -342,10 +306,10 @@ bool
 Project::addTaskAttribute(const QString& id, CustomAttributeDefinition* cad)
 {
     if (taskAttributes.find(id))
-        return FALSE;
+        return false;
 
     taskAttributes.insert(id, cad);
-    return TRUE;
+    return true;
 }
 
 const CustomAttributeDefinition*
@@ -383,10 +347,10 @@ Project::addResourceAttribute(const QString& id,
                               CustomAttributeDefinition* cad)
 {
     if (resourceAttributes.find(id))
-        return FALSE;
+        return false;
 
     resourceAttributes.insert(id, cad);
-    return TRUE;
+    return true;
 }
 
 const CustomAttributeDefinition*
@@ -411,23 +375,23 @@ bool
 Project::addAccountAttribute(const QString& id,
                               CustomAttributeDefinition* cad)
 {
-    if (resourceAttributes.find(id))
-        return FALSE;
+    if (accountAttributes.find(id))
+        return false;
 
-    resourceAttributes.insert(id, cad);
-    return TRUE;
+    accountAttributes.insert(id, cad);
+    return true;
 }
 
 const CustomAttributeDefinition*
 Project::getAccountAttribute(const QString& id) const
 {
-    return resourceAttributes[id];
+    return accountAttributes[id];
 }
 
 bool
 Project::isWorkingDay(time_t d) const
 {
-    return !(workingHours[dayOfWeek(d, FALSE)]->isEmpty() ||
+    return !(workingHours[dayOfWeek(d, false)]->isEmpty() ||
              isVacation(d));
 }
 
@@ -435,31 +399,31 @@ bool
 Project::isWorkingTime(time_t d) const
 {
     if (isVacation(d))
-        return FALSE;
+        return false;
 
-    int dow = dayOfWeek(d, FALSE);
+    int dow = dayOfWeek(d, false);
     for (QPtrListIterator<Interval> ili(*(workingHours[dow])); *ili != 0; ++ili)
     {
         if ((*ili)->contains(secondsOfDay(d)))
-            return TRUE;
+            return true;
     }
-    return FALSE;
+    return false;
 }
 
 bool
 Project::isWorkingTime(const Interval& iv) const
 {
     if (isVacation(iv.getStart()))
-        return FALSE;
+        return false;
 
-    int dow = dayOfWeek(iv.getStart(), FALSE);
+    int dow = dayOfWeek(iv.getStart(), false);
     for (QPtrListIterator<Interval> ili(*(workingHours[dow])); *ili != 0; ++ili)
     {
         if ((*ili)->contains(Interval(secondsOfDay(iv.getStart()),
                                   secondsOfDay(iv.getEnd()))))
-            return TRUE;
+            return true;
     }
-    return FALSE;
+    return false;
 }
 
 int
@@ -487,22 +451,21 @@ Project::addJournalEntry(JournalEntry* entry)
     journal.inSort(entry);
 }
 
-JournalIterator
+Journal::Iterator
 Project::getJournalIterator() const
 {
-    return JournalIterator(journal);
+    return Journal::Iterator(journal);
 }
 
 bool
-Project::pass2(bool noDepCheck, bool& fatalError, int& errors, int& warnings)
+Project::pass2(bool noDepCheck)
 {
-    int oldErrors = errors;
+    int oldErrors = TJMH.getErrors();
 
     if (taskList.isEmpty())
     {
         TJMH.errorMessage(i18n("The project does not contain any tasks."));
-        errors++;
-        return FALSE;
+        return false;
     }
 
     QDict<Task> idHash;
@@ -512,10 +475,10 @@ Project::pass2(bool noDepCheck, bool& fatalError, int& errors, int& warnings)
     initUtility(4 * ((end - start) / scheduleGranularity));
 
     // Generate sequence numbers for all lists.
-    taskList.createIndex(TRUE);
-    resourceList.createIndex(TRUE);
-    accountList.createIndex(TRUE);
-    shiftList.createIndex(TRUE);
+    taskList.createIndex(true);
+    resourceList.createIndex(true);
+    accountList.createIndex(true);
+    shiftList.createIndex(true);
 
     // Initialize random generator.
     srand((int) start);
@@ -527,7 +490,7 @@ Project::pass2(bool noDepCheck, bool& fatalError, int& errors, int& warnings)
     }
     // Create cross links from dependency lists.
     for (TaskListIterator tli(taskList); *tli != 0; ++tli)
-        (*tli)->xRef(idHash, errors, warnings);
+        (*tli)->xRef(idHash);
 
     for (TaskListIterator tli(taskList); *tli != 0; ++tli)
     {
@@ -556,60 +519,56 @@ Project::pass2(bool noDepCheck, bool& fatalError, int& errors, int& warnings)
 
     // Now check that all tasks have sufficient data to be scheduled.
     setProgressInfo(i18n("Checking scheduling data..."));
+    bool error = false;
     for (ScenarioListIterator sci(scenarioList); *sci; ++sci)
         for (TaskListIterator tli(taskList); *tli != 0; ++tli)
             if (!(*tli)->preScheduleOk((*sci)->getSequenceNo() - 1))
             {
-                errors++;
-                fatalError = true;
+                error = true;
             }
+    if (error)
+        return false;
 
     if (!noDepCheck)
     {
         setProgressInfo(i18n("Searching for dependency loops ..."));
         if (DEBUGPS(1))
-            qDebug("Searching for dependency loops ...");
+            tjDebug("Searching for dependency loops ...");
         // Check all tasks for dependency loops.
         LDIList chkedTaskList;
         for (TaskListIterator tli(taskList); *tli != 0; ++tli)
             if ((*tli)->loopDetector(chkedTaskList))
-            {
-                errors++;
-                fatalError = true;
-                return FALSE;
-            }
+                return false;
 
         setProgressInfo(i18n("Searching for underspecified tasks ..."));
         if (DEBUGPS(1))
-            qDebug("Searching for underspecified tasks ...");
+            tjDebug("Searching for underspecified tasks ...");
         for (ScenarioListIterator sci(scenarioList); *sci; ++sci)
             for (TaskListIterator tli(taskList); *tli != 0; ++tli)
                 if (!(*tli)->checkDetermination((*sci)->getSequenceNo() - 1))
-                {
-                    errors++;
-                    fatalError = true;
-                }
-        if (fatalError)
+                    error = true;
+
+        if (error)
             return false;
     }
 
-    return errors == oldErrors;
+    return TJMH.getErrors() == oldErrors;
 }
 
 bool
-Project::scheduleScenario(Scenario* sc, int& errors, int& warnings)
+Project::scheduleScenario(Scenario* sc)
 {
-    int oldErrors = errors;
+    int oldErrors = TJMH.getErrors();
 
     setProgressInfo(i18n("Scheduling scenario %1...").arg(sc->getId()));
 
     int scIdx = sc->getSequenceNo() - 1;
     prepareScenario(scIdx);
 
-    if (!schedule(scIdx, errors, warnings))
+    if (!schedule(scIdx))
     {
         if (DEBUGPS(2))
-            qDebug(i18n("Scheduling errors in scenario '%1'.")
+            tjDebug(i18n("Scheduling errors in scenario '%1'.")
                    .arg(sc->getId()));
         if (breakFlag)
             return false;
@@ -619,13 +578,10 @@ Project::scheduleScenario(Scenario* sc, int& errors, int& warnings)
     for (ResourceListIterator rli(resourceList); *rli != 0; ++rli)
     {
         if (!(*rli)->bookingsOk(scIdx))
-        {
-            errors++;
             break;
-        }
     }
 
-    return errors == oldErrors;
+    return TJMH.getErrors() == oldErrors;
 }
 
 void
@@ -643,18 +599,18 @@ Project::completeBuffersAndIndices()
 }
 
 bool
-Project::scheduleAllScenarios(int& errors, int& warnings)
+Project::scheduleAllScenarios()
 {
-    bool schedulingOk = TRUE;
+    bool schedulingOk = true;
     for (ScenarioListIterator sci(scenarioList); *sci; ++sci)
         if ((*sci)->getEnabled())
         {
             if (DEBUGPS(1))
-                qDebug(i18n("Scheduling scenario '%1' ...")
+                tjDebug(i18n("Scheduling scenario '%1' ...")
                        .arg((*sci)->getId()));
 
-            if (!scheduleScenario(*sci, errors, warnings))
-                schedulingOk = FALSE;
+            if (!scheduleScenario(*sci))
+                schedulingOk = false;
             if (breakFlag)
                 return false;
         }
@@ -678,6 +634,9 @@ Project::overlayScenario(int base, int sc)
 void
 Project::prepareScenario(int sc)
 {
+    for (ResourceListIterator rli(resourceList); *rli != 0; ++rli)
+        (*rli)->prepareScenario(sc);
+
     for (TaskListIterator tli(taskList); *tli != 0; ++tli)
         (*tli)->prepareScenario(sc);
 
@@ -694,16 +653,14 @@ Project::prepareScenario(int sc)
     for (TaskListIterator tli(taskList); *tli != 0; ++tli)
         (*tli)->propagateInitialValues(sc);
 
-    for (ResourceListIterator rli(resourceList); *rli != 0; ++rli)
-        (*rli)->prepareScenario(sc);
     if (DEBUGTS(4))
     {
-        qDebug("Allocation probabilities for the resources:");
+        tjDebug("Allocation probabilities for the resources:");
         for (ResourceListIterator rli(resourceList); *rli != 0; ++rli)
             qDebug("Resource %s: %f%%",
                    (*rli)->getId().latin1(),
                    (*rli)->getAllocationProbability(sc));
-        qDebug("Criticalnesses of the tasks with respect to resource "
+        tjDebug("Criticalnesses of the tasks with respect to resource "
                "availability:");
         for (TaskListIterator tli(taskList); *tli != 0; ++tli)
             qDebug("Task %s: %-5.1f %-5.1f", (*tli)->getId().latin1(),
@@ -719,20 +676,34 @@ Project::finishScenario(int sc)
         (*rli)->finishScenario(sc);
     for (TaskListIterator tli(taskList); *tli != 0; ++tli)
         (*tli)->finishScenario(sc);
+
     /* We need to have finished the scenario for all tasks before we can
      * calculate the completion degree. */
     for (TaskListIterator tli(taskList); *tli != 0; ++tli)
-    {
         (*tli)->calcCompletionDegree(sc);
-        (*tli)->checkAndMarkCriticalPath(sc,
-                                         getScenario(sc)->getMinSlackRate());
+
+    /* If the user has not set the minSlackRate to 0 we look for critical
+     * pathes. */
+    if (getScenario(sc)->getMinSlackRate() > 0.0)
+    {
+        setProgressInfo(i18n("Computing critical pathes..."));
+        /* The critical path detector needs to know the end of the last task.
+         * So we have to find this out first. */
+        time_t maxEnd = 0;
+        for (TaskListIterator tli(taskList); *tli != 0; ++tli)
+        if (maxEnd < (*tli)->getEnd(sc))
+            maxEnd = (*tli)->getEnd(sc);
+
+        for (TaskListIterator tli(taskList); *tli != 0; ++tli)
+            (*tli)->checkAndMarkCriticalPath
+                (sc, getScenario(sc)->getMinSlackRate(), maxEnd);
     }
 }
 
 bool
-Project::schedule(int sc, int& errors, int& warnings)
+Project::schedule(int sc)
 {
-    int oldErrors = errors;
+    int oldErrors = TJMH.getErrors();
 
     // The scheduling function only cares about leaf tasks. Container tasks
     // are scheduled automatically when all their childern are scheduled. So
@@ -769,9 +740,10 @@ Project::schedule(int sc, int& errors, int& warnings)
      * number so the first round of cleanup is done right after the first
      * scheduling pass. */
     breakFlag = false;
+    bool runAwayFound = false;
     do
     {
-        done = TRUE;
+        done = true;
         time_t slot = 0;
         int priority = 0;
         Task::SchedulingInfo schedulingInfo = Task::ASAP;
@@ -805,15 +777,12 @@ Project::schedule(int sc, int& errors, int& warnings)
                     slot > (end - (time_t) scheduleGranularity + 1))
                 {
                     (*tli)->setRunaway();
-                    if (DEBUGPS(5))
-                        qDebug("Marking task '%s' as runaway",
-                               (*tli)->getId().latin1());
-                    errors++;
+                    runAwayFound = true;
                     slot = 0;
                     continue;
                 }
             }
-            done = FALSE;
+            done = false;
             /* Each task has a scheduling direction (forward or backward)
              * depending on it's constrains. The task with the highest
              * priority determins the time slot and hence the scheduling
@@ -856,7 +825,7 @@ Project::schedule(int sc, int& errors, int& warnings)
                     setProgressBar(sortedTasks - allLeafTasks.count(),
                                    sortedTasks);
                     setProgressInfo
-                        (i18n("Scheduling scenario %1 at %1")
+                        (i18n("Scheduling scenario %1 at %2")
                          .arg(getScenarioId(sc)).arg(time2tjp(slot)));
                 }
             }
@@ -868,11 +837,10 @@ Project::schedule(int sc, int& errors, int& warnings)
         setProgressInfo("");
         setProgressBar(0, 0);
         TJMH.errorMessage(i18n("Scheduling aborted on user request"));
-        errors++;
         return false;
     }
 
-    if (errors != oldErrors)
+    if (runAwayFound)
         for (TaskListIterator tli(taskList); *tli != 0; ++tli)
             if ((*tli)->isRunaway())
                 if ((*tli)->getScheduling() == Task::ASAP)
@@ -887,16 +855,16 @@ Project::schedule(int sc, int& errors, int& warnings)
                               "project time frame. Try using an earlier "
                               "project start date.").arg((*tli)->getId()));
 
-    if (errors == oldErrors)
+    if (TJMH.getErrors() == oldErrors)
         setProgressBar(100, 100);
 
     /* Check that the resulting schedule meets all the requirements that the
      * user has specified. */
     setProgressInfo(i18n("Checking schedule of scenario %1")
                     .arg(getScenarioId(sc)));
-    checkSchedule(sc, errors, warnings);
+    checkSchedule(sc);
 
-    return errors == oldErrors;
+    return TJMH.getErrors() == oldErrors;
 }
 
 void
@@ -906,25 +874,25 @@ Project::breakScheduling()
 }
 
 bool
-Project::checkSchedule(int sc, int& errors, int& warnings) const
+Project::checkSchedule(int sc) const
 {
-    int oldErrors = errors;
+    int oldErrors = TJMH.getErrors();
     for (TaskListIterator tli(taskList); *tli != 0; ++tli)
     {
         /* Only check top-level tasks, since they recursively check their sub
          * tasks. */
         if ((*tli)->getParent() == 0)
-            (*tli)->scheduleOk(sc, errors, warnings);
-        if (maxErrors > 0 && errors >= maxErrors)
+            (*tli)->scheduleOk(sc);
+        if (maxErrors > 0 && TJMH.getErrors() >= maxErrors)
         {
             TJMH.errorMessage
                 (i18n("Too many errors in %1 scenario. Giving up.")
                  .arg(getScenarioId(sc)));
-            return FALSE;
+            return false;
         }
     }
 
-    return errors == oldErrors;
+    return TJMH.getErrors() == oldErrors;
 }
 
 Report*
@@ -942,122 +910,28 @@ Project::getReportListIterator() const
     return QPtrListIterator<Report>(reports);
 }
 
-void
+bool
 Project::generateReports() const
 {
     // Generate reports
+    int errors = 0;
     for (QPtrListIterator<Report> ri(reports); *ri != 0; ++ri)
     {
         // We generate all but Qt*Reports. Those are for the GUI version.
         if (strncmp((*ri)->getType(), "Qt", 2) != 0)
         {
             if (DEBUGPS(1))
-                qDebug(i18n("Generating report '%1' ...")
+                tjDebug(i18n("Generating report '%1' ...")
                        .arg((*ri)->getFileName()));
 
-            (*ri)->generate();
+            if (!(*ri)->generate())
+                errors++;
         }
     }
 
     generateXMLReport();
-}
 
-void
-Project::setKotrus(Kotrus* k)
-{
-    if (kotrus)
-        delete kotrus;
-    kotrus = k;
-}
-
-bool
-Project::readKotrus()
-{
-    if (!kotrus)
-        return TRUE;
-
-    for (ResourceListIterator rli(resourceList); *rli != 0; ++rli)
-        (*rli)->dbLoadBookings((*rli)->getKotrusId(), 0);
-
-    return TRUE;
-}
-
-bool
-Project::updateKotrus()
-{
-    return TRUE;
-}
-
-bool
-Project::loadFromXML( const QString& inpFile )
-{
-   QDomDocument doc;
-   QFile file( inpFile );
-
-   doc.setContent( &file );
-   qDebug(  "Loading XML " + inpFile );
-
-   QDomElement elemProject = doc.documentElement();
-
-   if( !elemProject.isNull())
-   {
-      parseDomElem( elemProject );
-   }
-   else
-   {
-      qDebug("Empty !" );
-   }
-   bool fatalError;
-   int errors = 0;
-   int warnings = 0;
-   if (!pass2(TRUE, fatalError, errors, warnings))
-       return FALSE;
-   scheduleAllScenarios(errors, warnings);
-   return errors == 0;
-}
-
-
-void Project::parseDomElem( QDomElement& parentElem )
-{
-   QDomElement elem = parentElem.firstChild().toElement();
-
-   for( ; !elem.isNull(); elem = elem.nextSibling().toElement() )
-   {
-      QString tagName = elem.tagName();
-
-      qDebug(  "|| elemType: " + tagName );
-
-      if( tagName == "Task" )
-      {
-     QString tId = elem.attribute("Id");
-     Task *t = new Task( this, tId, QString(), 0, QString(), 0 );
-     t->inheritValues();
-
-     t->loadFromXML( elem, this  );
-      }
-      else if( tagName == "Name" )
-      {
-     setName( elem.text() );
-      }
-      else if( tagName == "Project" )
-      {
-     QString prjId = elem.attribute("Id");
-     addId( prjId );  // FIXME ! There can be more than one project id!
-
-     prjId = elem.attribute("WeekStart");
-     setWeekStartsMonday( prjId == "Mon" );
-      }
-      else if( tagName == "Version" )
-     setVersion( elem.text() );
-      else if( tagName == "Priority" )
-     setPriority( elem.text().toInt());
-      else if( tagName == "start" )
-     setStart( elem.text().toLong());
-      else if( tagName == "end" )
-     setEnd( elem.text().toLong());
-
-      // parseDomElem( elem );
-   }
+    return errors == 0;
 }
 
 bool Project::generateXMLReport() const
