@@ -8,18 +8,13 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: Project.h 1351 2006-10-31 20:34:24Z cs $
+ * $Id: Project.h 1493 2007-06-05 13:17:21Z cs $
  */
 
 #ifndef _Project_h_
 #define _Project_h_
 
-#include <time.h>
-
 #include <qobject.h>
-#include <qptrlist.h>
-#include <qstringlist.h>
-#include <qdict.h>
 #include "config.h"
 #include "VacationList.h"
 #include "ScenarioList.h"
@@ -27,7 +22,6 @@
 #include "ShiftList.h"
 #include "ResourceList.h"
 #include "AccountList.h"
-#include "RealFormat.h"
 #include "QtReport.h"
 #include "Journal.h"
 
@@ -36,7 +30,6 @@ class QDomElement;
 
 class ReportXML;
 class Report;
-class Kotrus;
 class CustomAttributeDefinition;
 class VacationInterval;
 class UsageLimits;
@@ -76,7 +69,7 @@ public:
      * project ID. So, you have to add at least one ID before you add any
      * tasks.
      */
-    bool addId(const QString& i, bool changeCurrentId = TRUE);
+    bool addId(const QString& i, bool changeCurrentId = true);
 
     /**
      * Returns the first (default) ID of the project.
@@ -98,7 +91,7 @@ public:
      */
     QStringList getProjectIdList() const { return projectIDs; }
     /**
-     * Returns TRUE if the passed ID is a registered project ID.
+     * Returns true if the passed ID is a registered project ID.
      */
     bool isValidId(const QString& i) const
     {
@@ -232,7 +225,7 @@ public:
     void setWeekStartsMonday(bool wsm) { weekStartsMonday = wsm; }
     /**
      * Get the setting for the first day of the week.
-     * @return TRUE of weeks should start on Monday.
+     * @return true of weeks should start on Monday.
      */
     bool getWeekStartsMonday() const { return weekStartsMonday; }
 
@@ -280,13 +273,13 @@ public:
 
     /**
      * If date is contained in a vacation day or the date is outside
-     * of the defined working hours, FALSE is returned. Otherwise TRUE.
+     * of the defined working hours, false is returned. Otherwise true.
      */
     bool isWorkingTime(time_t d) const;
 
     /**
      * If the interval overlaps with a vacation day or the interval is outside
-     * of the defined working hours, FALSE is returned. Otherwise TRUE.
+     * of the defined working hours, false is returned. Otherwise true.
      */
     bool isWorkingTime(const Interval& iv) const;
 
@@ -365,7 +358,7 @@ public:
         vacationList.add(vi);
     }
     /**
-     * Returns TRUE if the passed moment falls within any of the vacation
+     * Returns true if the passed moment falls within any of the vacation
      * intervals.
      */
     bool isVacation(time_t d) const { return vacationList.isVacation(d); }
@@ -382,9 +375,9 @@ public:
     /**
      * Returns an iterator for the vacation list.
      */
-    VacationListIterator getVacationListIterator() const
+    VacationList::Iterator getVacationListIterator() const
     {
-        return VacationListIterator(vacationList);
+        return VacationList::Iterator(vacationList);
     }
 
     /**
@@ -578,7 +571,7 @@ public:
     const QDict<CustomAttributeDefinition>&
         getAccountAttributeDict() const
     {
-        return resourceAttributes;
+        return accountAttributes;
     }
 
     /**
@@ -728,9 +721,6 @@ public:
     Report* getReport(uint idx) const;
     QPtrListIterator<Report> getReportListIterator() const;
 
-    bool loadFromXML( const QString& file );
-    void parseDomElem( QDomElement& parentElem );
-
     void addAllowedFlag(QString flag)
     {
         if (!isAllowedFlag(flag))
@@ -751,33 +741,27 @@ public:
      */
     double convertToDailyLoad(long secs) const;
 
-    void setKotrus(Kotrus* k);
-    Kotrus* getKotrus() const { return kotrus; }
-
-    bool readKotrus();
-    bool updateKotrus();
-
     void setMaxErrors(int me) { maxErrors = me; }
 
     void addJournalEntry(JournalEntry* entry);
 
     bool hasJournal() const { return !journal.isEmpty(); }
 
-    JournalIterator getJournalIterator() const;
+    Journal::Iterator getJournalIterator() const;
 
     /**
      * Generate cross references between all data structures and run a
      * consistency check. This function must be called after the project data
      * tree has been contructed.
-     * @return Only if all tests were successful TRUE is returned.
+     * @return Only if all tests were successful true is returned.
      */
-    bool pass2(bool noDepCheck, bool& fatalError, int& errors, int& warnings);
+    bool pass2(bool noDepCheck);
 
-    bool scheduleScenario(Scenario* sc, int& errors, int& warnings);
+    bool scheduleScenario(Scenario* sc);
     void breakScheduling();
     void completeBuffersAndIndices();
-    bool scheduleAllScenarios(int& errors, int& warnings);
-    void generateReports() const;
+    bool scheduleAllScenarios();
+    bool generateReports() const;
 
     bool generateXMLReport() const;
 
@@ -790,9 +774,9 @@ private:
     void prepareScenario(int sc);
     void finishScenario(int sc);
 
-    bool schedule(int sc, int& errors, int& warnings);
+    bool schedule(int sc);
 
-    bool checkSchedule(int sc, int& errors, int& warnings) const;
+    bool checkSchedule(int sc) const;
 
     /// The start date of the project
     time_t start;
@@ -917,8 +901,7 @@ private:
 
     QDict<CustomAttributeDefinition> taskAttributes;
     QDict<CustomAttributeDefinition> resourceAttributes;
-
-    Kotrus* kotrus;
+    QDict<CustomAttributeDefinition> accountAttributes;
 
     /* This is for version 1.0 XML reports and should be removed before the
      * next major release. */
