@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: ProjectFile.h 1345 2006-10-19 03:17:39Z cs $
+ * $Id: ProjectFile.h 1472 2007-04-19 08:47:13Z cs $
  */
 
 #ifndef _ProjectFile_h_
@@ -15,11 +15,7 @@
 
 #include <time.h>
 
-#include <qptrlist.h>
-
 #include "taskjuggler.h"
-#include "Token.h"
-#include "MacroTable.h"
 #include "FileInfo.h"
 
 class QBitArray;
@@ -69,7 +65,7 @@ public:
      * This is a file, that is not included by any other file.
      */
     bool open(const QString& file, const QString& parentPath,
-              const QString& taskPrefix, bool masterfile = FALSE);
+              const QString& taskPrefix, bool masterfile = false);
     /**
      * Close the just read input file.
      */
@@ -112,13 +108,12 @@ public:
 
     bool generateMakeDepList(const QString& fileName, bool append) const;
 
-    void errorMessage(const char* msg, ...);
+    void errorMessage(const QString& msg);
+    void warningMessage(const QString& msg);
 
     MacroTable& getMacros() { return macros; }
 
 private:
-    ProjectFile() {};   // don't use
-
     bool readProject();
     bool readExtend();
     bool readScenario(Scenario* parent);
@@ -136,7 +131,7 @@ private:
     bool readResourceBody(Resource* r);
 
     JournalEntry* readJournalEntry();
-    bool readVacation(time_t& from, time_t& to, bool readName = FALSE,
+    bool readVacation(time_t& from, time_t& to, bool readName = false,
                       QString* = 0);
     bool readAccount(Account* parent);
     bool readShift(Shift* parent);
