@@ -7,39 +7,36 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: QtReport.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: QtReport.h 1454 2007-03-23 10:20:38Z cs $
  */
 
 #ifndef _QtReport_h_
 #define _QtReport_h_
 
-#include <stdio.h>
-#include <time.h>
-
-#include <qstring.h>
-
-#include "Report.h"
-
-class Project;
-class ExpressionTree;
+#include "QtReportElement.h"
+#include "ElementHolder.h"
 
 /**
  * @short Stores all information about a Qt report.
  * @author Chris Schlaeger <cs@kde.org>
  */
-class QtReport : public Report
+class QtReport : public Report, public ElementHolder
 {
 public:
-    QtReport(Project* p, const QString& f, const QString& df, int dl);
+    QtReport(Project* p, const QString& f, const QString& df, int dl) :
+        Report(p, f, df, dl)
+    {
+        loadUnit = shortAuto;
+    }
+
     virtual ~QtReport() { }
 
     virtual const char* getType() const { return "QtReport"; }
 
-    void generateHeader();
-    void generateFooter();
-
-protected:
-    QtReport() { }
+    virtual bool generate()
+    {
+        return false;
+    }
 } ;
 
 #endif
