@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: QtReportElement.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: QtReportElement.h 1436 2007-03-17 17:04:30Z cs $
  */
 
 #ifndef _QtReportElement_h_
@@ -35,7 +35,7 @@ public:
     QtReportElement(Report* r, const QString& df, int dl);
     virtual ~QtReportElement() { }
 
-    virtual bool generate()  { return FALSE; }
+    virtual bool generate()  { return false; }
 
     virtual void genHeadDefault(TableCellInfo*) { }
     virtual void genHeadCurrency(TableCellInfo*) { }
@@ -111,13 +111,8 @@ public:
     virtual void genCellMaxEffort(TableCellInfo*) { }
     virtual void genCellEfficiency(TableCellInfo*) { }
     virtual void genCellRate(TableCellInfo*) { }
-    virtual void genCellKotrusId(TableCellInfo*) { }
     virtual void genCellTotal(TableCellInfo*) { }
     virtual void genCellSummary(TableCellInfo*) { }
-
-protected:
-    QtReportElement() { }
-
 } ;
 
 #endif
