@@ -7,16 +7,14 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: QtResourceReport.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: QtResourceReport.h 1449 2007-03-23 09:17:52Z cs $
  */
 
 #ifndef _QtResourceReport_h_
 #define _QtResourceReport_h_
 
 #include "QtReport.h"
-
-class Project;
-class QtResourceReportElement;
+#include "QtResourceReportElement.h"
 
 /**
  * @short Stores all information about an Qt task report.
@@ -25,19 +23,16 @@ class QtResourceReportElement;
 class QtResourceReport : public QtReport
 {
 public:
-    QtResourceReport(Project* p, const QString& f, const QString& df, int dl);
-    virtual ~QtResourceReport();
+    QtResourceReport(Project* p, const QString& f, const QString& df, int dl) :
+        QtReport(p, f, df, dl)
+    { 
+        setTable(new QtResourceReportElement(this, df, dl));
+    }
+
+    virtual ~QtResourceReport()
+    { }
 
     virtual const char* getType() const { return "QtResourceReport"; }
-
-    bool generate() { return FALSE; }
-
-    QtResourceReportElement* getTable() const { return tab; }
-
-private:
-    QtResourceReport() { }
-
-    QtResourceReportElement* tab;
 } ;
 
 #endif
