@@ -7,21 +7,13 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: QtResourceReportElement.cpp 1259 2006-01-31 12:04:00Z cs $
+ * $Id: QtResourceReportElement.cpp 1422 2007-02-23 03:20:18Z cs $
  */
 
 #include "QtResourceReportElement.h"
-#include "TableColumnInfo.h"
-#include "TableLineInfo.h"
 #include "ExpressionTree.h"
 #include "Operation.h"
-#include "Report.h"
 #include "Project.h"
-#include "Task.h"
-#include "TaskList.h"
-#include "Resource.h"
-#include "ResourceList.h"
-#include "CoreAttributes.h"
 
 QtResourceReportElement::QtResourceReportElement(Report* r, const QString& df,
                                              int dl) :
