@@ -7,16 +7,14 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: QtTaskReport.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: QtTaskReport.h 1449 2007-03-23 09:17:52Z cs $
  */
 
 #ifndef _QtTaskReport_h_
 #define _QtTaskReport_h_
 
 #include "QtReport.h"
-
-class Project;
-class QtTaskReportElement;
+#include "QtTaskReportElement.h"
 
 /**
  * @short Stores all information about an Qt task report.
@@ -25,19 +23,20 @@ class QtTaskReportElement;
 class QtTaskReport : public QtReport
 {
 public:
-    QtTaskReport(Project* p, const QString& f, const QString& df, int dl);
-    virtual ~QtTaskReport();
+    QtTaskReport(Project* p, const QString& f, const QString& df, int dl) :
+        QtReport(p, f, df, dl)
+    { 
+        setTable(new QtTaskReportElement(this, df, dl));
+        taskSortCriteria[0] = CoreAttributesList::TreeMode;
+        taskSortCriteria[1] = CoreAttributesList::StartUp;
+        taskSortCriteria[2] = CoreAttributesList::EndUp;
+        resourceSortCriteria[0] = CoreAttributesList::TreeMode;
+    }
+
+    virtual ~QtTaskReport()
+    { }
 
     virtual const char* getType() const { return "QtTaskReport"; }
-
-    bool generate() { return FALSE; }
-
-    QtTaskReportElement* getTable() const { return tab; }
-
-private:
-    QtTaskReport() { }
-
-    QtTaskReportElement* tab;
 } ;
 
 #endif
