@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: QtTaskReportElement.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: QtTaskReportElement.h 1428 2007-03-17 15:24:21Z cs $
  */
 
 #ifndef _QtTaskReportElement_h_
@@ -21,10 +21,7 @@ public:
     QtTaskReportElement(Report* r, const QString& df, int dl);
     ~QtTaskReportElement();
 
-    bool generate() { return FALSE; }
-
-private:
-    QtTaskReportElement() { }
+    bool generate() { return false; }
 } ;
 
 #endif
