@@ -7,28 +7,31 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: RealFormat.cpp 1259 2006-01-31 12:04:00Z cs $
+ * $Id: RealFormat.cpp 1420 2007-02-23 02:51:52Z cs $
  */
 
+#include "RealFormat.h"
+
 #include <stdlib.h>
 #include <math.h>
 
-#include "RealFormat.h"
-
 RealFormat::RealFormat(const QString& sp, const QString& ss,
-                       const QString& ts, const QString& fs, uint fd)
-    : signPrefix(sp), signSuffix(ss), thousandSep(ts), fractionSep(fs),
+                       const QString& ts, const QString& fs, uint fd) :
+    signPrefix(sp),
+    signSuffix(ss),
+    thousandSep(ts),
+    fractionSep(fs),
     fracDigits(fd)
 {
 }
 
-RealFormat::RealFormat(const RealFormat& r)
+RealFormat::RealFormat(const RealFormat& r) :
+    signPrefix(r.signPrefix),
+    signSuffix(r.signSuffix),
+    thousandSep(r.thousandSep),
+    fractionSep(r.fractionSep),
+    fracDigits(r.fracDigits)
 {
-    signPrefix = r.signPrefix;
-    signSuffix = r.signSuffix;
-    thousandSep = r.thousandSep;
-    fractionSep = r.fractionSep;
-    fracDigits = r.fracDigits;
 }
 
 QString
@@ -53,8 +56,8 @@ RealFormat::format(double val, bool showZeroFract) const
     text.replace(QChar(' '), QChar('0'));
     if (!fractionSep.isEmpty() && fracDigits > 0)
     {
-        double v = fabs(val) - abs((int) val);
-        int fract = (int) (v * pow(10, fracDigits));
+        double v = fabs(val) - abs(static_cast<int>(val));
+        int fract = static_cast<int>(v * pow(10, fracDigits));
         text += fractionSep + QString("%1").arg(fract);
         /* If showZeroFract is false, we remove all zeros from the right end
          * of the text string. */
