@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: ReferenceAttribute.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: ReferenceAttribute.h 1407 2007-02-17 09:46:12Z cs $
  */
 #ifndef _ReferenceAttribute_h_
 #define _ReferenceAttribute_h_
@@ -23,15 +23,24 @@
 class ReferenceAttribute : public CustomAttribute
 {
 public:
-    ReferenceAttribute() { }
+    ReferenceAttribute() :
+        CustomAttribute(),
+        url(),
+        label()
+    { }
+
     ReferenceAttribute(const ReferenceAttribute& ra) :
-        CustomAttribute(ra)
-    {
-        url = ra.url;
-        label = ra.label;
-    }
+        CustomAttribute(ra),
+        url(ra.url),
+        label(ra.label)
+    { }
+
     ReferenceAttribute(const QString& u, const QString& l) :
-        url(u), label(l) { }
+        CustomAttribute(),
+        url(u),
+        label(l)
+    { }
+
     virtual ~ReferenceAttribute() { }
 
     CustomAttributeType getType() const { return CAT_Reference; }
