@@ -7,30 +7,53 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: Report.cpp 1373 2007-01-25 15:13:13Z cs $
+ * $Id: Report.cpp 1497 2007-06-13 07:54:55Z cs $
  */
 
-#include <config.h>
-#include <stdio.h>
-
 #include "Report.h"
-#include "Interval.h"
+
 #include "TjMessageHandler.h"
 #include "tjlib-internal.h"
 #include "Project.h"
-#include "Task.h"
 #include "Resource.h"
 #include "Account.h"
-#include "Utility.h"
 #include "ExpressionTree.h"
 #include "TaskTreeIterator.h"
 #include "ResourceTreeIterator.h"
 #include "AccountTreeIterator.h"
 
-#define KW(a) a
 
 Report::Report(Project* p, const QString& f, const QString& df, int dl) :
-        project(p), fileName(f), defFileName(df), defFileLine(dl)
+    project(p),
+    fileName(f),
+    defFileName(df),
+    defFileLine(dl),
+    f(),
+    s(),
+    scenarios(),
+    weekStartsMonday(p->getWeekStartsMonday()),
+    headline(),
+    caption(),
+    maxDepthTaskList(1),
+    maxDepthResourceList(1),
+    maxDepthAccountList(1),
+    columns(),
+    start(p->getStart()),
+    end(p->getEnd()),
+    timeFormat(p->getTimeFormat()),
+    shortTimeFormat(p->getShortTimeFormat()),
+    numberFormat(p->getNumberFormat()),
+    currencyFormat(p->getCurrencyFormat()),
+    taskSortCriteria(),
+    resourceSortCriteria(),
+    accountSortCriteria(),
+    hideTask(0),
+    hideResource(0),
+    hideAccount(0),
+    rollUpTask(0),
+    rollUpResource(0),
+    rollUpAccount(0),
+    taskRoot()
 {
     for (int i = 0; i < CoreAttributesList::maxSortingLevel; ++i)
     {
@@ -39,31 +62,9 @@ Report::Report(Project* p, const QString& f, const QString& df, int dl) :
         accountSortCriteria[i] = CoreAttributesList::SequenceUp;
     }
 
-    start = p->getStart();
-    end = p->getEnd();
-
-    weekStartsMonday = p->getWeekStartsMonday();
-    timeFormat = p->getTimeFormat();
-    shortTimeFormat = p->getShortTimeFormat();
-    numberFormat = p->getNumberFormat();
-    currencyFormat = p->getCurrencyFormat();
-
-    hideTask = 0;
-    rollUpTask = 0;
-    hideResource = 0;
-    rollUpResource = 0;
-    hideAccount = 0;
-    rollUpAccount = 0;
-
-    showPIDs = FALSE;
-
+    showPIDs = false;
     loadUnit = days;
-
-    timeStamp = TRUE;
-
-    maxDepthTaskList = 1;
-    maxDepthResourceList = 1;
-    maxDepthAccountList = 1;
+    timeStamp = true;
 }
 
 Report::~Report()
@@ -84,7 +85,7 @@ Report::open()
         if (!f.open(IO_WriteOnly, stdout))
         {
             TJMH.errorMessage(i18n("Cannout open stdout"));
-            return FALSE;
+            return false;
         }
     }
     else
@@ -97,11 +98,18 @@ Report::open()
             TJMH.errorMessage
                 (QString(i18n("Cannot open report file %1!\n"))
                  .arg(fullFileName.latin1()));
-            return FALSE;
+            return false;
         }
     }
     s.setDevice(&f);
-    return TRUE;
+    return true;
+}
+
+bool
+Report::close()
+{
+    f.close();
+    return true;
 }
 
 QString
@@ -130,12 +138,12 @@ Report::setTaskSorting(int sc, int level)
     {
         if ((sc == CoreAttributesList::TreeMode && level > 0) ||
             !TaskList::isSupportedSortingCriteria(sc & 0xFFFF))
-            return FALSE;
+            return false;
         taskSortCriteria[level] = sc;
     }
     else
-        return FALSE;
-    return TRUE;
+        return false;
+    return true;
 }
 
 bool
@@ -145,12 +153,12 @@ Report::setResourceSorting(int sc, int level)
     {
         if ((sc == CoreAttributesList::TreeMode && level > 0) ||
             !ResourceList::isSupportedSortingCriteria(sc & 0xFFFF))
-            return FALSE;
+            return false;
         resourceSortCriteria[level] = sc;
     }
     else
-        return FALSE;
-    return TRUE;
+        return false;
+    return true;
 }
 
 bool
@@ -160,12 +168,12 @@ Report::setAccountSorting(int sc, int level)
     {
         if ((sc == CoreAttributesList::TreeMode && level > 0) ||
             !AccountList::isSupportedSortingCriteria(sc & 0xFFFF))
-            return FALSE;
+            return false;
         accountSortCriteria[level] = sc;
     }
     else
-        return FALSE;
-    return TRUE;
+        return false;
+    return true;
 }
 
 bool
@@ -174,24 +182,24 @@ Report::isHidden(const CoreAttributes* c, ExpressionTree* et) const
     if (!taskRoot.isEmpty() && c->getType() == CA_Task &&
         taskRoot != c->getId().left(taskRoot.length()))
     {
-        return TRUE;
+        return true;
     }
 
     if (!et)
-        return FALSE;
+        return false;
 
     et->clearSymbolTable();
     QStringList allFlags = project->getAllowedFlags();
     for (QStringList::Iterator ait = allFlags.begin(); ait != allFlags.end();
          ++ait)
     {
-        bool found = FALSE;
+        bool found = false;
         QStringList flags = c->getFlagList();
         for (QStringList::Iterator it = flags.begin(); it != flags.end(); ++it)
             if (*it == *ait)
             {
                 et->registerSymbol(*it, 1);
-                found = TRUE;
+                found = true;
                 break;
             }
         if (!found)
@@ -204,20 +212,20 @@ bool
 Report::isRolledUp(const CoreAttributes* c, ExpressionTree* et) const
 {
     if (!et)
-        return FALSE;
+        return false;
 
     et->clearSymbolTable();
     QStringList allFlags = project->getAllowedFlags();
     for (QStringList::Iterator ait = allFlags.begin(); ait != allFlags.end();
          ++ait)
     {
-        bool found = FALSE;
+        bool found = false;
         QStringList flags = c->getFlagList();
         for (QStringList::Iterator it = flags.begin(); it != flags.end(); ++it)
             if (*it == *ait)
             {
                 et->registerSymbol(*it, 1);
-                found = TRUE;
+                found = true;
                 break;
             }
         if (!found)
@@ -279,18 +287,18 @@ const
     for (TaskListIterator tli(project->getTaskListIterator());
          *tli != 0; ++tli)
     {
-        bool resourceLoadedInAnyScenario = FALSE;
+        bool resourceLoadedInAnyScenario = false;
         if (r != 0)
         {
             QValueList<int>::const_iterator it;
             for (it = scenarios.begin(); it != scenarios.end(); ++it)
                 if ((*tli)->isBookedResource(*it, r))
                 {
-                    resourceLoadedInAnyScenario = TRUE;
+                    resourceLoadedInAnyScenario = true;
                     break;
                 }
         }
-        bool taskOverlapsInAnyScenario = FALSE;
+        bool taskOverlapsInAnyScenario = false;
         Interval iv(start, end);
         QValueList<int>::const_iterator it;
         for (it = scenarios.begin(); it != scenarios.end(); ++it)
@@ -300,7 +308,7 @@ const
                                  (*tli)->getStart(*it) :
                                  (*tli)->getEnd(*it))))
             {
-                taskOverlapsInAnyScenario = TRUE;
+                taskOverlapsInAnyScenario = true;
                 break;
             }
         if (taskOverlapsInAnyScenario &&
@@ -310,7 +318,7 @@ const
             filteredList.append(tli);
         }
         if (hideExp && hideExp->getErrorFlag())
-            return FALSE;
+            return false;
     }
 
     /* In tasktree sorting mode we need to make sure that we don't hide
@@ -331,7 +339,7 @@ const
     filteredList = list;
 
     if (!rollUpExp)
-        return TRUE;
+        return true;
 
     /* Now we have to remove all sub tasks of rolled-up tasks
      * from the filtered list */
@@ -344,10 +352,10 @@ const
                 if (*tti != *tli)
                     filteredList.removeRef(*tti);
         if (rollUpExp && rollUpExp->getErrorFlag())
-            return FALSE;
+            return false;
     }
 
-    return TRUE;
+    return true;
 }
 
 void
@@ -373,16 +381,16 @@ const
     for (ResourceListIterator rli(project->getResourceListIterator());
          *rli != 0; ++rli)
     {
-        bool taskLoadedInAnyScenario = FALSE;
+        bool taskLoadedInAnyScenario = false;
         if (t != 0)
         {
             QValueList<int>::const_iterator it;
             for (it = scenarios.begin(); it != scenarios.end();
                  ++it)
-                if ((*rli)->getLoad(*it, Interval(start, end),
-                                    AllAccounts, t) > 0.0)
+                if ((*rli)->getEffectiveLoad(*it, Interval(start, end),
+                                             AllAccounts, t) > 0.0)
                 {
-                    taskLoadedInAnyScenario = TRUE;
+                    taskLoadedInAnyScenario = true;
                     break;
                 }
         }
@@ -392,7 +400,7 @@ const
             filteredList.append(*rli);
         }
         if (hideExp && hideExp->getErrorFlag())
-            return FALSE;
+            return false;
     }
 
     /* In resourcetree sorting mode we need to make sure that we don't
@@ -410,7 +418,7 @@ const
     filteredList = list;
 
     if (!rollUpExp)
-        return TRUE;
+        return true;
 
     /* Now we have to remove all sub resources of resource in the
      * roll-up list from the filtered list */
@@ -423,10 +431,10 @@ const
                 if (*rti != *rli)
                     filteredList.removeRef(*rti);
         if (rollUpExp && rollUpExp->getErrorFlag())
-            return FALSE;
+            return false;
     }
 
-    return TRUE;
+    return true;
 }
 
 void
@@ -448,10 +456,11 @@ const
     for (AccountListIterator ali(project->getAccountListIterator());
          *ali != 0; ++ali)
     {
-        if (!isHidden(*ali, hideExp) && (*ali)->getAcctType() == at)
+        if (!isHidden(*ali, hideExp) &&
+            (at == AllAccounts || (*ali)->getAcctType() == at))
             filteredList.append(*ali);
         if (hideExp && hideExp->getErrorFlag())
-            return FALSE;
+            return false;
     }
 
     /* In accounttree sorting mode we need to make sure that we don't hide
@@ -469,7 +478,7 @@ const
     filteredList = list;
 
     if (!rollUpExp)
-        return TRUE;
+        return true;
 
     /* Now we have to remove all sub accounts of account in the roll-up list
      * from the filtered list */
@@ -482,10 +491,10 @@ const
                 if (*ati != *ali)
                     filteredList.removeRef(*ati);
         if (rollUpExp && rollUpExp->getErrorFlag())
-            return FALSE;
+            return false;
     }
 
-    return TRUE;
+    return true;
 }
 
 void
@@ -518,21 +527,15 @@ Report::setLoadUnit(const QString& u)
     else if (u == KW("longauto"))
         loadUnit = longAuto;
     else
-        return FALSE;
+        return false;
 
-    return TRUE;
+    return true;
 }
 
 void
-Report::errorMessage(const char* msg, ... )
+Report::errorMessage(const QString& msg)
 {
-    va_list ap;
-    va_start(ap, msg);
-    char buf[1024];
-    vsnprintf(buf, 1024, msg, ap);
-    va_end(ap);
-
-    TJMH.errorMessage(buf, defFileName, defFileLine);
+    TJMH.errorMessage(msg, defFileName, defFileLine);
 }
 
 QString
