@@ -7,21 +7,16 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: Report.h 1335 2006-09-24 13:49:05Z cs $
+ * $Id: Report.h 1472 2007-04-19 08:47:13Z cs $
  */
 
 #ifndef _Report_h_
 #define _Report_h_
 
-#include <time.h>
-
-#include <qstring.h>
-#include <qstringlist.h>
 #include <qvaluelist.h>
 #include <qfile.h>
 #include <qtextstream.h>
 
-#include "taskjuggler.h"
 #include "CoreAttributesList.h"
 #include "RealFormat.h"
 #include "Interval.h"
@@ -49,6 +44,7 @@ public:
     virtual const char* getType() const { return "Report"; }
 
     bool open();
+    bool close();
 
     QTextStream& stream() { return s; }
 
@@ -177,9 +173,7 @@ public:
     virtual bool generate() = 0;
 
 protected:
-    Report() { }
-
-    void errorMessage(const char* msg, ... );
+    void errorMessage(const QString& msg);
 
     /**
      * This utility function removes the path that matches the taskRoot
