@@ -7,28 +7,20 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: ReportElement.cpp 1336 2006-09-26 18:09:50Z cs $
+ * $Id: ReportElement.cpp 1497 2007-06-13 07:54:55Z cs $
  */
 
-#include <config.h>
-#include <stdio.h>
-
-#include <qdict.h>
-
 #include "ReportElement.h"
+
 #include "Interval.h"
-#include "TableColumnFormat.h"
-#include "TableColumnInfo.h"
 #include "TableCellInfo.h"
 #include "TableLineInfo.h"
 #include "TjMessageHandler.h"
 #include "tjlib-internal.h"
 #include "Project.h"
 #include "CoreAttributes.h"
-#include "Task.h"
 #include "Resource.h"
 #include "Account.h"
-#include "Utility.h"
 #include "ExpressionTree.h"
 #include "TaskTreeIterator.h"
 #include "ResourceTreeIterator.h"
@@ -36,25 +28,44 @@
 #include "CustomAttributeDefinition.h"
 #include "TextAttribute.h"
 #include "ReferenceAttribute.h"
-#include "MacroTable.h"
-
-#define KW(a) a
 
 ReportElement::ReportElement(Report* r, const QString& df, int dl) :
-        ReportElementBase(r), defFileName(df), defFileLine(dl)
+    ReportElementBase(r),
+    scenarios(),
+    columns(),
+    columnFormat(),
+    start(r->getStart()),
+    end(r->getEnd()),
+    barLabels(BLT_LOAD),
+    rawHead(),
+    rawTail(),
+    timeFormat(r->getTimeFormat()),
+    shortTimeFormat(r->getShortTimeFormat()),
+    defFileName(df),
+    defFileLine(dl),
+    colors(),
+    headline(),
+    caption(),
+    taskSortCriteria(),
+    resourceSortCriteria(),
+    accountSortCriteria(),
+    hideTask(0),
+    hideResource(0),
+    hideAccount(0),
+    rollUpTask(0),
+    rollUpResource(0),
+    rollUpAccount(0),
+    taskRoot(r->getTaskRoot()),
+    showPIDs(r->getShowPIDs()),
+    accumulate(false),
+    maxDepthTaskList(1),
+    maxDepthResourceList(1),
+    maxDepthAccountList(1),
+    mt()
 {
-    columns.setAutoDelete(TRUE);
-    columnFormat.setAutoDelete(TRUE);
+    columns.setAutoDelete(true);
+    columnFormat.setAutoDelete(true);
 
-    maxDepthTaskList = 1;
-    maxDepthResourceList = 1;
-    maxDepthAccountList = 1;
-
-    start = r->getStart();
-    end = r->getEnd();
-
-    timeFormat = r->getTimeFormat();
-    shortTimeFormat = r->getShortTimeFormat();
     numberFormat = r->getNumberFormat();
     currencyFormat = r->getCurrencyFormat();
 
@@ -101,8 +112,8 @@ ReportElement::ReportElement(Report* r, const QString& df, int dl) :
     tcf->genAccountLine1 = &ReportElement::genCellName;
     tcf->genSummaryLine1 = &ReportElement::genCellName;
     tcf->hAlign = TableColumnFormat::left;
-    tcf->indent = TRUE;
-    tcf->noWrap = TRUE;
+    tcf->indent = true;
+    tcf->noWrap = true;
     tcf->expandable = true;
 
     tcf = new TableColumnFormat(KW("start"), this, i18n("Start"));
@@ -162,7 +173,7 @@ ReportElement::ReportElement(Report* r, const QString& df, int dl) :
     tcf->genTaskLine2 = &ReportElement::genCellDuration;
     tcf->hAlign = TableColumnFormat::right;
     tcf->realFormat = numberFormat;
-    tcf->indent = TRUE;
+    tcf->indent = true;
 
     tcf = new TableColumnFormat(KW("effort"), this, i18n("Effort"));
     tcf->genTaskLine1 = &ReportElement::genCellEffort;
@@ -171,21 +182,21 @@ ReportElement::ReportElement(Report* r, const QString& df, int dl) :
     tcf->genResourceLine2 = &ReportElement::genCellEffort;
     tcf->hAlign = TableColumnFormat::right;
     tcf->realFormat = numberFormat;
-    tcf->indent = TRUE;
+    tcf->indent = true;
 
     tcf = new TableColumnFormat(KW("freeload"), this, i18n("Free Load"));
     tcf->genResourceLine1 = &ReportElement::genCellFreeLoad;
     tcf->genResourceLine2 = &ReportElement::genCellFreeLoad;
     tcf->hAlign = TableColumnFormat::right;
     tcf->realFormat = numberFormat;
-    tcf->indent = TRUE;
+    tcf->indent = true;
 
     tcf = new TableColumnFormat(KW("utilization"), this, i18n("Utilization"));
     tcf->genResourceLine1 = &ReportElement::genCellUtilization;
     tcf->genResourceLine2 = &ReportElement::genCellUtilization;
     tcf->hAlign = TableColumnFormat::right;
     tcf->realFormat = numberFormat;
-    tcf->indent = TRUE;
+    tcf->indent = true;
 
     tcf = new TableColumnFormat(KW("criticalness"), this, i18n("Criticalness"));
     tcf->genTaskLine1 = &ReportElement::genCellCriticalness;
@@ -266,7 +277,7 @@ ReportElement::ReportElement(Report* r, const QString& df, int dl) :
     tcf->genTaskLine1 = &ReportElement::genCellCompleted;
     tcf->genTaskLine2 = &ReportElement::genCellCompleted;
     tcf->hAlign = TableColumnFormat::right;
-    tcf->indent = TRUE;
+    tcf->indent = true;
 
     tcf = new TableColumnFormat(KW("status"), this, i18n("Status"));
     tcf->genTaskLine1 = &ReportElement::genCellStatus;
@@ -274,10 +285,6 @@ ReportElement::ReportElement(Report* r, const QString& df, int dl) :
     tcf->hAlign = TableColumnFormat::left;
     tcf->expandable = true;
 
-    tcf = new TableColumnFormat(KW("kotrusid"), this, i18n("Kotrus ID"));
-    tcf->genResourceLine1 = &ReportElement::genCellKotrusId;
-    tcf->hAlign = TableColumnFormat::left;
-
     tcf = new TableColumnFormat(KW("note"), this, i18n("Note"));
     tcf->genTaskLine1 = &ReportElement::genCellText;
     tcf->hAlign = TableColumnFormat::left;
@@ -328,7 +335,7 @@ ReportElement::ReportElement(Report* r, const QString& df, int dl) :
     tcf->genResourceLine2 = &ReportElement::genCellCost;
     tcf->hAlign = TableColumnFormat::right;
     tcf->realFormat = currencyFormat;
-    tcf->indent = TRUE;
+    tcf->indent = true;
 
     tcf = new TableColumnFormat(KW("revenue"), this, i18n("Revenue"));
     tcf->genHeadLine1 = &ReportElement::genHeadCurrency;
@@ -338,7 +345,7 @@ ReportElement::ReportElement(Report* r, const QString& df, int dl) :
     tcf->genResourceLine2 = &ReportElement::genCellRevenue;
     tcf->hAlign = TableColumnFormat::right;
     tcf->realFormat = currencyFormat;
-    tcf->indent = TRUE;
+    tcf->indent = true;
 
     tcf = new TableColumnFormat(KW("profit"), this, i18n("Profit"));
     tcf->genHeadLine1 = &ReportElement::genHeadCurrency;
@@ -348,7 +355,7 @@ ReportElement::ReportElement(Report* r, const QString& df, int dl) :
     tcf->genResourceLine2 = &ReportElement::genCellProfit;
     tcf->hAlign = TableColumnFormat::right;
     tcf->realFormat = currencyFormat;
-    tcf->indent = TRUE;
+    tcf->indent = true;
 
     tcf = new TableColumnFormat(KW("total"), this, i18n("Total"));
     tcf->genHeadLine1 = &ReportElement::genHeadCurrency;
@@ -358,7 +365,7 @@ ReportElement::ReportElement(Report* r, const QString& df, int dl) :
     tcf->genSummaryLine2 = &ReportElement::genCellSummary;
     tcf->hAlign = TableColumnFormat::right;
     tcf->realFormat = currencyFormat;
-    tcf->indent = TRUE;
+    tcf->indent = true;
 
     tcf = new TableColumnFormat(KW("daily"), this, "");
     tcf->genHeadLine1 = &ReportElement::genHeadDaily1;
@@ -443,10 +450,6 @@ ReportElement::ReportElement(Report* r, const QString& df, int dl) :
     // All reports default to just showing the first scenario.
     scenarios.append(0);
 
-    barLabels = BLT_LOAD;
-
-    accumulate = FALSE;
-
     for (int i = 0; i < CoreAttributesList::maxSortingLevel; ++i)
     {
         taskSortCriteria[i] = r->getTaskSorting(i);
@@ -467,9 +470,7 @@ ReportElement::ReportElement(Report* r, const QString& df, int dl) :
     rollUpAccount = r->getRollUpAccount() ?
         new ExpressionTree(*r->getRollUpAccount()) : 0;
 
-    taskRoot = r->getTaskRoot();
     loadUnit = r->getLoadUnit();
-    showPIDs = r->getShowPIDs();
 }
 
 ReportElement::~ReportElement()
@@ -545,12 +546,12 @@ ReportElement::setTaskSorting(int sc, int level)
     {
         if ((sc == CoreAttributesList::TreeMode && level > 0) ||
             !TaskList::isSupportedSortingCriteria(sc & 0xFFFF))
-            return FALSE;
+            return false;
         taskSortCriteria[level] = sc;
     }
     else
-        return FALSE;
-    return TRUE;
+        return false;
+    return true;
 }
 
 bool
@@ -560,12 +561,12 @@ ReportElement::setResourceSorting(int sc, int level)
     {
         if ((sc == CoreAttributesList::TreeMode && level > 0) ||
             !ResourceList::isSupportedSortingCriteria(sc & 0xFFFF))
-            return FALSE;
+            return false;
         resourceSortCriteria[level] = sc;
     }
     else
-        return FALSE;
-    return TRUE;
+        return false;
+    return true;
 }
 
 bool
@@ -575,12 +576,12 @@ ReportElement::setAccountSorting(int sc, int level)
     {
         if ((sc == CoreAttributesList::TreeMode && level > 0) ||
             !AccountList::isSupportedSortingCriteria(sc & 0xFFFF))
-            return FALSE;
+            return false;
         accountSortCriteria[level] = sc;
     }
     else
-        return FALSE;
-    return TRUE;
+        return false;
+    return true;
 }
 
 bool
@@ -594,12 +595,12 @@ ReportElement::isHidden(const CoreAttributes* c, ExpressionTree* et) const
     if (c->getType() == CA_Task && !taskRoot.isEmpty() &&
         taskRoot != c->getId().left(taskRoot.length()))
     {
-        return TRUE;
+        return true;
     }
 
     // If we don't have an ExpressionTree the object is always visible.
     if (!et)
-        return FALSE;
+        return false;
 
     // Pump all flags into the symbol table.
     et->clearSymbolTable();
@@ -607,13 +608,13 @@ ReportElement::isHidden(const CoreAttributes* c, ExpressionTree* et) const
     for (QStringList::Iterator ait = allFlags.begin(); ait != allFlags.end();
          ++ait)
     {
-        bool found = FALSE;
+        bool found = false;
         QStringList flags = c->getFlagList();
         for (QStringList::Iterator it = flags.begin(); it != flags.end(); ++it)
             if (*it == *ait)
             {
                 et->registerSymbol(*it, 1);
-                found = TRUE;
+                found = true;
                 break;
             }
         if (!found)
@@ -632,7 +633,7 @@ ReportElement::isRolledUp(const CoreAttributes* c, ExpressionTree* et) const
     /* If we don't have an ExpressionTree the object's descendants are always
      * visible. */
     if (!et)
-        return FALSE;
+        return false;
 
     // Pump all flags into the symbol table.
     et->clearSymbolTable();
@@ -640,13 +641,13 @@ ReportElement::isRolledUp(const CoreAttributes* c, ExpressionTree* et) const
     for (QStringList::Iterator ait = allFlags.begin(); ait != allFlags.end();
          ++ait)
     {
-        bool found = FALSE;
+        bool found = false;
         QStringList flags = c->getFlagList();
         for (QStringList::Iterator it = flags.begin(); it != flags.end(); ++it)
             if (*it == *ait)
             {
                 et->registerSymbol(*it, 1);
-                found = TRUE;
+                found = true;
                 break;
             }
         if (!found)
@@ -709,18 +710,18 @@ const
     for (TaskListIterator tli(report->getProject()->getTaskListIterator());
          *tli != 0; ++tli)
     {
-        bool resourceLoadedInAnyScenario = FALSE;
+        bool resourceLoadedInAnyScenario = false;
         if (r != 0)
         {
             QValueList<int>::const_iterator it;
             for (it = scenarios.begin(); it != scenarios.end(); ++it)
                 if ((*tli)->isBookedResource(*it, r))
                 {
-                    resourceLoadedInAnyScenario = TRUE;
+                    resourceLoadedInAnyScenario = true;
                     break;
                 }
         }
-        bool taskOverlapsInAnyScenario = FALSE;
+        bool taskOverlapsInAnyScenario = false;
         Interval iv(start, end);
         QValueList<int>::const_iterator it;
         for (it = scenarios.begin(); it != scenarios.end(); ++it)
@@ -730,7 +731,7 @@ const
                                      (*tli)->getStart(*it) :
                                      (*tli)->getEnd(*it))))
             {
-                taskOverlapsInAnyScenario = TRUE;
+                taskOverlapsInAnyScenario = true;
                 break;
             }
 
@@ -741,7 +742,7 @@ const
             filteredList.append(tli);
         }
         if (hideExp && hideExp->getErrorFlag())
-            return FALSE;
+            return false;
     }
     /* In tasktree sorting mode we need to make sure that we don't hide
      * parents of shown tasks. */
@@ -761,7 +762,7 @@ const
     filteredList = list;
 
     if (!rollUpExp)
-        return TRUE;
+        return true;
 
     /* Now we have to remove all sub tasks of rolled-up tasks
      * from the filtered list */
@@ -774,10 +775,10 @@ const
                 if (*tti != *tli)
                     filteredList.removeRef(*tti);
         if (rollUpExp && rollUpExp->getErrorFlag())
-            return FALSE;
+            return false;
     }
 
-    return TRUE;
+    return true;
 }
 
 void
@@ -804,14 +805,14 @@ const
                                   getResourceListIterator());
          *rli != 0; ++rli)
     {
-        bool taskLoadedInAnyScenario = FALSE;
+        bool taskLoadedInAnyScenario = false;
         if (t != 0)
         {
             QValueList<int>::const_iterator it;
             for (it = scenarios.begin(); it != scenarios.end(); ++it)
                 if ((*rli)->isAllocated(*it, Interval(start, end), t) > 0.0)
                 {
-                    taskLoadedInAnyScenario = TRUE;
+                    taskLoadedInAnyScenario = true;
                     break;
                 }
         }
@@ -821,7 +822,7 @@ const
             filteredList.append(*rli);
         }
         if (hideExp && hideExp->getErrorFlag())
-            return FALSE;
+            return false;
     }
 
     /* In resourcetree sorting mode we need to make sure that we don't
@@ -839,7 +840,7 @@ const
     filteredList = list;
 
     if (!rollUpExp)
-        return TRUE;
+        return true;
 
     /* Now we have to remove all sub resources of resource in the
      * roll-up list from the filtered list */
@@ -853,10 +854,10 @@ const
                 if (*rti != *rli)
                     filteredList.removeRef(*rti);
         if (rollUpExp && rollUpExp->getErrorFlag())
-            return FALSE;
+            return false;
     }
 
-    return TRUE;
+    return true;
 }
 
 void
@@ -882,7 +883,7 @@ const
         if (!isHidden(*ali, hideExp) && (*ali)->getAcctType() == at)
             filteredList.append(*ali);
         if (hideExp && hideExp->getErrorFlag())
-            return FALSE;
+            return false;
     }
 
     /* In accounttree sorting mode we need to make sure that we don't hide
@@ -900,7 +901,7 @@ const
     filteredList = list;
 
     if (!rollUpExp)
-        return TRUE;
+        return true;
 
     /* Now we have to remove all sub accounts of account in the roll-up list
      * from the filtered list */
@@ -914,10 +915,10 @@ const
                 if (*ati != *ali)
                     filteredList.removeRef(*ati);
         if (rollUpExp && rollUpExp->getErrorFlag())
-            return FALSE;
+            return false;
     }
 
-    return TRUE;
+    return true;
 }
 
 void
@@ -939,15 +940,9 @@ ReportElement::taskRootLevel() const
 }
 
 void
-ReportElement::errorMessage(const char* msg, ... )
+ReportElement::errorMessage(const QString& msg)
 {
-    va_list ap;
-    va_start(ap, msg);
-    char buf[1024];
-    vsnprintf(buf, 1024, msg, ap);
-    va_end(ap);
-
-    TJMH.errorMessage(buf, defFileName, defFileLine);
+    TJMH.errorMessage(msg, defFileName, defFileLine);
 }
 
 QString
@@ -1011,61 +1006,59 @@ ReportElement::setMacros(TableLineInfo* tli)
                               defFileName, defFileLine));
 
     // Set macros for built-in attributes.
-    mt.addMacro(new Macro(KW("id"), tli->ca1 ? tli->ca1->getId() : QString(),
+    mt.addMacro(new Macro(KW("id"), tli->ca1 ? tli->ca1->getId() :
+                          QString::null,
                           defFileName, defFileLine));
     mt.addMacro(new Macro(KW("no"), tli->ca1 ?
                           QString("%1").arg(tli->ca1->getSequenceNo()) :
-                          QString(),
+                          QString::null,
                           defFileName, defFileLine));
     mt.addMacro(new Macro(KW("index"), tli->ca1 ?
                           QString("%1").arg(tli->ca1->getIndex()) :
-                          QString(),
+                          QString::null,
                           defFileName, defFileLine));
     mt.addMacro(new Macro(KW("hierarchno"), tli->ca1 ?
-                          tli->ca1->getHierarchNo() : QString(),
+                          tli->ca1->getHierarchNo() : QString::null,
                           defFileName, defFileLine));
     mt.addMacro(new Macro(KW("hierarchindex"),
-                          tli->ca1 ? tli->ca1->getHierarchIndex() : QString(),
+                          tli->ca1 ? tli->ca1->getHierarchIndex() :
+                          QString::null,
                           defFileName, defFileLine));
-    mt.addMacro(new Macro(KW("name"), tli->ca1 ? tli->ca1->getName() : QString(),
+    mt.addMacro(new Macro(KW("name"),
+                          tli->ca1 ? tli->ca1->getName() : QString::null,
                           defFileName, defFileLine));
 
-    QPtrList< QDict<CustomAttributeDefinition> > dictList;
-    dictList.setAutoDelete(TRUE);
-    dictList.append(new QDict<CustomAttributeDefinition>
-                    (report->getProject()->getTaskAttributeDict()));
-    dictList.append(new QDict<CustomAttributeDefinition>
-                    (report->getProject()->getResourceAttributeDict()));
-    dictList.append(new QDict<CustomAttributeDefinition>
-                    (report->getProject()->getAccountAttributeDict()));
-
-    for (QPtrListIterator< QDict<CustomAttributeDefinition> >
-         dli(dictList); *dli; ++dli)
-    {
-        QDictIterator<CustomAttributeDefinition> cadi(**dli);
-        for ( ; cadi.current(); ++cadi)
-        {
-            const CustomAttribute* custAttr;
-            QString macroName = cadi.currentKey();
-            QString macroValue;
-            if (tli->ca1 &&
-                (custAttr = tli->ca1->getCustomAttribute(macroName)) != 0)
-            {
-                switch (custAttr->getType())
-                {
-                    case CAT_Text:
-                        macroValue = ((TextAttribute*) custAttr)->getText();
-                        break;
-                    case CAT_Reference:
-                        macroValue = ((ReferenceAttribute*) custAttr)->getURL();
-                        break;
-                    default:
-                        break;
-                }
-            }
-            mt.addMacro(new Macro(macroName, macroValue, defFileName,
-                                  defFileLine));
-        }
-    }
+    setPropertyMacros(tli, report->getProject()->getTaskAttributeDict());
+    setPropertyMacros(tli, report->getProject()->getResourceAttributeDict());
+    setPropertyMacros(tli, report->getProject()->getAccountAttributeDict());
 }
 
+void
+ReportElement::setPropertyMacros(TableLineInfo* tli,
+   const QDictIterator<CustomAttributeDefinition>& d)
+{
+    QDictIterator<CustomAttributeDefinition> cadi(d);
+    for ( ; cadi.current(); ++cadi)
+    {
+        const CustomAttribute* custAttr;
+        QString macroName = cadi.currentKey();
+        QString macroValue;
+        if (tli->ca1 &&
+            (custAttr = tli->ca1->getCustomAttribute(macroName)) != 0)
+        {
+            switch (custAttr->getType())
+            {
+                case CAT_Text:
+                    macroValue = static_cast<const TextAttribute*>(custAttr)->getText();
+                    break;
+                case CAT_Reference:
+                    macroValue = static_cast<const ReferenceAttribute*>(custAttr)->getURL();
+                    break;
+                default:
+                    break;
+            }
+        }
+        mt.addMacro(new Macro(macroName, macroValue, defFileName,
+                              defFileLine));
+    }
+}
