@@ -7,19 +7,13 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: ReportXML.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: ReportXML.h 1428 2007-03-17 15:24:21Z cs $
  */
 
 #ifndef _Report_xml_h_
 #define _Report_xml_h_
 
-#include <stdio.h>
-#include <time.h>
-
-#include <qstring.h>
-#include <qstringlist.h>
 #include <qcolor.h>
-#include <qtextstream.h>
 #include <qdom.h>
 
 #include "Report.h"
@@ -37,9 +31,6 @@ public:
 
    static QDomElement createXMLElem( QDomDocument& doc, const QString& name,
                      const QString& val );
-   
-protected:
-   ReportXML() { }
 } ;
 
 #endif
