@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: Resource.cpp 1373 2007-01-25 15:13:13Z cs $
+ * $Id: Resource.cpp 1497 2007-06-13 07:54:55Z cs $
  */
 
 #include "Resource.h"
@@ -17,19 +17,12 @@
 #include "ResourceTreeIterator.h"
 
 #include "Project.h"
-#include "Interval.h"
-#include "VacationInterval.h"
 #include "ShiftSelection.h"
-#include "Booking.h"
 #include "BookingList.h"
-#include "SbBooking.h"
 #include "Account.h"
-#include "Task.h"
 #include "UsageLimits.h"
 #include "TjMessageHandler.h"
 #include "tjlib-internal.h"
-#include "kotrus.h"
-#include "debug.h"
 #include "ReportXML.h"
 #include "CustomAttributeDefinition.h"
 
@@ -45,30 +38,36 @@ static uint* DayEndIndex = 0;
 static uint* WeekEndIndex = 0;
 static uint* MonthEndIndex = 0;
 
-Resource::Resource(Project* p, const QString& i, const QString& n,
-                   Resource* pr, const QString& df, uint dl)
-    : CoreAttributes(p, i, n, pr, df, dl)
-{
-    sbSize = (p->getEnd() + 1 - p->getStart()) /
-        p->getScheduleGranularity() + 1;
 
-    vacations.setAutoDelete(TRUE);
-    shifts.setAutoDelete(TRUE);
+Resource::Resource(Project* p, const QString& i, const QString& n,
+                   Resource* pr, const QString& df, uint dl) :
+    CoreAttributes(p, i, n, pr, df, dl),
+    minEffort(0.0),
+    journal(),
+    limits(0),
+    efficiency(0.0),
+    rate(0.0),
+    workingHours(),
+    shifts(),
+    vacations(),
+    scoreboard(0),
+    sbSize((p->getEnd() + 1 - p->getStart()) / p->getScheduleGranularity() + 1),
+    specifiedBookings(new SbBooking**[p->getMaxScenarios()]),
+    scoreboards(new SbBooking**[p->getMaxScenarios()]),
+    scenarios(new ResourceScenario[p->getMaxScenarios()]),
+    allocationProbability(new double[p->getMaxScenarios()])
+{
+    vacations.setAutoDelete(true);
+    shifts.setAutoDelete(true);
 
     p->addResource(this);
 
-    limits = 0;
-
-    scenarios = new ResourceScenario[p->getMaxScenarios()];
-    scoreboards = new SbBooking**[p->getMaxScenarios()];
-    specifiedBookings = new SbBooking**[p->getMaxScenarios()];
     for (int sc = 0; sc < p->getMaxScenarios(); sc++)
     {
         scoreboards[sc] = 0;
         specifiedBookings[sc] = 0;
     }
 
-    allocationProbability = new double[p->getMaxScenarios()];
     for (int i = 0; i < p->getMaxScenarios(); ++i)
         allocationProbability[i] = 0;
 
@@ -127,7 +126,7 @@ Resource::Resource(Project* p, const QString& i, const QString& n,
     for (int i = 0; i < 7; i++)
     {
         workingHours[i] = new QPtrList<Interval>();
-        workingHours[i]->setAutoDelete(TRUE);
+        workingHours[i]->setAutoDelete(true);
     }
 }
 
@@ -215,7 +214,7 @@ Resource::inheritValues()
         {
             delete workingHours[i];
             workingHours[i] = new QPtrList<Interval>();
-            workingHours[i]->setAutoDelete(TRUE);
+            workingHours[i]->setAutoDelete(true);
             for (QPtrListIterator<Interval> ivi(*pr->workingHours[i]);
                  *ivi != 0; ++ivi)
                 workingHours[i]->append(new Interval(**ivi));
@@ -246,7 +245,7 @@ Resource::inheritValues()
         {
             delete workingHours[i];
             workingHours[i] = new QPtrList<Interval>();
-            workingHours[i]->setAutoDelete(TRUE);
+            workingHours[i]->setAutoDelete(true);
             for (QPtrListIterator<Interval>
                  ivi(project->getWorkingHoursIterator(i));
                  *ivi != 0; ++ivi)
@@ -283,14 +282,13 @@ Resource::initScoreboard()
         scoreboard[i] = (SbBooking*) 1;
 
     // Then change all worktime slots to 0 (available) again.
-    for (time_t day = project->getStart(); day < project->getEnd() + 1;
-         day += project->getScheduleGranularity())
+    for (time_t t = project->getStart(); t < project->getEnd() + 1;
+         t += project->getScheduleGranularity())
     {
-        if (isOnShift(Interval(day,
-                               day + project->getScheduleGranularity() - 1)))
-            scoreboard[sbIndex(day)] = (SbBooking*) 0;
+        if (isOnShift(Interval(t,
+                               t + project->getScheduleGranularity() - 1)))
+            scoreboard[sbIndex(t)] = (SbBooking*) 0;
     }
-
     // Then mark all resource specific vacation slots as such (2).
     for (QPtrListIterator<Interval> ivi(vacations); *ivi != 0; ++ivi)
         for (time_t date = (*ivi)->getStart() > project->getStart() ?
@@ -300,7 +298,7 @@ Resource::initScoreboard()
             scoreboard[sbIndex(date)] = (SbBooking*) 2;
 
     // Mark all global vacation slots as such (2)
-    for (VacationListIterator ivi(project->getVacationListIterator());
+    for (VacationList::Iterator ivi(project->getVacationListIterator());
          *ivi != 0; ++ivi)
     {
         if ((*ivi)->getStart() > project->getEnd() ||
@@ -469,7 +467,7 @@ Resource::bookSlot(uint idx, SbBooking* nb, int overtime)
     if (scoreboard[idx] > (SbBooking*) overtime)
     {
         delete nb;
-        return FALSE;
+        return false;
     }
 
     SbBooking* b;
@@ -479,7 +477,7 @@ Resource::bookSlot(uint idx, SbBooking* nb, int overtime)
     {
         scoreboard[idx] = b;
         delete nb;
-        return TRUE;
+        return true;
     }
     // Try to merge the booking with the booking in the following slot.
     if (idx < sbSize - 1 && (b = scoreboard[idx + 1]) > (SbBooking*) 3 &&
@@ -487,10 +485,10 @@ Resource::bookSlot(uint idx, SbBooking* nb, int overtime)
     {
         scoreboard[idx] = b;
         delete nb;
-        return TRUE;
+        return true;
     }
     scoreboard[idx] = nb;
-    return TRUE;
+    return true;
 }
 
 bool
@@ -499,7 +497,7 @@ Resource::bookInterval(Booking* nb, int sc, int sloppy, int overtime)
     uint sIdx = sbIndex(nb->getStart());
     uint eIdx = sbIndex(nb->getEnd());
 
-    bool conflict = FALSE;
+    bool conflict = false;
 
     for (uint i = sIdx; i <= eIdx; i++)
         if (scoreboard[i] > (SbBooking*) overtime)
@@ -517,11 +515,10 @@ Resource::bookInterval(Booking* nb, int sc, int sloppy, int overtime)
                 }
                 TJMH.errorMessage
                     (i18n("Error in %1 scenario: "
-                          "%2 has no duty hours at %3 - %4 "
-                          "to be assigned to %5.")
+                          "%2 has no duty hours at %3 "
+                          "to be assigned to %4.")
                      .arg(project->getScenarioId(sc))
                      .arg(id).arg(time2ISO(index2start(i)))
-                     .arg(time2ISO(index2end(j  - 1)))
                      .arg(nb->getTask()->getId().latin1()));
             }
             else if (scoreboard[i] == (SbBooking*) 2)
@@ -533,11 +530,10 @@ Resource::bookInterval(Booking* nb, int sc, int sloppy, int overtime)
                 }
                 TJMH.errorMessage
                     (i18n("Error in %1 scenario: "
-                          "%2 is on vacation at %3 - %4. "
-                          "It cannot be assigned to %5.")
+                          "%2 is on vacation at %3. "
+                          "It cannot be assigned to %4.")
                      .arg(project->getScenarioId(sc))
                      .arg(id).arg(time2ISO(index2start(i)))
-                     .arg(time2ISO(index2end(j - 1)))
                      .arg(nb->getTask()->getId().latin1()));
             }
             else
@@ -549,27 +545,26 @@ Resource::bookInterval(Booking* nb, int sc, int sloppy, int overtime)
                 }
                 TJMH.errorMessage
                     (i18n("Error in %1 scenario: "
-                          "Allocation conflict for %2 at %3 - %4. "
-                          "Conflicting tasks are %5 and %6.")
+                          "Allocation conflict for %2 at %3. "
+                          "Conflicting tasks are %4 and %5.")
                      .arg(project->getScenarioId(sc))
                      .arg(id).arg(time2ISO(index2start(i)))
-                     .arg(time2ISO(index2end(j - 1)))
                      .arg(scoreboard[i]->getTask()->getId().latin1())
                      .arg(nb->getTask()->getId().latin1()));
             }
 
-            conflict = TRUE;
+            conflict = true;
             i = j;
         }
 
     if (conflict)
-        return FALSE;
+        return false;
 
     for (uint i = sIdx; i <= eIdx; i++)
         if (scoreboard[i] <= (SbBooking*) overtime)
             bookSlot(i, new SbBooking(*nb), overtime);
 
-    return TRUE;
+    return true;
 }
 
 bool
@@ -588,6 +583,7 @@ Resource::addBooking(int sc, Booking* nb, int sloppy, int overtime)
     delete nb;
     scoreboards[sc] = scoreboard;
     scoreboard = tmp;
+
     return retVal;
 }
 
@@ -674,9 +670,7 @@ Resource::getCurrentDaySlots(time_t date, const Task* t)
 
     uint sbIdx = sbIndex(date);
 
-    // Now check that the resource is not overloaded on this day.
     uint bookedSlots = 0;
-    uint bookedTaskSlots = 0;
 
     for (uint i = DayStartIndex[sbIdx]; i <= DayEndIndex[sbIdx]; i++)
     {
@@ -684,18 +678,11 @@ Resource::getCurrentDaySlots(time_t date, const Task* t)
         if (b < (SbBooking*) 4)
             continue;
 
-        bookedSlots++;
-        if (b->getTask() == t)
-            bookedTaskSlots++;
-    }
-    // If the current slot is still available we count this as booked as well.
-    if (scoreboard[sbIdx] < ((SbBooking*) 4))
-    {
-        bookedSlots++;
-        bookedTaskSlots++;
+        if (!t || b->getTask() == t)
+            bookedSlots++;
     }
 
-    return t ? bookedTaskSlots : bookedSlots;
+    return bookedSlots;
 }
 
 uint
@@ -718,9 +705,7 @@ Resource::getCurrentWeekSlots(time_t date, const Task* t)
 
     uint sbIdx = sbIndex(date);
 
-    // Now check that the resource is not overloaded on this day.
     uint bookedSlots = 0;
-    uint bookedTaskSlots = 0;
 
     for (uint i = WeekStartIndex[sbIdx]; i <= WeekEndIndex[sbIdx]; i++)
     {
@@ -728,19 +713,11 @@ Resource::getCurrentWeekSlots(time_t date, const Task* t)
         if (b < (SbBooking*) 4)
             continue;
 
-        bookedSlots++;
-        if (b->getTask() == t)
-            bookedTaskSlots++;
+        if (!t || b->getTask() == t)
+            bookedSlots++;
     }
 
-    // If the current slot is still available we count this as booked as well.
-    if (scoreboard[sbIdx] < ((SbBooking*) 4))
-    {
-        bookedSlots++;
-        bookedTaskSlots++;
-    }
-
-    return t ? bookedTaskSlots : bookedSlots;
+    return bookedSlots;
 }
 
 uint
@@ -763,9 +740,7 @@ Resource::getCurrentMonthSlots(time_t date, const Task* t)
 
     uint sbIdx = sbIndex(date);
 
-    // Now check that the resource is not overloaded on this day.
     uint bookedSlots = 0;
-    uint bookedTaskSlots = 0;
 
     for (uint i = MonthStartIndex[sbIdx]; i <= MonthEndIndex[sbIdx]; i++)
     {
@@ -773,26 +748,37 @@ Resource::getCurrentMonthSlots(time_t date, const Task* t)
         if (b < (SbBooking*) 4)
             continue;
 
-        bookedSlots++;
-        if (b->getTask() == t)
-            bookedTaskSlots++;
+        if (!t || b->getTask() == t)
+            bookedSlots++;
     }
 
-    // If the current slot is still available we count this as booked as well.
-    if (scoreboard[sbIdx] < ((SbBooking*) 4))
-    {
-        bookedSlots++;
-        bookedTaskSlots++;
-    }
-
-    return t ? bookedTaskSlots : bookedSlots;
+    return bookedSlots;
 }
 
 double
-Resource::getLoad(int sc, const Interval& period, AccountType acctType,
-                  const Task* task) const
+Resource::getEffectiveLoad(int sc, const Interval& period, AccountType acctType,
+                           const Task* task) const
 {
-    return efficiency * getAllocatedTimeLoad(sc, period, acctType, task);
+    double load = 0.0;
+    Interval iv(period);
+    if (!iv.overlap(Interval(project->getStart(), project->getEnd())))
+        return 0.0;
+
+    if (hasSubs())
+    {
+        for (ResourceListIterator rli(*sub); *rli != 0; ++rli)
+            load += (*rli)->getEffectiveLoad(sc, iv, acctType, task);
+    }
+    else
+    {
+        uint startIdx = sbIndex(iv.getStart());
+        uint endIdx = sbIndex(iv.getEnd());
+        load = project->convertToDailyLoad
+            (getAllocatedSlots(sc, startIdx, endIdx, acctType, task) *
+             project->getScheduleGranularity()) * efficiency;
+    }
+
+    return load;
 }
 
 double
@@ -842,22 +828,30 @@ Resource::getAllocatedSlots(int sc, uint startIdx, uint endIdx,
     if (!scoreboards[sc])
         return bookings;
 
-    if (task && scenarios[sc].firstSlot >= 0 && scenarios[sc].lastSlot >= 0)
+    if (scenarios[sc].firstSlot > 0 && scenarios[sc].lastSlot > 0)
     {
-        /* If the load is to be calculated for a certain task, we check
-         * whether this task is in the resource allocation list. Only then we
-         * calculate the real number of allocated slots. */
-        bool isAllocated = FALSE;
-        for (TaskListIterator tli(scenarios[sc].allocatedTasks); *tli; ++tli)
-            if (task == *tli)
-            {
-                isAllocated = TRUE;
-                break;
-            }
-        if (!isAllocated)
-            return bookings;
-    }
+        if (task)
+        {
+            /* If the load is to be calculated for a certain task, we check
+             * whether this task is in the resource allocation list. Only then
+             * we calculate the real number of allocated slots. */
+            bool isAllocated = false;
+            for (TaskListIterator tli(scenarios[sc].allocatedTasks); *tli;
+                 ++tli)
+                if (task == *tli)
+                {
+                    isAllocated = true;
+                    break;
+                }
+            if (!isAllocated)
+                return bookings;
+        }
 
+        if (startIdx < (uint) scenarios[sc].firstSlot)
+            startIdx = scenarios[sc].firstSlot;
+        if (endIdx > (uint) scenarios[sc].lastSlot)
+            endIdx = scenarios[sc].lastSlot;
+    }
     for (uint i = startIdx; i <= endIdx && i < sbSize; i++)
     {
         SbBooking* b = scoreboards[sc][i];
@@ -875,9 +869,28 @@ Resource::getAllocatedSlots(int sc, uint startIdx, uint endIdx,
 }
 
 double
-Resource::getAvailableWorkLoad(int sc, const Interval& period)
+Resource::getEffectiveFreeLoad(int sc, const Interval& period)
 {
-    return efficiency * getAvailableTimeLoad(sc, period);
+    double load = 0.0;
+    Interval iv(period);
+    if (!iv.overlap(Interval(project->getStart(), project->getEnd())))
+        return 0.0;
+
+    if (hasSubs())
+    {
+        for (ResourceListIterator rli(*sub); *rli != 0; ++rli)
+            load += (*rli)->getEffectiveFreeLoad(sc, iv);
+    }
+    else
+    {
+        uint startIdx = sbIndex(iv.getStart());
+        uint endIdx = sbIndex(iv.getEnd());
+        load = project->convertToDailyLoad
+            (getAvailableSlots(sc, startIdx, endIdx) *
+             project->getScheduleGranularity()) * efficiency;
+    }
+
+    return load;
 }
 
 double
@@ -939,7 +952,7 @@ Resource::isAllocated(int sc, const Interval& period, const QString& prjId)
 {
     Interval iv(period);
     if (!iv.overlap(Interval(project->getStart(), project->getEnd())))
-        return FALSE;
+        return false;
 
     uint startIdx = sbIndex(iv.getStart());
     uint endIdx = sbIndex(iv.getEnd());
@@ -952,7 +965,7 @@ Resource::isAllocated(int sc, const Interval& period, const QString& prjId)
     }
 
     if (endIdx < startIdx)
-        return FALSE;
+        return false;
 
     return isAllocatedSub(sc, startIdx, endIdx, prjId);
 }
@@ -964,19 +977,19 @@ Resource::isAllocatedSub(int sc, uint startIdx, uint endIdx, const QString&
     /* If resource is a group, check members first. */
     for (ResourceListIterator rli(*sub); *rli != 0; ++rli)
         if ((*rli)->isAllocatedSub(sc, startIdx, endIdx, prjId))
-            return TRUE;
+            return true;
 
     if (!scoreboards[sc])
-        return FALSE;
+        return false;
     for (uint i = startIdx; i <= endIdx; i++)
     {
         SbBooking* b = scoreboards[sc][i];
         if (b < (SbBooking*) 4)
             continue;
         if (prjId.isNull() || b->getTask()->getProjectId() == prjId)
-            return TRUE;
+            return true;
     }
-    return FALSE;
+    return false;
 }
 
 bool
@@ -984,7 +997,7 @@ Resource::isAllocated(int sc, const Interval& period, const Task* task) const
 {
     Interval iv(period);
     if (!iv.overlap(Interval(project->getStart(), project->getEnd())))
-        return FALSE;
+        return false;
 
     uint startIdx = sbIndex(iv.getStart());
     uint endIdx = sbIndex(iv.getEnd());
@@ -996,7 +1009,7 @@ Resource::isAllocated(int sc, const Interval& period, const Task* task) const
             endIdx = scenarios[sc].lastSlot;
     }
     if (endIdx < startIdx)
-        return FALSE;
+        return false;
 
     return isAllocatedSub(sc, startIdx, endIdx, task);
 }
@@ -1008,19 +1021,19 @@ Resource::isAllocatedSub(int sc, uint startIdx, uint endIdx, const Task* task)
     /* If resource is a group, check members first. */
     for (ResourceListIterator rli(*sub); *rli != 0; ++rli)
         if ((*rli)->isAllocatedSub(sc, startIdx, endIdx, task))
-            return TRUE;
+            return true;
 
     if (!scoreboards[sc])
-        return FALSE;
+        return false;
     for (uint i = startIdx; i <= endIdx; i++)
     {
         SbBooking* b = scoreboards[sc][i];
         if (b < (SbBooking*) 4)
             continue;
         if (task == 0 || b->getTask() == task)
-            return TRUE;
+            return true;
     }
-    return FALSE;
+    return false;
 }
 
 void
@@ -1062,16 +1075,6 @@ Resource::getProjectIDs(int sc, const Interval& period, const Task* task) const
     return pidStr;
 }
 
-bool
-Resource::dbLoadBookings(const QString& kotrusID,
-                         const QStringList& skipProjectIDs)
-{
-    /* retrieve all bookings _not_ belonging to this project */
-    BookingList blist = project->getKotrus()->loadBookings
-        (kotrusID, skipProjectIDs);
-    return TRUE;
-}
-
 bool
 Resource::hasVacationDay(time_t day) const
 {
@@ -1079,31 +1082,31 @@ Resource::hasVacationDay(time_t day) const
                      sameTimeNextDay(midnight(day)) - 1);
     for (QPtrListIterator<Interval> vli(vacations); *vli != 0; ++vli)
         if ((*vli)->overlaps(fullDay))
-            return TRUE;
+            return true;
 
     if (shifts.isVacationDay(day))
-        return TRUE;
+        return true;
 
-    if (workingHours[dayOfWeek(day, FALSE)]->isEmpty())
-        return TRUE;
+    if (workingHours[dayOfWeek(day, false)]->isEmpty())
+        return true;
 
-    return FALSE;
+    return false;
 }
 
 bool
 Resource::isOnShift(const Interval& slot) const
 {
-    for (ShiftSelectionListIterator ssli(shifts); *ssli != 0; ++ssli)
+    for (ShiftSelectionList::Iterator ssli(shifts); *ssli != 0; ++ssli)
         if ((*ssli)->getPeriod().contains(slot))
             return (*ssli)->getShift()->isOnShift(slot);
 
-    int dow = dayOfWeek(slot.getStart(), FALSE);
+    int dow = dayOfWeek(slot.getStart(), false);
     for (QPtrListIterator<Interval> ivi(*workingHours[dow]); *ivi != 0; ++ivi)
         if ((*ivi)->contains(Interval(secondsOfDay(slot.getStart()),
                                       secondsOfDay(slot.getEnd()))))
-            return TRUE;
+            return true;
 
-    return FALSE;
+    return false;
 }
 
 void
@@ -1240,45 +1243,28 @@ Resource::prepareScenario(int sc)
 {
     copyBookings(sc, specifiedBookings, scoreboards);
     scoreboard = scoreboards[sc];
-    scenarios[sc].allocatedTasks.clear();
 
-    scenarios[sc].firstSlot = -1;
-    scenarios[sc].lastSlot = -1;
+    updateSlotMarks(sc);
 }
 
 void
 Resource::finishScenario(int sc)
 {
     scoreboards[sc] = scoreboard;
-
-    if (!scoreboard)
-        return;
-
-    scenarios[sc].firstSlot = -1;
-    scenarios[sc].lastSlot = -1;
-    /* Create a list of all tasks that the resource is allocated to in this
-     * scenario. */
-    for (uint i = 0; i < sbSize; i++)
-        if (scoreboard[i] > (SbBooking*) 4)
-        {
-            if (scenarios[sc].firstSlot == -1)
-                scenarios[sc].firstSlot = i;
-            scenarios[sc].lastSlot = i;
-            scenarios[sc].addTask(scoreboard[i]->getTask());
-        }
+    updateSlotMarks(sc);
 }
 
 bool
 Resource::bookingsOk(int sc)
 {
     if (scoreboards[sc] == 0)
-        return TRUE;
+        return true;
 
     if (hasSubs())
     {
        TJMH.errorMessage
           (i18n("Group resource '%1' may not have bookings") .arg(id));
-       return FALSE;
+       return false;
     }
 
     for (uint i = 0; i < sbSize; ++i)
@@ -1298,11 +1284,11 @@ Resource::bookingsOk(int sc)
                      .arg(id).arg(scoreboards[sc][i]->getTask()->getId())
                      .arg(time2ISO(start)).arg(time2ISO(tStart))
                      .arg(time2ISO(tEnd)).arg(project->getScenarioId(sc)));
-                return FALSE;
+                return false;
             }
         }
 
-    return TRUE;
+    return true;
 }
 
 void
@@ -1311,10 +1297,30 @@ Resource::addJournalEntry(JournalEntry* entry)
     journal.append(entry);
 }
 
-JournalIterator
+Journal::Iterator
 Resource::getJournalIterator() const
 {
-    return JournalIterator(journal);
+    return Journal::Iterator(journal);
+}
+
+void
+Resource::updateSlotMarks(int sc)
+{
+    scenarios[sc].allocatedTasks.clear();
+    scenarios[sc].firstSlot = -1;
+    scenarios[sc].lastSlot = -1;
+
+    if (scoreboard)
+    {
+        for (uint i = 0; i < sbSize; i++)
+            if (scoreboard[i] > (SbBooking*) 4)
+            {
+                if (scenarios[sc].firstSlot == -1)
+                    scenarios[sc].firstSlot = i;
+                scenarios[sc].lastSlot = i;
+                scenarios[sc].addTask(scoreboard[i]->getTask());
+            }
+    }
 }
 
 QDomElement Resource::xmlIDElement( QDomDocument& doc ) const
