@@ -8,19 +8,12 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: Resource.h 1314 2006-08-11 20:31:18Z cs $
+ * $Id: Resource.h 1497 2007-06-13 07:54:55Z cs $
  */
 #ifndef _Resource_h_
 #define _Resource_h_
 
-#include "time.h"
-
-#include "taskjuggler.h"
-#include "CoreAttributes.h"
-#include "ResourceList.h"
-#include "ShiftSelectionList.h"
 #include "ResourceScenario.h"
-#include "Journal.h"
 
 class Project;
 class Shift;
@@ -39,8 +32,8 @@ class UsageLimits;
  */
 class Resource : public CoreAttributes
 {
-    friend int ResourceList::compareItemsLevel(Resource* r1, Resource* r2,
-                                               int level);
+    friend int ResourceList::compareItemsLevel(CoreAttributes* c1,
+                                               CoreAttributes* c2, int level);
 public:
     Resource(Project* p, const QString& i, const QString& n, Resource* pr,
              const QString& df = QString::null, uint dl = 0);
@@ -50,7 +43,7 @@ public:
 
     virtual CAType getType() const { return CA_Resource; }
 
-    Resource* getParent() const { return (Resource*) parent; }
+    Resource* getParent() const { return static_cast<Resource*>(parent); }
 
     ResourceListIterator getSubListIterator() const
     {
@@ -119,16 +112,24 @@ public:
     uint getCurrentWeekSlots(time_t date, const Task* t);
     uint getCurrentMonthSlots(time_t date, const Task* t);
 
-    double getLoad(int sc, const Interval& i,
-                   AccountType acctType = AllAccounts,
-                   const Task* task = 0) const;
+    /***
+     * Return the load of the resource (and its children) weighted by their
+     * efficiency.
+     */
+    double getEffectiveLoad(int sc, const Interval& i,
+                            AccountType acctType = AllAccounts,
+                             const Task* task = 0) const;
     double getAllocatedTimeLoad(int sc, const Interval& period,
                                 AccountType acctType, const Task* task = 0)
         const;
     long getAllocatedTime(int sc, const Interval& period, AccountType acctType,
                           const Task* task = 0) const;
 
-    double getAvailableWorkLoad(int sc, const Interval& period);
+    /***
+     * Return the unallocated load of the resource and its children wheighted
+     * by their efficiency.
+     */
+    double getEffectiveFreeLoad(int sc, const Interval& period);
     double getAvailableTimeLoad(int sc, const Interval& period);
     long getAvailableTime(int sc, const Interval& period);
 
@@ -148,12 +149,6 @@ public:
     time_t getStartOfFirstSlot(int sc, const Task* task);
     time_t getEndOfLastSlot(int sc, const Task* task);
 
-    void setKotrusId(const QString k) { kotrusId = k; }
-    const QString& getKotrusId() const { return kotrusId; }
-
-    bool dbLoadBookings(const QString& kotrusID,
-                        const QStringList& skipProjectIDs);
-
     QDomElement xmlIDElement( QDomDocument& doc ) const;
 
     void copyBookings(int sc, SbBooking*** srd, SbBooking*** dst);
@@ -182,7 +177,7 @@ public:
 
     bool hasJournal() const { return !journal.isEmpty(); }
 
-    JournalIterator getJournalIterator() const;
+    Journal::Iterator getJournalIterator() const;
 
 private:
     void getPIDs(int sc, const Interval& period, const Task* task,
@@ -201,6 +196,7 @@ private:
                         prjId) const;
     bool isAllocatedSub(int sc, uint startIdx, uint endIdx, const Task* task)
         const;
+    void updateSlotMarks(int sc);
 
     uint sbIndex(time_t date) const;
 
@@ -224,9 +220,6 @@ private:
     /// The daily costs of this resource.
     double rate;
 
-    /// KoTrus ID, ID by which the resource is known to KoTrus.
-    QString kotrusId;
-
     /// The list of standard working or opening hours for the resource.
     QPtrList<Interval>* workingHours[7];
 
