@@ -7,40 +7,23 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: ResourceList.cpp 1259 2006-01-31 12:04:00Z cs $
+ * $Id: ResourceList.cpp 1497 2007-06-13 07:54:55Z cs $
  */
 
-#include <stdio.h>
-
 #include "ResourceList.h"
-#include "debug.h"
+
 #include "TjMessageHandler.h"
-#include "ShiftSelection.h"
-#include "Task.h"
 #include "Resource.h"
 #include "Project.h"
-#include "kotrus.h"
 #include "UsageLimits.h"
 
-ResourceList::ResourceList()
+ResourceList::ResourceList() :
+    CoreAttributesList()
 {
     sorting[0] = CoreAttributesList::TreeMode;
     sorting[1] = CoreAttributesList::IdUp;
 }
 
-int
-ResourceList::compareItems(QCollection::Item i1, QCollection::Item i2)
-{
-    Resource* r1 = static_cast<Resource*>(i1);
-    Resource* r2 = static_cast<Resource*>(i2);
-
-    int res;
-    for (int i = 0; i < CoreAttributesList::maxSortingLevel; ++i)
-        if ((res = compareItemsLevel(r1, r2, i)) != 0)
-            return res;
-    return res;
-}
-
 bool
 ResourceList::isSupportedSortingCriteria(int sc)
 {
@@ -53,17 +36,19 @@ ResourceList::isSupportedSortingCriteria(int sc)
     case MaxEffortDown:
     case RateUp:
     case RateDown:
-    case KotrusIdUp:
-    case KotrusIdDown:
-        return TRUE;
+        return true;
     default:
         return CoreAttributesList::isSupportedSortingCriteria(sc);
-    }       
+    }
 }
 
 int
-ResourceList::compareItemsLevel(Resource* r1, Resource* r2, int level)
+ResourceList::compareItemsLevel(CoreAttributes* c1, CoreAttributes* c2,
+                                int level)
 {
+    Resource* r1 = static_cast<Resource*>(c1);
+    Resource* r2 = static_cast<Resource*>(c2);
+
     if (level < 0 || level >= maxSortingLevel)
         return -1;
 
@@ -77,24 +62,20 @@ ResourceList::compareItemsLevel(Resource* r1, Resource* r2, int level)
                 r1->getSequenceNo() < r2->getSequenceNo() ? -1 : 1;
     case MinEffortUp:
         return r1->minEffort == r2->minEffort ? 0 :
-            r1->minEffort < r2->minEffort ? 1 : -1;
+            r1->minEffort < r2->minEffort ? -1 : 1;
     case MinEffortDown:
         return r1->minEffort == r2->minEffort ? 0 :
-            r1->minEffort < r2->minEffort ? -1 : 1;
+            r1->minEffort < r2->minEffort ? 1 : -1;
     case MaxEffortUp:
         return r1->limits->getDailyMax() == r2->limits->getDailyMax() ? 0 :
-            r1->limits->getDailyMax() < r2->limits->getDailyMax() ? 1 : -1;
+            r1->limits->getDailyMax() < r2->limits->getDailyMax() ? -1 : 1;
     case MaxEffortDown:
         return r1->limits->getDailyMax() == r2->limits->getDailyMax() ? 0 :
-            r1->limits->getDailyMax() < r2->limits->getDailyMax() ? -1 : 1;
+            r1->limits->getDailyMax() < r2->limits->getDailyMax() ? 1 : -1;
     case RateUp:
-        return r1->rate == r2->rate ? 0 : r1->rate < r2->rate ? 1 : -1;
-    case RateDown:
         return r1->rate == r2->rate ? 0 : r1->rate < r2->rate ? -1 : 1;
-    case KotrusIdUp:
-        return r2->kotrusId.compare(r1->kotrusId);
-    case KotrusIdDown:
-        return r1->kotrusId.compare(r2->kotrusId);
+    case RateDown:
+        return r1->rate == r2->rate ? 0 : r1->rate < r2->rate ? 1 : -1;
     default:
         return CoreAttributesList::compareItemsLevel(r1, r2, level);
     }
