@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: ResourceList.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: ResourceList.h 1420 2007-02-23 02:51:52Z cs $
  */
 
 #ifndef _ResourceList_h_
@@ -31,24 +31,25 @@ public:
     Resource* getResource(const QString& id) const;
 
     static bool isSupportedSortingCriteria(int sc);
-    
-    virtual int compareItemsLevel(Resource* r1, Resource* r2, int level);
 
-protected:
-    virtual int compareItems(QCollection::Item i1, QCollection::Item i2);
+    virtual int compareItemsLevel(CoreAttributes* c1, CoreAttributes* c2,
+                                  int level);
 } ;
 
 /**
  * @short Iterator class for ResourceList objects.
  * @author Chris Schlaeger <cs@kde.org>
  */
-class ResourceListIterator : public virtual CoreAttributesListIterator 
+class ResourceListIterator : public virtual CoreAttributesListIterator
 {
 public:
     ResourceListIterator(const CoreAttributesList& l) :
-        CoreAttributesListIterator(l) { }
+        CoreAttributesListIterator(l)
+    { }
+
     ~ResourceListIterator() { }
-    Resource* operator*() { return (Resource*) get(); }
+
+    Resource* operator*() { return static_cast<Resource*>(get()); }
 } ;
 
 #endif
