@@ -7,13 +7,12 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: ResourceScenario.h 1214 2005-11-17 20:05:36Z cs $
+ * $Id: ResourceScenario.h 1408 2007-02-18 21:55:37Z cs $
  */
 
 #ifndef _ResourceScenario_h_
 #define _ResourceScenario_h_
 
-#include "TaskList.h"
 #include "Task.h"
 
 class ResourceScenario
@@ -21,10 +20,12 @@ class ResourceScenario
     friend class Resource;
 
 public:
-    ResourceScenario()
-    {
-        firstSlot = lastSlot = -1;
-    }
+    ResourceScenario() :
+        allocatedTasks(),
+        firstSlot(-1),
+        lastSlot(-1)
+    { }
+
     ~ResourceScenario() { }
 
     void addTask(const Task* t)
