@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: ResourceTreeIterator.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: ResourceTreeIterator.h 1420 2007-02-23 02:51:52Z cs $
  */
 
 #ifndef _ResourceTreeIterator_h_
@@ -23,10 +23,10 @@ public:
         : T(r, m) { }
     virtual ~ResourceTreeIteratorT() { }
 
-    R* operator*() { return (R*) T::current; }
+    R* operator*() { return static_cast<R*>(T::current); }
     R* operator++()
     {
-        return (R*) T::operator++();
+        return static_cast<R*>(T::operator++());
     }
 } ;
 
