@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: SbBooking.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: SbBooking.h 1396 2007-02-15 19:17:18Z cs $
  */
 #ifndef _SbBooking_h_
 #define _SbBooking_h_
@@ -26,7 +26,7 @@ public:
     SbBooking(Task* t)
         : task(t) { }
     SbBooking(const SbBooking* b) { task = b->task; }
-    ~SbBooking() { }
+    virtual ~SbBooking() { }
 
     Task* getTask() const { return task; }
 
