@@ -7,16 +7,21 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: Scenario.cpp 1262 2006-02-03 13:06:24Z cs $
+ * $Id: Scenario.cpp 1492 2007-06-05 13:17:18Z cs $
  */
 
 #include "Scenario.h"
-#include "ScenarioList.h"
 #include "Project.h"
 
 Scenario::Scenario(Project* p, const QString& i, const QString& n,
-                   Scenario* pr)
-    : CoreAttributes(p, i, n, pr)
+                   Scenario* pr) :
+    CoreAttributes(p, i, n, pr),
+    enabled(true),
+    projectionMode(false),
+    strictBookings(false),
+    optimize(false),
+    minSlackRate(0.05),
+    maxPaths(10000000)
 {
     p->addScenario(this);
     if (pr)
@@ -27,14 +32,7 @@ Scenario::Scenario(Project* p, const QString& i, const QString& n,
         optimize = pr->optimize;
         strictBookings = pr->strictBookings;
         minSlackRate = pr->minSlackRate;
-    }
-    else
-    {
-        enabled = true;
-        projectionMode = false;
-        optimize = false;
-        strictBookings = false;
-        minSlackRate = 0.0;
+        maxPaths = pr->maxPaths;
     }
 }
 
