@@ -7,29 +7,23 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: ScenarioList.cpp 1259 2006-01-31 12:04:00Z cs $
+ * $Id: ScenarioList.cpp 1428 2007-03-17 15:24:21Z cs $
  */
 
 #include "ScenarioList.h"
 #include "Scenario.h"
 
-ScenarioList::ScenarioList()
+ScenarioList::ScenarioList() :
+    CoreAttributesList()
 {
     sorting[0] = CoreAttributesList::TreeMode;
     sorting[1] = CoreAttributesList::IdUp;
 }
 
-int
-ScenarioList::compareItems(QCollection::Item i1, QCollection::Item i2)
+Scenario*
+ScenarioList::operator[](int i)
 {
-    Scenario* r1 = static_cast<Scenario*>(i1);
-    Scenario* r2 = static_cast<Scenario*>(i2);
-
-    int res;
-    for (int i = 0; i < CoreAttributesList::maxSortingLevel; ++i)
-        if ((res = compareItemsLevel(r1, r2, i)) != 0)
-            return res;
-    return res;
+    return static_cast<Scenario*>(at(i));
 }
 
 bool
@@ -38,15 +32,19 @@ ScenarioList::isSupportedSortingCriteria(int sc)
     switch (sc)
     {
     case TreeMode:
-        return TRUE;
+        return true;
     default:
         return CoreAttributesList::isSupportedSortingCriteria(sc);
-    }       
+    }
 }
 
 int
-ScenarioList::compareItemsLevel(Scenario* r1, Scenario* r2, int level)
+ScenarioList::compareItemsLevel(CoreAttributes* c1, CoreAttributes* c2,
+                                int level)
 {
+    Scenario* r1 = static_cast<Scenario*>(c1);
+    Scenario* r2 = static_cast<Scenario*>(c2);
+
     if (level < 0 || level >= maxSortingLevel)
         return -1;
 
