@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: ScenarioList.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: ScenarioList.h 1420 2007-02-23 02:51:52Z cs $
  */
 
 #ifndef _ScenarioList_h_
@@ -31,29 +31,27 @@ public:
     Scenario* getScenario(const QString& id) const;
 
     static bool isSupportedSortingCriteria(int sc);
-    
-    virtual int compareItemsLevel(Scenario* r1, Scenario* r2, int level);
 
-    virtual Scenario* operator[](int i)
-    {
-        return (Scenario*) at(i);
-    }
+    virtual int compareItemsLevel(CoreAttributes* c1, CoreAttributes* c2,
+                                  int level);
 
-protected:
-    virtual int compareItems(QCollection::Item i1, QCollection::Item i2);
+    virtual Scenario* operator[](int i);
 } ;
 
 /**
  * @short Iterator class for ScenarioList objects.
  * @author Chris Schlaeger <cs@kde.org>
  */
-class ScenarioListIterator : public virtual CoreAttributesListIterator 
+class ScenarioListIterator : public virtual CoreAttributesListIterator
 {
 public:
     ScenarioListIterator(const CoreAttributesList& l) :
-        CoreAttributesListIterator(l) { }
+        CoreAttributesListIterator(l)
+    { }
+
     ~ScenarioListIterator() { }
-    Scenario* operator*() { return (Scenario*) get(); }
+
+    Scenario* operator*() { return static_cast<Scenario*>(get()); }
 } ;
 
 #endif
