@@ -8,7 +8,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: Shift.h 1312 2006-07-22 14:28:45Z cs $
+ * $Id: Shift.h 1428 2007-03-17 15:24:21Z cs $
  */
 #ifndef _Shift_h_
 #define _Shift_h_
@@ -35,7 +35,7 @@ public:
 
     virtual CAType getType() const { return CA_Shift; }
 
-    Shift* getParent() const { return (Shift*) parent; }
+    Shift* getParent() const { return static_cast<Shift*>(parent); }
 
     ShiftListIterator getSubListIterator() const;
 
@@ -57,8 +57,6 @@ public:
     bool isVacationDay(time_t day) const;
 
 private:
-    Shift() { }     // Don't use this.
-
     QPtrList<Interval>* workingHours[7];
 };
 
