@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: ShiftList.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: ShiftList.h 1420 2007-02-23 02:51:52Z cs $
  */
 
 #ifndef _ShiftList_h_
@@ -35,10 +35,8 @@ public:
 
     Shift* getShift(const QString& id) const;
 
-    virtual int compareItemsLevel(Shift* s1, Shift* s2, int level);
-
-protected:
-    virtual int compareItems(QCollection::Item i1, QCollection::Item i2);
+    virtual int compareItemsLevel(CoreAttributes* c1, CoreAttributes* c2,
+                                  int level);
 } ;
 
 /**
@@ -46,13 +44,13 @@ protected:
  * @see ShiftList
  * @author Chris Schlaeger <cs@kde.org>
  */
-class ShiftListIterator : public virtual CoreAttributesListIterator 
+class ShiftListIterator : public virtual CoreAttributesListIterator
 {
 public:
     ShiftListIterator(const CoreAttributesList& l) :
         CoreAttributesListIterator(l) { }
     virtual ~ShiftListIterator() { }
-    Shift* operator*() { return (Shift*) get(); }
+    Shift* operator*() { return static_cast<Shift*>(get()); }
 } ;
 
 #endif
