@@ -7,15 +7,15 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: ShiftSelection.cpp 1259 2006-01-31 12:04:00Z cs $
+ * $Id: ShiftSelection.cpp 1416 2007-02-21 09:30:56Z cs $
  */
-#include "ShiftSelection.h"
-#include "Interval.h"
 
-ShiftSelection::ShiftSelection(const ShiftSelection& sl)
+#include "ShiftSelection.h"
+
+ShiftSelection::ShiftSelection(const ShiftSelection& sl) :
+    period(new Interval(*sl.period)),
+    shift(sl.shift)
 {
-    period = new Interval(*sl.period);
-    shift = sl.shift;
 }
 
 bool
