@@ -7,18 +7,16 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: ShiftSelection.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: ShiftSelection.h 1428 2007-03-17 15:24:21Z cs $
  */
 #ifndef _ShiftSelection_h_
 #define _ShiftSelection_h_
 
-#include <time.h>
-
-class ShiftSelectionList;
-
 #include "Shift.h"
 #include "Interval.h"
 
+class ShiftSelectionList;
+
 /**
  * @short Stores shift selection related information.
  * @author Chris Schlaeger <cs@kde.org>
@@ -29,9 +27,17 @@ class ShiftSelection
 
 public:
     ShiftSelection(const Interval& p, Shift* s) :
-        period(new Interval(p)), shift(s) { }
-    ShiftSelection(Interval* p, Shift* s) : period(p), shift(s) { }
+        period(new Interval(p)),
+        shift(s)
+    { }
+
+    ShiftSelection(Interval* p, Shift* s) :
+        period(p),
+        shift(s)
+    { }
+
     ShiftSelection(const ShiftSelection& sl);
+
     ~ShiftSelection()
     {
         delete period;
@@ -43,8 +49,6 @@ public:
     bool isVacationDay(time_t day) const;
 
 private:
-    ShiftSelection() { period = 0; }
-
     Interval* period;
     Shift* shift;
 };
