@@ -7,15 +7,11 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: ShiftSelectionList.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: ShiftSelectionList.h 1408 2007-02-18 21:55:37Z cs $
  */
 #ifndef _ShiftSelectionList_h_
 #define _ShiftSelectionList_h_
 
-#include <time.h>
-
-#include <qptrlist.h>
-
 #include "ShiftSelection.h"
 
 class Interval;
@@ -28,7 +24,9 @@ class ShiftSelectionList : public QPtrList<ShiftSelection>
 {
 public:
     ShiftSelectionList() { }
-    virtual ~ShiftSelectionList() { } 
+    virtual ~ShiftSelectionList() { }
+
+    typedef QPtrListIterator<ShiftSelection> Iterator;
 
     bool insert(ShiftSelection* s);
 
@@ -41,17 +39,5 @@ private:
     virtual int compareItems(QCollection::Item i1, QCollection::Item i2);
 };
 
-/**
- * @short Iterator for ShiftSelectionList objects.
- * @author Chris Schlaeger <cs@kde.org>
- */
-class ShiftSelectionListIterator : public QPtrListIterator<ShiftSelection>
-{
-public:
-    ShiftSelectionListIterator(const ShiftSelectionList& s) :
-        QPtrListIterator<ShiftSelection>(s) { }
-    virtual ~ShiftSelectionListIterator() { }
-} ;
-
 #endif
 
