@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: TableCellInfo.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: TableCellInfo.h 1428 2007-03-17 15:24:21Z cs $
  */
 
 #ifndef _TableCellInfo_h_
@@ -22,9 +22,22 @@ class TableCellInfo
 public:
     TableCellInfo(TableColumnFormat* tcf_, TableLineInfo* tli_,
                   TableColumnInfo* tci_) :
-        tcf(tcf_), tli(tli_), tci(tci_), rows(1), columns(1),
-        rightPadding(-1), leftPadding(-1),
-        boldText(FALSE), fontFactor(100) { }
+        tcf(tcf_),
+        tli(tli_),
+        tci(tci_),
+        rows(1),
+        columns(1),
+        rightPadding(-1),
+        leftPadding(-1),
+        hAlign(),
+        bgColor(),
+        boldText(false),
+        fontFactor(100),
+        statusText(),
+        toolTipID(),
+        toolTipText()
+    { }
+
     ~TableCellInfo() { }
 
     void setRows(int r) { rows = r; }
