@@ -7,14 +7,12 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: TableColumnFormat.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: TableColumnFormat.h 1428 2007-03-17 15:24:21Z cs $
  */
 
 #ifndef _TableColumnFormat_h_
 #define _TableColumnFormat_h_
 
-#include <qstring.h>
-
 #include "RealFormat.h"
 
 class ReportElement;
@@ -65,8 +63,6 @@ public:
     const QString& getId() const { return id; }
 
 protected:
-    TableColumnFormat() { }
-
     QString id;
     ReportElement* el;
     QString title;
