@@ -7,15 +7,18 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: TableColumnInfo.cpp 1259 2006-01-31 12:04:00Z cs $
+ * $Id: TableColumnInfo.cpp 1401 2007-02-16 16:52:24Z cs $
  */
 
 #include "TableColumnInfo.h"
+#include "ExpressionTree.h"
 
 TableColumnInfo::~TableColumnInfo()
 {
     delete [] sum;
     delete [] memory;
+    delete hideCellText;
+    delete hideCellURL;
 }
 
 void
