@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: TableColumnInfo.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: TableColumnInfo.h 1428 2007-03-17 15:24:21Z cs $
  */
 
 #ifndef _TableColumnInfo_h_
@@ -25,15 +25,25 @@ class ExpressionTree;
 class TableColumnInfo
 {
 public:
-    TableColumnInfo(uint sc, const QString& n) : name(n)
+    TableColumnInfo(uint sc, const QString& n) :
+        name(n),
+        maxScenarios(sc),
+        title(),
+        titleURL(),
+        subTitle(),
+        subTitleURL(),
+        cellText(),
+        cellURL(),
+        hideCellText(0),
+        hideCellURL(0),
+        sum(0),
+        memory(0),
+        subColumns(0)
     {
-        hideCellText = hideCellURL = 0;
-        sum = memory = 0;
-        maxScenarios = sc;
-        subColumns = 0;
         clearSum();
         clearMemory();
     }
+
     ~TableColumnInfo();
 
     const QString& getName() const { return name; }
@@ -90,9 +100,6 @@ protected:
     QMap<QString, double>* memory;
 
     uint subColumns;
-
-private:
-    TableColumnInfo() { }
 } ;
 
 #endif
