@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: TableLineInfo.h 1314 2006-08-11 20:31:18Z cs $
+ * $Id: TableLineInfo.h 1428 2007-03-17 15:24:21Z cs $
  */
 
 #ifndef _TableLineInfo_h_
@@ -23,18 +23,21 @@ class TableLineInfo
     friend class ReportElement;
 
 public:
-    TableLineInfo()
-    {
-        row = 0;
-        sc = 0;
-        ca1 = ca2 = 0;
-        task = 0;
-        resource = 0;
-        account = 0;
-        idxNo = 0;
-        boldText = FALSE;
-        fontFactor = 100;
-    }
+    TableLineInfo() :
+        row(0),
+        sc(0),
+        ca1(0),
+        ca2(0),
+        task(0),
+        resource(0),
+        account(0),
+        idxNo(0),
+        bgCol(),
+        boldText(false),
+        fontFactor(100),
+        specialName()
+    { }
+
     ~TableLineInfo() { }
 
     int row;
