@@ -8,7 +8,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: Task.h 1370 2007-01-14 15:54:54Z cs $
+ * $Id: Task.h 1497 2007-06-13 07:54:55Z cs $
  */
 
 #ifndef _Task_h_
@@ -18,18 +18,11 @@
 
 #include <stdarg.h>
 
-#include <qptrlist.h>
-#include <qdict.h>
-#include <qstring.h>
-#include <qstringlist.h>
 #include <qdom.h>
 
-#include "taskjuggler.h"
 #include "debug.h"
 #include "TaskList.h"
 #include "TaskScenario.h"
-#include "ResourceList.h"
-#include "CoreAttributes.h"
 #include "ShiftSelectionList.h"
 #include "LoopDetectorInfo.h"
 #include "TaskDependency.h"
@@ -57,7 +50,8 @@ class UsageLimits;
  */
 class Task : public CoreAttributes
 {
-    friend int TaskList::compareItemsLevel(Task*, Task*, int);
+    friend int TaskList::compareItemsLevel(CoreAttributes*, CoreAttributes*,
+                                           int);
 
 public:
     Task(Project* prj, const QString& id_, const QString& n, Task* p,
@@ -66,7 +60,7 @@ public:
 
     virtual CAType getType() const { return CA_Task; }
 
-    Task* getParent() const { return (Task*) parent; }
+    Task* getParent() const { return static_cast<Task*>(parent); }
 
     TaskListIterator getSubListIterator() const
     {
@@ -87,7 +81,7 @@ public:
 
     bool hasJournal() const { return !journal.isEmpty(); }
 
-    JournalIterator getJournalIterator() const;
+    Journal::Iterator getJournalIterator() const;
 
     void setReference(const QString& r, const QString& l)
     {
@@ -106,7 +100,7 @@ public:
     void setResponsible(Resource* r) { responsible = r; }
     Resource* getResponsible() const { return responsible; }
 
-    void setMilestone(bool ms = TRUE) { milestone = ms; }
+    void setMilestone(bool ms = true) { milestone = ms; }
     bool isMilestone() const { return milestone; }
 
     void setAccount(Account* a) { account = a; }
@@ -239,7 +233,7 @@ public:
     double getCalcDuration(int sc) const;
 
     double getCredits(int sc, const Interval& period, AccountType acctType,
-                      const Resource* resource = 0, bool recursive = TRUE)
+                      const Resource* resource = 0, bool recursive = true)
         const;
 
     bool isActive(int sc, const Interval& period) const;
@@ -297,7 +291,7 @@ public:
     void finishScenario(int sc);
     void computeCriticalness(int sc);
     double getCriticalness(int sc) const { return scenarios[sc].criticalness; }
-    void checkAndMarkCriticalPath(int sc, double minSlack);
+    void checkAndMarkCriticalPath(int sc, double minSlack, time_t maxEnd);
 
     void computePathCriticalness(int sc);
     double getPathCriticalness(int sc) const
@@ -318,18 +312,16 @@ public:
         return scenarios[sc].criticalLinks.containsRef(t);
     }
 
-    bool hasExtraValues(int sc) const;
-
     bool isContainer() const { return !sub->isEmpty(); }
 
-    bool xRef(QDict<Task>& hash, int& errors, int& warnings);
+    bool xRef(QDict<Task>& hash);
     void implicitXRef();
     void sortAllocations();
     void saveSpecifiedBookedResources();
     QString resolveId(QString relId);
 
     bool preScheduleOk(int sc);
-    bool scheduleOk(int sc, int& errors, int& warnings) const;
+    bool scheduleOk(int sc) const;
     /**
      * Checks for loops in task interdependencies starting with the current
      * task.
@@ -344,8 +336,6 @@ public:
     time_t nextSlot(time_t slotDuration) const;
     bool isReadyForScheduling() const;
     bool schedule(int sc, time_t& reqStart, time_t duration);
-    void propagateStart(int sc, bool safeMode = TRUE);
-    void propagateEnd(int sc, bool safeMode = TRUE);
     void propagateInitialValues(int sc);
     void setRunaway();
     bool isRunaway() const;
@@ -354,14 +344,14 @@ public:
 
     bool isSchedulingDone() const { return schedulingDone; }
 
-    void errorMessage(const char*, ...) const;
-    void warningMessage(const char*, ...) const;
+    void errorMessage(const QString& msg) const;
+    void warningMessage(const QString& msg) const;
 
     QDomElement xmlElement( QDomDocument& doc, bool absId = true );
 
-    void loadFromXML( QDomElement& parent, Project *p );
-    void allocationFromXML( const QDomElement& );
 private:
+    void propagateStart(int sc, time_t date);
+    void propagateEnd(int sc, time_t date);
     /**
      * Checks for loops in task interdependencies starting with the current
      * task under ASAP or ALAP scheduling.
@@ -371,13 +361,13 @@ private:
      * @retval false otherwise.
      */
     bool loopDetection(LDIList& list, LDIList& chkedTaskList, bool atEnd,
-                       LoopDetectorInfo::FromWhere caller) const;
+                       bool fromOutside) const;
     bool checkPathForLoops(LDIList& list, bool atEnd) const;
-    bool scheduleContainer(int sc, bool safeMode);
+    bool scheduleContainer(int sc);
     Task* subFirst() { return (Task*) sub->first(); }
     Task* subNext() { return (Task*) sub->next(); }
     bool bookResource(Resource* r, time_t day, time_t duration,
-                      int& availability);
+                      int& slotsToLimit, int& availability);
     void bookResources(int sc, time_t day, time_t duration);
     void addBookedResource(Resource* r)
     {
@@ -400,7 +390,9 @@ private:
     double computeBackwardCriticalness(int sc);
     double computeForwardCriticalness(int sc);
 
-    bool analyzePath(int sc, double minSlack, time_t pathStart, long busyTime);
+    bool analyzePath(int sc, double minSlack, time_t pathStart, long busyTime,
+                     long worstMinSlackTime, long& checked, long& found);
+    void collectTransientFollowers(TaskList& list);
 
     bool countMilestones(int sc, time_t now, int& totalMilestones,
                          int& completedMilestones,
@@ -519,7 +511,7 @@ private:
     double doneDuration;
 
     /**
-     * Set to TRUE when the first time slots have with resource usage
+     * Set to true when the first time slots have with resource usage
      * have been allocated. */
     bool workStarted;
 
