@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: TaskDependency.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: TaskDependency.h 1428 2007-03-17 15:24:21Z cs $
  */
 
 #ifndef _TaskDependency_h_
@@ -47,10 +47,9 @@ public:
     long getGapLengthNR(int sc) const { return gapLength[sc]; }
 
 private:
-    TaskDependency() { }    // Don't use this!
     /**
-     * When we read in the project file, we don't know all functions yet. So
-     * we need to store the ID of the dependency and later resolve this to the
+     * When we read in the project file, we don't know all tasks yet. So we
+     * need to store the ID of the dependency and later resolve this to the
      * pointer to the Task.
      */
     QString taskRefId;
