@@ -7,10 +7,9 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: TaskList.cpp 1344 2006-10-19 01:17:51Z cs $
+ * $Id: TaskList.cpp 1497 2007-06-13 07:54:55Z cs $
  */
 #include "TaskList.h"
-#include "Task.h"
 #include "Resource.h"
 
 Task*
@@ -45,15 +44,18 @@ TaskList::isSupportedSortingCriteria(int sc)
     case CriticalnessDown:
     case PathCriticalnessUp:
     case PathCriticalnessDown:
-        return TRUE;
+        return true;
     default:
         return CoreAttributesList::isSupportedSortingCriteria(sc);
     }
 }
 
 int
-TaskList::compareItemsLevel(Task* t1, Task* t2, int level)
+TaskList::compareItemsLevel(CoreAttributes* c1, CoreAttributes* c2, int level)
 {
+    Task* t1 = static_cast<Task*>(c1);
+    Task* t2 = static_cast<Task*>(c2);
+
     if (level < 0 || level >= maxSortingLevel)
         return -1;
 
@@ -101,14 +103,18 @@ TaskList::compareItemsLevel(Task* t1, Task* t2, int level)
          * slightly different from other processors. To get identical
          * results on all CPUs we ignore some precision that we don't need
          * anyhow. */
-        int cd1 = (int) (t1->getCompletionDegree(sortScenario) * 1000);
-        int cd2 = (int) (t2->getCompletionDegree(sortScenario) * 1000);
+        int cd1 = static_cast<int> (t1->getCompletionDegree(sortScenario) *
+                                    1000);
+        int cd2 = static_cast<int> (t2->getCompletionDegree(sortScenario) *
+                                    1000);
         return cd1 == cd2 ? 0 : cd1 < cd2 ? -1 : 1;
     }
     case CompletedDown:
     {
-        int cd1 = (int) (t1->getCompletionDegree(sortScenario) * 1000);
-        int cd2 = (int) (t2->getCompletionDegree(sortScenario) * 1000);
+        int cd1 = static_cast<int> (t1->getCompletionDegree(sortScenario) *
+                                    1000);
+        int cd2 = static_cast<int> (t2->getCompletionDegree(sortScenario) *
+                                    1000);
         return cd1 == cd2 ? 0 : cd1 > cd2 ? -1 : 1;
     }
     case PrioUp:
@@ -172,17 +178,3 @@ TaskList::compareItemsLevel(Task* t1, Task* t2, int level)
     }
 }
 
-int
-TaskList::compareItems(QCollection::Item i1, QCollection::Item i2)
-{
-    Task* t1 = static_cast<Task*>(i1);
-    Task* t2 = static_cast<Task*>(i2);
-
-    int res;
-    for (int i = 0; i < CoreAttributesList::maxSortingLevel; ++i)
-        if ((res = compareItemsLevel(t1, t2, i)) != 0)
-            return res;
-    return res;
-}
-
-
