@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: TaskTreeIterator.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: TaskTreeIterator.h 1420 2007-02-23 02:51:52Z cs $
  */
 
 #ifndef _TaskTreeIterator_h_
@@ -22,10 +22,10 @@ public:
         : CoreAttributesTreeIterator(r, m) { }
     virtual ~TaskTreeIterator() { }
 
-    Task* operator*() { return (Task*) current; }
+    Task* operator*() { return static_cast<Task*>(current); }
     Task* operator++()
     {
-        return (Task*) CoreAttributesTreeIterator::operator++();
+        return static_cast<Task*>(CoreAttributesTreeIterator::operator++());
     }
 } ;
 
