@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: TextAttribute.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: TextAttribute.h 1410 2007-02-20 08:34:27Z cs $
  */
 #ifndef _TextAttribute_h_
 #define _TextAttribute_h_
@@ -23,13 +23,21 @@
 class TextAttribute : public CustomAttribute
 {
 public:
-    TextAttribute() { }
+    TextAttribute() :
+        CustomAttribute(),
+        text()
+    { }
+
     TextAttribute(const TextAttribute& ta) :
-        CustomAttribute(ta)
-    {
-        text = ta.text;
-    }
-    TextAttribute(const QString& t) { text = t; }
+        CustomAttribute(ta),
+        text(ta.text)
+    { }
+
+    TextAttribute(const QString& t) :
+        CustomAttribute(),
+        text(t)
+    { }
+
     virtual ~TextAttribute() { }
 
     CustomAttributeType getType() const { return CAT_Text; }
