@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: TransactionList.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: TransactionList.h 1428 2007-03-17 15:24:21Z cs $
  */
 #ifndef _TransactionList_h_
 #define _TransactionList_h_
@@ -25,8 +25,12 @@ class Transaction
 {
     friend class TransactionList;
 public:
-    Transaction(time_t d, double a, const QString& descr)
-        : date(d), amount(a), description(descr) { }
+    Transaction(time_t d, double a, const QString& descr) :
+        date(d),
+        amount(a),
+        description(descr)
+    { }
+
     ~Transaction() { }
 
     time_t getDate() { return date; }
@@ -34,7 +38,6 @@ public:
     const QString& getDescription() { return description; }
 
 private:
-    Transaction() { }   // dont use this
     /// The moment when the transaction happened.
     time_t date;
     /// The amount deposited or withdrawn.
@@ -52,21 +55,12 @@ class TransactionList : public QPtrList<Transaction>
 public:
     TransactionList() { }
     virtual ~TransactionList() { }
+
+    typedef QPtrListIterator<Transaction> Iterator;
+
 protected:
     virtual int compareItems(QCollection::Item i1, QCollection::Item i2);
 } ;
 
-/**
- * @short Iterator for TransactionList objects.
- * @author Chris Schlaeger <cs@kde.org>
- */
-class TransactionListIterator : public QPtrListIterator<Transaction>
-{
-public:
-    TransactionListIterator(const TransactionList& t) :
-        QPtrListIterator<Transaction>(t) {}
-    virtual ~TransactionListIterator() { }
-} ;
-
 #endif
 
