@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: UsageLimits.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: UsageLimits.h 1410 2007-02-20 08:34:27Z cs $
  */
 
 #ifndef _UsageLimits_h_
@@ -25,10 +25,12 @@
 class UsageLimits
 {
     public:
-        UsageLimits()
-        {
-            dailyMax = weeklyMax = monthlyMax = 0;
-        }
+        UsageLimits() :
+            dailyMax(0),
+            weeklyMax(0),
+            monthlyMax(0)
+        { }
+
         ~UsageLimits() { }
 
         void setDailyMax(uint m) { dailyMax = m; }
