@@ -7,21 +7,29 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: Utility.cpp 1365 2007-01-10 12:55:41Z cs $
+ * $Id: Utility.cpp 1498 2007-06-20 08:21:49Z cs $
  */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
+#include "Utility.h"
+
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
+
+#include <string>
 
 #include <qdict.h>
 
 #include "TjMessageHandler.h"
 #include "tjlib-internal.h"
-#include "Utility.h"
+
+#if defined(__SVR4) && defined(__sun)
+int setenv(const char* var, const char* val, int ignore);
+int unsetenv (const char *var);
+#endif
 
 static QDict<const char> TZDict;
-static bool TZDictReady = FALSE;
+static bool TZDictReady = false;
 
 static QString UtilityError;
 
@@ -45,21 +53,21 @@ isRichText(const QString& str)
      * not. It looks for xml tags marks and does a simple validation on them.
      */
 
-    bool hasTags = FALSE;
-    bool inTag = FALSE;
+    bool hasTags = false;
+    bool inTag = false;
     for (uint i = 0; i < str.length(); ++i)
     {
         if (str[i] == '<')
         {
             if (inTag)
-                return FALSE;
-            inTag = hasTags = TRUE;
+                return false;
+            inTag = hasTags = true;
         }
         else if (str[i] == '>')
         {
             if (!inTag)
-                return FALSE;
-            inTag = FALSE;
+                return false;
+            inTag = false;
         }
     }
 
@@ -71,9 +79,10 @@ timezone2tz(const char* tzone)
 {
     if (!TZDictReady)
     {
-        TZDict.setAutoDelete(FALSE);
+        TZDict.setAutoDelete(false);
 
         // Let's start with generic timezones
+        TZDict.insert("+1300", "GMT-13:00");
         TZDict.insert("+1200", "GMT-12:00");
         TZDict.insert("+1100", "GMT-11:00");
         TZDict.insert("+1000", "GMT-10:00");
@@ -113,7 +122,7 @@ timezone2tz(const char* tzone)
         TZDict.insert("CET", "GMT-1:00");
         TZDict.insert("CEDT", "GMT-2:00");
 
-        TZDictReady = TRUE;
+        TZDictReady = true;
     }
 
     return TZDict[tzone];
@@ -147,7 +156,6 @@ void exitUtility()
         {
             LtHashTabEntry* tmp = htep->next;
             delete htep->tms;
-            delete htep;
             htep = tmp;
         }
 
@@ -164,14 +172,16 @@ setTimezone(const char* tZone)
         qFatal("Ran out of space in environment section while "
                "setting timezone.");
 
-    /* To valide the tZone value we call tzset(). It will convert the zone
+    /* To validate the tZone value we call tzset(). It will convert the zone
      * into a three-letter acronym in case the tZone value is good. If not, it
-     * will just copy the wrong value to tzname[0]. So, we need to validate
-     * tZone names that are already 3 letter acronyms first. timezone2tz can
-     * do this for us. */
+     * will just copy the wrong value to tzname[0] (glibc < 2.5) or fall back
+     * to UTC. */
     tzset();
-    if (timezone2tz(tZone) == 0 && strcmp(tZone, tzname[0]) == 0)
+    if (timezone2tz(tZone) == 0 &&
+        (strcmp(tzname[0], tZone) == 0 ||
+         (strcmp(tZone, "UTC") != 0 && strcmp(tzname[0], "UTC") == 0)))
     {
+        qDebug("1: %s, 2: %s", tzname[0], tzname[1]);
         UtilityError = QString(i18n("Illegal timezone '%1'")).arg(tZone);
         return false;
     }
@@ -184,7 +194,6 @@ setTimezone(const char* tZone)
         {
             LtHashTabEntry* tmp = htep->next;
             delete htep->tms;
-            delete htep;
             htep = tmp;
         }
         if (LtHashTab[i])
@@ -193,7 +202,7 @@ setTimezone(const char* tZone)
     return true;
 }
 
-const struct tm*
+const struct tm * const
 clocaltime(const time_t* t)
 {
     /* In some cases we haven't initialized the module yet. So we do not use
@@ -700,16 +709,6 @@ time2tjp(time_t t)
     return QString::fromLocal8Bit(buf);
 }
 
-QString
-time2rfc(time_t t)
-{
-    const struct tm* tms = clocaltime(&t);
-    static char buf[128];
-
-    strftime(buf, 127, "%Y-%m-%d-%H:%M:%S-%z", tms);
-    return QString::fromLocal8Bit(buf);
-}
-
 QString
 time2user(time_t t, const QString& timeFormat, bool localtime)
 {
@@ -782,8 +781,8 @@ date2time(const QString& date)
 
     int y, m, d, hour, min, sec;
     char tZone[64] = "";
-    char* savedTZ = 0;
-    bool restoreTZ = FALSE;
+    std::string savedTZ;
+    bool restoreTZ = false;
     if (sscanf(date, "%d-%d-%d-%d:%d:%d-%s",
                &y, &m, &d, &hour, &min, &sec, tZone) == 7 ||
         (sec = 0) ||    // set sec to 0
@@ -793,8 +792,7 @@ date2time(const QString& date)
         const char* tz;
         if ((tz = getenv("TZ")) != 0)
         {
-            savedTZ = new char[strlen(tz) + 1];
-            strcpy(savedTZ, tz);
+            savedTZ = tz;
         }
         if ((tz = timezone2tz(tZone)) == 0)
         {
@@ -805,7 +803,7 @@ date2time(const QString& date)
         {
             if (setenv("TZ", tz, 1) < 0)
                 qFatal("date2time: Ran out of space in environment section.");
-            restoreTZ = TRUE;
+            restoreTZ = true;
         }
     }
     else if (sscanf(date, "%d-%d-%d-%d:%d:%d",
@@ -867,11 +865,10 @@ date2time(const QString& date)
 
     if (restoreTZ)
     {
-        if (savedTZ)
+        if (!savedTZ.empty())
         {
-            if (setenv("TZ", savedTZ, 1) < 0)
+            if (setenv("TZ", savedTZ.c_str(), 1) < 0)
                 qFatal("date2time: Ran out of space in environment section.");
-            delete [] savedTZ;
         }
         else
             unsetenv("TZ");
@@ -894,7 +891,7 @@ int setenv(const char* var, const char* val, int ignore)
    int valLen = strlen(val);
    char *buffer = NULL;
 
-   if ((buffer = (char*) malloc (varLen + valLen + 2)) == NULL)
+   if ((buffer = static_cast<char*> malloc(varLen + valLen + 2)) == NULL)
       return -1;
 
    sprintf (buffer, "%s=%s", var, val);
