@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: Utility.h 1303 2006-07-05 20:21:20Z cs $
+ * $Id: Utility.h 1439 2007-03-18 17:00:09Z cs $
  */
 
 #ifndef _Utility_h_
@@ -16,9 +16,9 @@
 #include <time.h>
 #include <qstring.h>
 
-#define MAXTIME 0x7FFFFFFF
-#define ONEDAY (60 * 60 * 24)
-#define ONEHOUR (60 * 60)
+const int MAXTIME = 0x7FFFFFFF;
+const int ONEDAY = 60 * 60 * 24;
+const int ONEHOUR = 60 * 60;
 
 void initUtility(long dizeSize);
 
@@ -142,9 +142,7 @@ QString time2ISO(time_t t);
 
 QString time2tjp(time_t t);
 
-QString time2rfc(time_t t);
-
-QString time2user(time_t t, const QString& timeFormat, bool localtime = TRUE);
+QString time2user(time_t t, const QString& timeFormat, bool localtime = true);
 
 QString time2time(time_t t);
 
