@@ -7,13 +7,11 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: VacationInterval.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: VacationInterval.h 1410 2007-02-20 08:34:27Z cs $
  */
 #ifndef _VacationInterval_h_
 #define _VacationInterval_h_
 
-#include <qstring.h>
-
 #include "Interval.h"
 
 /**
@@ -23,9 +21,16 @@
 class VacationInterval : public Interval
 {
 public:
-    VacationInterval() { }
-    VacationInterval(const QString& n, const Interval& i)
-        : Interval(i), name(n) { }
+    VacationInterval() :
+        Interval(),
+        name()
+    { }
+
+    VacationInterval(const QString& n, const Interval& i) :
+        Interval(i),
+        name(n)
+    { }
+
     virtual ~VacationInterval() { }
 
     void setStart(time_t s) { start = s; }
