@@ -7,11 +7,10 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: VacationList.cpp 1310 2006-07-20 14:24:09Z cs $
+ * $Id: VacationList.cpp 1428 2007-03-17 15:24:21Z cs $
  */
 
 #include "VacationList.h"
-#include "VacationInterval.h"
 
 void
 VacationList::add(const QString& name, const Interval& i)
@@ -45,17 +44,17 @@ VacationList::compareItems(QCollection::Item it1, QCollection::Item it2)
 bool
 VacationList::isVacation(time_t date) const
 {
-    for (VacationListIterator vli(*this); *vli != 0; ++vli)
+    for (VacationList::Iterator vli(*this); *vli != 0; ++vli)
         if ((*vli)->contains(date))
-            return TRUE;
+            return true;
 
-    return FALSE;
+    return false;
 }
 
 const QString&
 VacationList::vacationName(time_t date) const
 {
-    for (VacationListIterator vli(*this); *vli != 0; ++vli)
+    for (VacationList::Iterator vli(*this); *vli != 0; ++vli)
         if ((*vli)->contains(date))
             return (*vli)->getName();
 
