@@ -7,16 +7,13 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: VacationList.h 1310 2006-07-20 14:24:09Z cs $
+ * $Id: VacationList.h 1428 2007-03-17 15:24:21Z cs $
  */
 
 #ifndef _VacationList_h_
 #define _VacationList_h_
 
-#include "time.h"
-
 #include <qptrlist.h>
-#include <qstring.h>
 
 #include "VacationInterval.h"
 
@@ -29,9 +26,11 @@ class Interval;
 class VacationList : public QPtrList<VacationInterval>
 {
 public:
-    VacationList() { setAutoDelete(TRUE); }
+    VacationList() { setAutoDelete(true); }
     virtual ~VacationList() {}
 
+    typedef QPtrListIterator<VacationInterval> Iterator;
+
     void add(const QString& name, const Interval& i);
     void add(VacationInterval* vi);
     bool isVacation(time_t date) const;
@@ -41,16 +40,4 @@ protected:
     virtual int compareItems(QCollection::Item i1, QCollection::Item i2);
 } ;
 
-/**
- * @short Iterator for VacationList objects.
- * @author Chris Schlaeger <cs@kde.org>
- */
-class VacationListIterator : public QPtrListIterator<VacationInterval>
-{
-public:
-    VacationListIterator(const VacationList& l) :
-        QPtrListIterator<VacationInterval>(l) { }
-    virtual ~VacationListIterator() { }
-} ;
-
 #endif
