@@ -8,31 +8,21 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: XMLFile.cpp 1271 2006-03-02 17:03:48Z cs $
+ * $Id: XMLFile.cpp 1497 2007-06-13 07:54:55Z cs $
  */
 
-#include <stdio.h>
+#include "XMLFile.h"
+
 #include <unistd.h>
 #include <zlib.h>
 
-#include <qdom.h>
 #include <qtextstream.h>
 
 #include "tjlib-internal.h"
-#include "debug.h"
 #include "ParserNode.h"
-#include "ParserElement.h"
 #include "ParserTreeContext.h"
 #include "Project.h"
-#include "Utility.h"
-#include "Scenario.h"
-#include "Shift.h"
-#include "Resource.h"
-#include "Account.h"
-#include "Task.h"
-#include "TaskScenario.h"
 #include "Allocation.h"
-#include "VacationInterval.h"
 #include "Booking.h"
 #include "CustomAttributeDefinition.h"
 #include "ReferenceAttribute.h"
@@ -41,12 +31,12 @@
 ParserNode* XMLFile::parserRootNode = 0;
 
 XMLFile::XMLFile(Project* p) :
-    project(p)
+    masterFile(),
+    project(p),
+    doc()
 {
     if (!parserRootNode)
         createParseTree();
-
-    doc = 0;
 }
 
 XMLFile::~XMLFile()
@@ -152,6 +142,7 @@ XMLFile::createParseTree()
             {
                 accountNode->add(pe, "account"); // recursive link
                 new ParserElement("flag", &XMLFile::doFlag, accountNode);
+                createSubTreeCustomAttribute(accountNode);
             }
         }
 
@@ -303,22 +294,22 @@ XMLFile::readDOM(const QString& file, const QString&, const QString&,
     {
         if ((zf = gzdopen(dup(STDIN_FILENO), "rb")) == NULL)
         {
-            qWarning(i18n("Cannot open compressed STDIN for reading."));
-            return FALSE;
+            tjWarning(i18n("Cannot open compressed STDIN for reading."));
+            return false;
         }
     }
     else
     {
         if ((zf = gzopen(file, "rb")) == NULL)
         {
-            qWarning(i18n("Cannot open compressed file %1 for "
+            tjWarning(i18n("Cannot open compressed file %1 for "
                           "reading.").arg(file));
-            return FALSE;
+            return false;
         }
     }
 
     if (DEBUGLEVEL > 0)
-        qWarning(i18n("Processing file \'%1\'").arg(file));
+        tjWarning(i18n("Processing file \'%1\'").arg(file));
 
     QString buf;
     while (!gzeof(zf))
@@ -330,19 +321,19 @@ XMLFile::readDOM(const QString& file, const QString&, const QString&,
     int zError;
     if ((zError = gzclose(zf)) != 0)
     {
-        qWarning(i18n("Cannot close compressed file %1: %2")
+        tjWarning(i18n("Cannot close compressed file %1: %2")
                  .arg(file).arg(gzerror(zf, &zError)));
-        return FALSE;
+        return false;
     }
 
     doc = new QDomDocument(file);
     if (!doc->setContent(buf))
     {
-        qWarning(i18n("Syntax error in XML file '%1'.").arg(file));
-        return FALSE;
+        tjWarning(i18n("Syntax error in XML file '%1'.").arg(file));
+        return false;
     }
 
-    return TRUE;
+    return true;
 }
 
 bool
@@ -359,7 +350,7 @@ XMLFile::parse()
 bool
 XMLFile::parseNode(const ParserNode* pn, QDomNode n, ParserTreeContext ptc)
 {
-    bool ret = TRUE;
+    bool ret = true;
 
     while (!n.isNull())
     {
@@ -369,8 +360,8 @@ XMLFile::parseNode(const ParserNode* pn, QDomNode n, ParserTreeContext ptc)
             const ParserElement* pEl = pn->getElement(el.tagName());
             if (!pEl)
             {
-                qWarning(i18n("Unsupported XML element %1").arg(el.tagName()));
-                ret = FALSE;
+                tjWarning(i18n("Unsupported XML element %1").arg(el.tagName()));
+                ret = false;
             }
             else
             {
@@ -382,18 +373,18 @@ XMLFile::parseNode(const ParserNode* pn, QDomNode n, ParserTreeContext ptc)
                  * and pass it the ptc. */
                 if (pEl->getPreFunc())
                     if (!((*this).*(pEl->getPreFunc()))(n, ptcCopy))
-                        return FALSE;
+                        return false;
                 /* If sub-elements of this node have been defined in the
                  * parse tree, call this function again to process the
                  * sub-elements. */
                 if (pEl->getNode())
                     if (!parseNode(pEl->getNode(), n.firstChild(), ptcCopy))
-                        return FALSE;
+                        return false;
                 /* If a node post function has been specified, call this
                  * function and pass it the ptc. */
                 if (pEl->getPostFunc())
                     if (!((*this).*(pEl->getPostFunc()))(n, ptcCopy))
-                        return FALSE;
+                        return false;
             }
         }
         n = n.nextSibling();
@@ -405,7 +396,7 @@ XMLFile::parseNode(const ParserNode* pn, QDomNode n, ParserTreeContext ptc)
 bool
 XMLFile::doTaskJuggler(QDomNode&, ParserTreeContext&)
 {
-    return TRUE;
+    return true;
 }
 
 bool
@@ -439,28 +430,28 @@ XMLFile::doProject(QDomNode& n, ParserTreeContext& ptc)
 
     ptc.setScenario(0);
 
-    return TRUE;
+    return true;
 }
 
 bool
 XMLFile::doProjectStart(QDomNode& n, ParserTreeContext&)
 {
     project->setStart(n.toElement().text().toLong());
-    return TRUE;
+    return true;
 }
 
 bool
 XMLFile::doProjectEnd(QDomNode& n, ParserTreeContext&)
 {
     project->setEnd(n.toElement().text().toLong() - 1);
-    return TRUE;
+    return true;
 }
 
 bool
 XMLFile::doProjectNow(QDomNode& n, ParserTreeContext&)
 {
     project->setNow(n.toElement().text().toLong());
-    return TRUE;
+    return true;
 }
 
 bool
@@ -476,7 +467,7 @@ XMLFile::doScenario(QDomNode& n, ParserTreeContext& ptc)
                                       el.attribute("name"), ptc.getScenario());
     ptc.setScenario(scenario);
 
-    return TRUE;
+    return true;
 }
 
 bool
@@ -488,14 +479,14 @@ XMLFile::doCurrencyFormat(QDomNode& n, ParserTreeContext&)
         (RealFormat(el.attribute("signPrefix"), el.attribute("signSuffix"),
                     el.attribute("thousandSep"), el.attribute("fractionSep"),
                     el.attribute("fracDigits").toInt()));
-    return TRUE;
+    return true;
 }
 
 bool
 XMLFile::doExtend(QDomNode& n, ParserTreeContext& ptc)
 {
     ptc.setExtendProperty(n.toElement().attribute("property"));
-    return TRUE;
+    return true;
 }
 
 bool
@@ -512,17 +503,19 @@ XMLFile::doExtendAttribute(QDomNode& n, ParserTreeContext& ptc)
         new CustomAttributeDefinition(el.attribute("name"), cat);
     if (!ca)
     {
-        qWarning(i18n("Unknown custom attribute %1")
+        tjWarning(i18n("Unknown custom attribute %1")
                  .arg(el.attribute("name")));
-        return FALSE;
+        return false;
     }
     ca->setInherit(el.attribute("inherit").toInt());
     if (ptc.getExtendProperty() == "task")
         project->addTaskAttribute(el.attribute("id"), ca);
     else if (ptc.getExtendProperty() == "resource")
         project->addResourceAttribute(el.attribute("id"), ca);
+    else if (ptc.getExtendProperty() == "account")
+        project->addAccountAttribute(el.attribute("id"), ca);
 
-    return TRUE;
+    return true;
 }
 
 bool
@@ -596,21 +589,21 @@ XMLFile::doTimeInterval(QDomNode&, ParserTreeContext& ptc)
     ptc.getWorkingHours()->append(iv);
     ptc.setInterval(iv);
 
-    return TRUE;
+    return true;
 }
 
 bool
 XMLFile::doTimeIntervalStart(QDomNode& n, ParserTreeContext& ptc)
 {
     ptc.getInterval()->setStart(n.toElement().text().toLong());
-    return TRUE;
+    return true;
 }
 
 bool
 XMLFile::doTimeIntervalEnd(QDomNode& n, ParserTreeContext& ptc)
 {
     ptc.getInterval()->setEnd(n.toElement().text().toLong() - 1);
-    return TRUE;
+    return true;
 }
 
 bool
@@ -621,7 +614,7 @@ XMLFile::doProjectVacation(QDomNode& n, ParserTreeContext& ptc)
     vi->setName(el.attribute("name"));
     ptc.setVacationInterval(vi);
     project->addVacation(vi);
-    return TRUE;
+    return true;
 }
 
 bool
@@ -631,14 +624,14 @@ XMLFile::doResourceVacation(QDomNode& n, ParserTreeContext& ptc)
     Interval* vi = new Interval();
     ptc.setInterval(vi);
     ptc.getResource()->addVacation(vi);
-    return TRUE;
+    return true;
 }
 
 bool
 XMLFile::doCustomAttribute(QDomNode& n, ParserTreeContext& ptc)
 {
     ptc.setExtendProperty(n.toElement().attribute("id"));
-    return TRUE;
+    return true;
 }
 
 bool
@@ -648,7 +641,7 @@ XMLFile::doTextAttribute(QDomNode& n, ParserTreeContext& ptc)
     TextAttribute* ta =
         new TextAttribute(el.attribute("text"));
     ptc.getCoreAttributes()->addCustomAttribute(ptc.getExtendProperty(), ta);
-    return TRUE;
+    return true;
 }
 
 bool
@@ -658,14 +651,14 @@ XMLFile::doReferenceAttribute(QDomNode& n, ParserTreeContext& ptc)
     ReferenceAttribute* ra =
         new ReferenceAttribute(el.attribute("url"), el.attribute("label"));
     ptc.getCoreAttributes()->addCustomAttribute(ptc.getExtendProperty(), ra);
-    return TRUE;
+    return true;
 }
 
 bool
 XMLFile::doShiftList(QDomNode&, ParserTreeContext& ptc)
 {
     ptc.setShift(0);
-    return TRUE;
+    return true;
 }
 
 bool
@@ -682,14 +675,14 @@ XMLFile::doShift(QDomNode& n, ParserTreeContext& ptc)
     for (int i = 0; i < 7; ++i)
         shift->setWorkingHours(i, iv);
 
-    return TRUE;
+    return true;
 }
 
 bool
 XMLFile::doResourceList(QDomNode&, ParserTreeContext& ptc)
 {
     ptc.setResource(0);
-    return TRUE;
+    return true;
 }
 
 bool
@@ -707,7 +700,7 @@ XMLFile::doResource(QDomNode& n, ParserTreeContext& ptc)
 
     ptc.setResource(r);
 
-    return TRUE;
+    return true;
 }
 
 bool
@@ -720,14 +713,14 @@ XMLFile::doShiftSelection(QDomNode& n, ParserTreeContext& ptc)
         (iv, project->getShift(n.toElement().attribute("shiftId")));
     ptc.getResource()->addShift(ss);
 
-    return TRUE;
+    return true;
 }
 
 bool
 XMLFile::doAccountList(QDomNode&, ParserTreeContext& ptc)
 {
     ptc.setAccount(0);
-    return TRUE;
+    return true;
 }
 
 bool
@@ -742,14 +735,14 @@ XMLFile::doAccount(QDomNode& n, ParserTreeContext& ptc)
                              Cost : Revenue);
     ptc.setAccount(a);
 
-    return TRUE;
+    return true;
 }
 
 bool
 XMLFile::doTaskList(QDomNode&, ParserTreeContext& ptc)
 {
     ptc.setTask(0);
-    return TRUE;
+    return true;
 }
 
 bool
@@ -771,7 +764,7 @@ XMLFile::doTask(QDomNode& n, ParserTreeContext& ptc)
     if (!el.attribute("account").isEmpty())
         t->setAccount(project->getAccount(el.attribute("account")));
 
-    return TRUE;
+    return true;
 }
 
 bool
@@ -790,7 +783,7 @@ XMLFile::doTaskScenario(QDomNode& n, ParserTreeContext& ptc)
      * read in. */
     t->setStatusNote(sc, el.attribute("statusNote", ""));
 
-    return TRUE;
+    return true;
 }
 
 bool
@@ -798,7 +791,7 @@ XMLFile::doTaskScenarioStart(QDomNode& n, ParserTreeContext& ptc)
 {
     ptc.getTask()->setSpecifiedStart(ptc.getScenarioIndex(),
                                      n.toElement().text().toLong());
-    return TRUE;
+    return true;
 }
 
 bool
@@ -806,7 +799,7 @@ XMLFile::doTaskScenarioEnd(QDomNode& n, ParserTreeContext& ptc)
 {
     ptc.getTask()->setSpecifiedEnd(ptc.getScenarioIndex(),
                                    n.toElement().text().toLong() - 1);
-    return TRUE;
+    return true;
 }
 
 bool
@@ -814,7 +807,7 @@ XMLFile::doTaskScenarioMaxEnd(QDomNode& n, ParserTreeContext& ptc)
 {
     ptc.getTask()->setMaxEnd(ptc.getScenarioIndex(),
                              n.toElement().text().toLong() - 1);
-    return TRUE;
+    return true;
 }
 
 bool
@@ -822,7 +815,7 @@ XMLFile::doTaskScenarioMinEnd(QDomNode& n, ParserTreeContext& ptc)
 {
     ptc.getTask()->setMinEnd(ptc.getScenarioIndex(),
                              n.toElement().text().toLong() - 1);
-    return TRUE;
+    return true;
 }
 
 bool
@@ -830,7 +823,7 @@ XMLFile::doTaskScenarioMaxStart(QDomNode& n, ParserTreeContext& ptc)
 {
     ptc.getTask()->setMaxStart(ptc.getScenarioIndex(),
                                n.toElement().text().toLong());
-    return TRUE;
+    return true;
 }
 
 bool
@@ -838,7 +831,7 @@ XMLFile::doTaskScenarioMinStart(QDomNode& n, ParserTreeContext& ptc)
 {
     ptc.getTask()->setMinStart(ptc.getScenarioIndex(),
                                n.toElement().text().toLong());
-    return TRUE;
+    return true;
 }
 
 bool
@@ -848,7 +841,7 @@ XMLFile::doAllocate(QDomNode&, ParserTreeContext& ptc)
     ptc.getTask()->addAllocation(a);
     ptc.setAllocation(a);
 
-    return TRUE;
+    return true;
 }
 
 bool
@@ -858,7 +851,7 @@ XMLFile::doCandidate(QDomNode& n, ParserTreeContext& ptc)
     ptc.getAllocation()->addCandidate
         (project->getResource(el.attribute("resourceId")));
 
-    return TRUE;
+    return true;
 }
 
 bool
@@ -868,7 +861,7 @@ XMLFile::doFlag(QDomNode& n, ParserTreeContext& ptc)
 
     ptc.getCoreAttributes()->addFlag(el.text());
 
-    return TRUE;
+    return true;
 }
 
 bool
@@ -876,7 +869,7 @@ XMLFile::doDepends(QDomNode& n, ParserTreeContext& ptc)
 {
     ptc.setTaskDependency
         (ptc.getTask()->addDepends(n.toElement().text()));
-    return TRUE;
+    return true;
 }
 
 bool
@@ -884,7 +877,7 @@ XMLFile::doPrecedes(QDomNode& n, ParserTreeContext& ptc)
 {
     ptc.setTaskDependency
         (ptc.getTask()->addPrecedes(n.toElement().text()));
-    return TRUE;
+    return true;
 }
 
 bool
@@ -897,14 +890,14 @@ XMLFile::doDependencyGapScenario(QDomNode& n, ParserTreeContext& ptc)
     ptc.getTaskDependency()->setGapLength
         (sc, el.attribute("gapLength", "0").toLong());
 
-    return TRUE;
+    return true;
 }
 
 bool
 XMLFile::doNote(QDomNode& n, ParserTreeContext& ptc)
 {
     ptc.getTask()->setNote(n.toElement().text());
-    return TRUE;
+    return true;
 }
 
 bool
@@ -914,20 +907,20 @@ XMLFile::doResourceBooking(QDomNode& n, ParserTreeContext& ptc)
     Resource* resource = project->getResource(el.attribute("resourceId"));
     if (!resource)
     {
-        qWarning(i18n("Booking for unknown resource %1")
+        tjWarning(i18n("Booking for unknown resource %1")
                  .arg(el.attribute("resourceId")));
-        return FALSE;
+        return false;
     }
     ptc.setResource(resource);
     int sc = project->getScenarioIndex(el.attribute("scenarioId")) - 1;
     if (sc < 0)
     {
-        qWarning(i18n("Booking for unknown scenario %1")
+        tjWarning(i18n("Booking for unknown scenario %1")
                  .arg(el.attribute("scenarioId")));
-        return FALSE;
+        return false;
     }
     ptc.setScenarioIndex(sc);
-    return TRUE;
+    return true;
 }
 
 bool
@@ -935,7 +928,7 @@ XMLFile::doBooking(QDomNode&, ParserTreeContext& ptc)
 {
     Interval* iv = new Interval();
     ptc.setInterval(iv);
-    return TRUE;
+    return true;
 }
 
 bool
@@ -944,13 +937,13 @@ XMLFile::doBookingPost(QDomNode& n, ParserTreeContext& ptc)
     Task* t = project->getTask(n.toElement().attribute("taskId"));
     if (!t)
     {
-        qWarning(i18n("Booking for unknown task %1")
+        tjWarning(i18n("Booking for unknown task %1")
                  .arg(n.toElement().attribute("taskId")));
-        return FALSE;
+        return false;
     }
     ptc.getResource()->addBooking(ptc.getScenarioIndex(),
                                   new Booking(ptc.getInterval(), t));
 
-    return TRUE;
+    return true;
 }
 
