@@ -8,7 +8,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: XMLFile.h 1271 2006-03-02 17:03:48Z cs $
+ * $Id: XMLFile.h 1428 2007-03-17 15:24:21Z cs $
  */
 
 #ifndef _XMLFile_h_
@@ -16,8 +16,6 @@
 
 #include <time.h>
 
-#include <qstring.h>
-
 #include "ParserElement.h"
 
 class Project;
@@ -53,7 +51,7 @@ public:
      * This is a file, that is not included by any other file.
      */
     bool readDOM(const QString& file, const QString& parentPath,
-                 const QString& taskPrefix, bool masterfile = FALSE);
+                 const QString& taskPrefix, bool masterfile = false);
 
     /**
      * Calling the parse function will start the processing of the DOM tree
