@@ -7,29 +7,20 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: XMLReport.cpp 1312 2006-07-22 14:28:45Z cs $
+ * $Id: XMLReport.cpp 1497 2007-06-13 07:54:55Z cs $
  */
 
 #include "XMLReport.h"
 
-#include <config.h>
 #include <zlib.h>
 
-#include <qfile.h>
 #include <qmap.h>
-#include <qdom.h>
 
 #include "tjlib-internal.h"
-#include "taskjuggler.h"
 #include "Project.h"
 #include "Scenario.h"
-#include "VacationList.h"
-#include "VacationInterval.h"
-#include "Shift.h"
-#include "ShiftSelection.h"
-#include "Task.h"
+#include "Account.h"
 #include "Resource.h"
-#include "Booking.h"
 #include "BookingList.h"
 #include "Allocation.h"
 #include "XMLReport.h"
@@ -39,8 +30,6 @@
 #include "TextAttribute.h"
 #include "ReferenceAttribute.h"
 
-#define KW(a) a
-
 static QMap<QString, int> TaskAttributeDict;
 typedef enum TADs {
     TA_UNDEFINED = 0,
@@ -58,12 +47,16 @@ typedef enum TADs {
     TA_PRIORITY,
     TA_RESPONSIBLE,
     TA_STATUS,
-    TA_STATUSNOTE
+    TA_STATUSNOTE,
+    TA_ACCOUNT
 };
 
 XMLReport::XMLReport(Project* p, const QString& f,
                            const QString& df, int dl) :
-    Report(p, f, df, dl)
+    Report(p, f, df, dl),
+    doc(0),
+    accountAttributes(),
+    taskAttributes()
 {
     if (TaskAttributeDict.empty())
     {
@@ -82,24 +75,25 @@ XMLReport::XMLReport(Project* p, const QString& f,
         TaskAttributeDict[KW("responsible")] = TA_RESPONSIBLE;
         TaskAttributeDict[KW("status")] = TA_STATUS;
         TaskAttributeDict[KW("statusnote")] = TA_STATUSNOTE;
+        TaskAttributeDict[KW("account")] = TA_ACCOUNT;
     }
     // show all tasks
     hideTask = new ExpressionTree(new Operation(0));
     // show all resources
     hideResource = new ExpressionTree(new Operation(0));
+    // show all accounts
+    hideAccount = new ExpressionTree(new Operation(0));
 
     taskSortCriteria[0] = CoreAttributesList::TreeMode;
     taskSortCriteria[1] = CoreAttributesList::StartUp;
     taskSortCriteria[2] = CoreAttributesList::EndUp;
     resourceSortCriteria[0] = CoreAttributesList::TreeMode;
     resourceSortCriteria[1] = CoreAttributesList::IdUp;
+    accountSortCriteria[0] = CoreAttributesList::TreeMode;
+    accountSortCriteria[1] = CoreAttributesList::IdUp;
 
     // All XML reports default to just showing the first scenario.
     scenarios.append(0);
-
-    doc = 0;
-
-    masterFile = FALSE;
 }
 
 XMLReport::~XMLReport()
@@ -111,7 +105,7 @@ bool
 XMLReport::generate()
 {
     if (!open())
-        return FALSE;
+        return false;
 
     doc = new QDomDocument
         ("taskjuggler PUBLIC "
@@ -136,51 +130,58 @@ XMLReport::generate()
 
     TaskList filteredTaskList;
     if (!filterTaskList(filteredTaskList, 0, hideTask, rollUpTask))
-        return FALSE;
+        return false;
     sortTaskList(filteredTaskList);
 
     ResourceList filteredResourceList;
     if (!filterResourceList(filteredResourceList, 0, hideResource,
                             rollUpResource))
-        return FALSE;
+        return false;
     sortResourceList(filteredResourceList);
 
+    AccountList filteredAccountList;
+    if (!filterAccountList(filteredAccountList, AllAccounts, hideAccount,
+                           rollUpAccount))
+        return false;
+    sortAccountList(filteredAccountList);
+
     if (!generateProjectProperty(&tjEl))
-        return FALSE;
+        return false;
     if (!generateGlobalVacationList(&tjEl))
-        return FALSE;
+        return false;
     if (!generateShiftList(&tjEl))
-        return FALSE;
+        return false;
     if (!generateResourceList(&tjEl, filteredResourceList, filteredTaskList))
-        return FALSE;
+        return false;
+    if (!generateAccountList(&tjEl, filteredAccountList, filteredTaskList))
+        return false;
     if (!generateTaskList(&tjEl, filteredTaskList, filteredResourceList))
-        return FALSE;
+        return false;
     if (!generateBookingList(&tjEl, filteredTaskList, filteredResourceList))
-       return FALSE;
+       return false;
 
     gzFile zf = gzdopen(dup(f.handle()), "wb");
     if (!zf)
     {
-        qWarning(i18n("Cannot open compressed file %1 for writing.")
+        tjWarning(i18n("Cannot open compressed file %1 for writing.")
                  .arg(fileName));
-        return FALSE;
+        return false;
     }
     int bytes;
-    if ((bytes = gzputs(zf, (const char*) (doc->toCString()))) == 0)
+    if ((bytes = gzputs(zf, static_cast<const char*>(doc->toCString()))) == 0)
     {
-        qWarning(i18n("Compression of %1 failed").arg(fileName));
-        return FALSE;
+        tjWarning(i18n("Compression of %1 failed").arg(fileName));
+        return false;
     }
     int zError;
     if ((zError = gzclose(zf)) != 0)
     {
-        qWarning(i18n("Closing of file %1 failed: %2").arg(fileName)
+        tjWarning(i18n("Closing of file %1 failed: %2").arg(fileName)
                  .arg(gzerror(zf, &zError)));
-        return FALSE;
+        return false;
     }
-    f.close();
 
-    return TRUE;
+    return close();
 }
 
 bool
@@ -198,13 +199,13 @@ XMLReport::generateProjectProperty(QDomElement* n)
     // Generate custom attribute definitions
     if (!generateCustomAttributeDeclaration
         (&el, "task", project->getTaskAttributeDict()))
-        return FALSE;
+        return false;
     if (!generateCustomAttributeDeclaration
         (&el, "resource", project->getResourceAttributeDict()))
-        return FALSE;
+        return false;
     if (!generateCustomAttributeDeclaration
         (&el, "account", project->getAccountAttributeDict()))
-        return FALSE;
+        return false;
 
     // Generate date/time related settings
     genLongAttr(&el, "weekStartMonday",
@@ -236,7 +237,7 @@ XMLReport::generateProjectProperty(QDomElement* n)
 
     generateScenario(&el, project->getScenario(0));
 
-    return TRUE;
+    return true;
 }
 
 bool
@@ -245,7 +246,7 @@ XMLReport::generateCustomAttributeDeclaration(QDomElement* parentEl,
     QDictIterator<CustomAttributeDefinition> it)
 {
     if (!it.current())
-        return TRUE;
+        return true;
     QDomElement el = doc->createElement("extend");
     parentEl->appendChild(el);
     genTextAttr(&el, "property", propertyName);
@@ -264,7 +265,7 @@ XMLReport::generateCustomAttributeDeclaration(QDomElement* parentEl,
             default:
                 qFatal("XMLReport::generateCustomAttributeDeclaration: "
                        "Unknown CAT %d", it.current()->getType());
-                return FALSE;
+                return false;
         }
         QDomElement exEl = doc->createElement("extendAttributeDefinition");
         el.appendChild(exEl);
@@ -273,7 +274,7 @@ XMLReport::generateCustomAttributeDeclaration(QDomElement* parentEl,
         genTextAttr(&exEl, "type", exElType);
     }
 
-    return TRUE;
+    return true;
 }
 
 bool
@@ -292,13 +293,13 @@ XMLReport::generateScenario(QDomElement* parentEl, Scenario* scenario)
          *sci != 0; ++sci)
         generateScenario(&el, *sci);
 
-    return TRUE;
+    return true;
 }
 
 bool
 XMLReport::generateGlobalVacationList(QDomElement* parentNode)
 {
-    VacationListIterator vli(project->getVacationListIterator());
+    VacationList::Iterator vli(project->getVacationListIterator());
 
     if (*vli != 0)
     {
@@ -316,7 +317,7 @@ XMLReport::generateGlobalVacationList(QDomElement* parentNode)
         }
     }
 
-    return TRUE;
+    return true;
 }
 
 bool
@@ -330,10 +331,10 @@ XMLReport::generateShiftList(QDomElement* parentNode)
     {
         if ((*sli)->getParent() == 0)
             if (!generateShift(&el, *sli))
-                return FALSE;
+                return false;
     }
 
-    return TRUE;
+    return true;
 }
 
 bool
@@ -348,9 +349,9 @@ XMLReport::generateShift(QDomElement* parentEl, const Shift* shift)
 
     for (ShiftListIterator sli(shift->getSubListIterator()); *sli; ++sli)
         if (!generateShift(&el, *sli))
-            return FALSE;
+            return false;
 
-    return TRUE;
+    return true;
 }
 
 bool
@@ -378,7 +379,7 @@ XMLReport::generateWorkingHours(QDomElement* parentEl,
         }
     }
 
-    return TRUE;
+    return true;
 }
 
 bool
@@ -393,9 +394,9 @@ XMLReport::generateResourceList(QDomElement* parentNode,
         if ((*rli)->getParent() == 0)
             if (!generateResource(&el, filteredResourceList,
                                   filteredTaskList, *rli))
-                return FALSE;
+                return false;
 
-    return TRUE;
+    return true;
 }
 
 bool
@@ -410,6 +411,10 @@ XMLReport::generateResource(QDomElement* parentEl,
     genTextAttr(&el, "id", resource->getId());
     genTextAttr(&el, "name", resource->getName());
 
+    QStringList fl = resource->getFlagList();
+    for (QStringList::Iterator jt = fl.begin(); jt != fl.end(); ++jt)
+        genTextElement(&el, "flag", *jt);
+
     for (ResourceListIterator srli(resource->getSubListIterator());
          *srli != 0; ++srli)
     {
@@ -417,7 +422,7 @@ XMLReport::generateResource(QDomElement* parentEl,
         {
             if (!generateResource(&el, filteredResourceList, filteredTaskList,
                                   *srli))
-                return FALSE;
+                return false;
         }
     }
 
@@ -436,7 +441,8 @@ XMLReport::generateResource(QDomElement* parentEl,
     }
 
     generateWorkingHours(&el, resource->getWorkingHours());
-    for (ShiftSelectionListIterator sli(*resource->getShiftList()); *sli; ++sli)
+    for (ShiftSelectionList::Iterator sli(*resource->getShiftList()); *sli;
+         ++sli)
     {
         QDomElement sSel = doc->createElement("shiftSelection");
         el.appendChild(sSel);
@@ -446,7 +452,71 @@ XMLReport::generateResource(QDomElement* parentEl,
         genDateElement(&sSel, "end", (*sli)->getPeriod().getEnd() + 1);
     }
 
-    return TRUE;
+    return true;
+}
+
+bool
+XMLReport::generateAccountList(QDomElement* parentNode,
+                               AccountList& filteredAccountList,
+                               TaskList& filteredTaskList)
+{
+    QDomElement el = doc->createElement("accountList");
+    parentNode->appendChild(el);
+
+    for (AccountListIterator ali(filteredAccountList); *ali != 0; ++ali)
+    {
+        if ((*ali)->getParent() == 0)
+            if (!generateAccount(&el, filteredAccountList,
+                                 filteredTaskList, *ali))
+                return false;
+    }
+    return true;
+}
+
+bool
+XMLReport::generateAccount(QDomElement* parentEl,
+                           AccountList& filteredAccountList,
+                           TaskList& filteredTaskList,
+                           const Account* account)
+{
+    QDomElement el = doc->createElement("account");
+    parentEl->appendChild(el);
+
+    genTextAttr(&el, "id", account->getId());
+    genTextAttr(&el, "name", account->getName());
+
+    switch (account->getAcctType())
+    {
+    case Cost:
+        genTextAttr(&el, "type", "cost");
+        break;
+    case Revenue:
+        genTextAttr(&el, "type", "revenue");
+        break;
+    default:
+        qFatal("XMLReport::generateAccount: Unknown AccountType %d",
+               account->getAcctType());
+        return false;
+    }
+
+    for (QStringList::Iterator it = accountAttributes.begin();
+         it != accountAttributes.end(); ++it)
+    {
+        if (account->getCustomAttribute(*it))
+            generateCustomAttributeValue(&el, *it, account);
+    }
+
+    for (AccountListIterator srli(account->getSubListIterator());
+         *srli != 0; ++srli)
+    {
+        if (filteredAccountList.findRef(*srli) >= 0)
+        {
+            if (!generateAccount(&el, filteredAccountList, filteredTaskList,
+                                 *srli))
+                return false;
+        }
+    }
+    return true;
 }
 
 bool
@@ -460,9 +530,9 @@ XMLReport::generateTaskList(QDomElement* parentNode, TaskList& filteredTaskList,
         if ((*tli)->getParent() == 0 ||
             (*tli)->getParent()->getId() + "." == taskRoot)
             if (!generateTask(&el, filteredTaskList, *tli))
-                return FALSE;
+                return false;
 
-    return TRUE;
+    return true;
 }
 
 bool
@@ -531,25 +601,30 @@ XMLReport::generateTask(QDomElement* parentEl, TaskList& filteredTaskList,
                 generateDepList(&el, filteredTaskList, task,
                                 task->getPrecedesIterator(), "precedes");
                 break;
+            case TA_ACCOUNT:
+                if (task->getAccount())
+                    genTextAttr(&el, "account",
+                                task->getAccount()->getId());
+                break;
             default:
                 qDebug("XMLReport::generateTask(): "
                        "Unknown task attribute %s", (*it).latin1());
-                return FALSE;
+                return false;
         }
 
     }
 
     /* If a container task has sub tasks that are exported as well, we do
      * not export start/end date for those container tasks. */
-    bool taskHasNoSubTasks = TRUE;
+    bool taskHasNoSubTasks = true;
     for (TaskListIterator stli(task->getSubListIterator());
          *stli != 0; ++stli)
     {
         if (filteredTaskList.findRef(*stli) >= 0)
         {
-            taskHasNoSubTasks = FALSE;
+            taskHasNoSubTasks = false;
             if (!generateTask(&el, filteredTaskList, *stli))
-                return FALSE;
+                return false;
         }
     }
 
@@ -631,7 +706,7 @@ XMLReport::generateTask(QDomElement* parentEl, TaskList& filteredTaskList,
 
     generateAllocate(&el, task);
 
-    return TRUE;
+    return true;
 }
 
 bool
@@ -685,7 +760,7 @@ XMLReport::generateDepList(QDomElement* parentEl, TaskList& filteredTaskList,
         filteredTaskList.findRef(curr);
     }
 
-    return TRUE;
+    return true;
 }
 
 bool
@@ -706,7 +781,7 @@ XMLReport::generateCustomAttributeValue(QDomElement* parentEl,
             QDomElement cEl = doc->createElement("textAttribute");
             el.appendChild(cEl);
 
-            genTextAttr(&cEl, "text", ((const TextAttribute*) ca)->getText());
+            genTextAttr(&cEl, "text", static_cast<const TextAttribute*>(ca)->getText());
             break;
         }
         case CAT_Reference:
@@ -715,7 +790,7 @@ XMLReport::generateCustomAttributeValue(QDomElement* parentEl,
             el.appendChild(cEl);
 
             const ReferenceAttribute* a =
-                (const ReferenceAttribute*) ca;
+                static_cast<const ReferenceAttribute*>(ca);
             genTextAttr(&cEl, "url", a->getURL());
             genTextAttr(&cEl, "label", a->getLabel());
             break;
@@ -727,7 +802,7 @@ XMLReport::generateCustomAttributeValue(QDomElement* parentEl,
                    ca->getType());
     }
 
-    return TRUE;
+    return true;
 }
 
 bool
@@ -748,7 +823,7 @@ XMLReport::generateAllocate(QDomElement* parentEl, const Task* t)
         }
     }
 
-    return TRUE;
+    return true;
 }
 
 bool
@@ -770,11 +845,11 @@ XMLReport::generateBookingList(QDomElement* parentEl,
             genTextAttr(&scEl, "scenarioId", project->getScenarioId(*sit));
 
             BookingList bl = (*rli)->getJobs(*sit);
-            bl.setAutoDelete(TRUE);
+            bl.setAutoDelete(true);
             if (bl.isEmpty())
                 continue;
 
-            for (BookingListIterator bli(bl); *bli != 0; ++bli)
+            for (BookingList::Iterator bli(bl); *bli != 0; ++bli)
             {
                 if (filteredTaskList.findRef((*bli)->getTask()) >= 0)
                 {
@@ -789,7 +864,33 @@ XMLReport::generateBookingList(QDomElement* parentEl,
             }
         }
     }
-    return TRUE;
+    return true;
+}
+
+bool
+XMLReport::addAccountAttribute(const QString& aa)
+{
+    if (aa == KW("all"))
+    {
+        for (QDictIterator<CustomAttributeDefinition>
+             it(project->getAccountAttributeDict()); *it; ++it)
+        {
+            accountAttributes.append(it.currentKey());
+        }
+
+        return true;
+    }
+
+    /* Make sure the 'ta' is a valid attribute name and that we don't
+     * insert it twice into the list. Trying to insert it twice it not an
+     * error though. */
+    if (project->getAccountAttribute(aa) == 0)
+        return false;
+
+    if (accountAttributes.findIndex(aa) >= 0)
+        return true;
+    accountAttributes.append(aa);
+    return true;
 }
 
 bool
@@ -808,7 +909,7 @@ XMLReport::addTaskAttribute(const QString& ta)
              it(project->getTaskAttributeDict()); *it; ++it)
             taskAttributes.append(it.currentKey());
 
-        return TRUE;
+        return true;
     }
 
     /* Make sure the 'ta' is a valid attribute name and that we don't
@@ -816,12 +917,12 @@ XMLReport::addTaskAttribute(const QString& ta)
      * error though. */
     if (TaskAttributeDict.find(ta) == TaskAttributeDict.end() &&
         project->getTaskAttribute(ta) == 0)
-        return FALSE;
+        return false;
 
     if (taskAttributes.findIndex(ta) >= 0)
-        return TRUE;
+        return true;
     taskAttributes.append(ta);
-    return TRUE;
+    return true;
 }
 
 void
@@ -885,7 +986,7 @@ XMLReport::genTimeElement(QDomElement* parentEl, const QString& name,
    el.appendChild(tEl);
 
    QDomAttr at = doc->createAttribute("humanReadable");
-   at.setValue(time2user(val, shortTimeFormat, FALSE));
+   at.setValue(time2user(val, shortTimeFormat, false));
    el.setAttributeNode(at);
 
    parentEl->appendChild(el);
